# OZI CHANGELOG
## 2.0.18 (2025-06-10)


### ⬆️ Upgraded Dependencies

* (cflite): Bump pyinstaller in /.clusterfuzzlite

Bumps [pyinstaller](https://github.com/pyinstaller/pyinstaller) from 6.14.0 to 6.14.1.
- [Release notes](https://github.com/pyinstaller/pyinstaller/releases)
- [Changelog](https://github.com/pyinstaller/pyinstaller/blob/develop/doc/CHANGES.rst)
- [Commits](https://github.com/pyinstaller/pyinstaller/compare/v6.14.0...v6.14.1)


updated-dependencies:
- dependency-name: pyinstaller
  dependency-version: 6.14.1
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`5660244`](https://github.com/OZI-Project/OZI/commit/56602449a09de8ef46f5fed31fd28504f1992a56))


### 🔨 Updated Scripts

* (cflite): fix locale path typo — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`0c94057`](https://github.com/OZI-Project/OZI/commit/0c940578966fb5a86b154b2bd6eb0cdb7b39d80c))

* (cflite): add gettext deb package source — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`81f212f`](https://github.com/OZI-Project/OZI/commit/81f212f8eeefb5aceda04a1ea3f446516fa50573))

* (cflite): add locales data to bundle — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`a4c7646`](https://github.com/OZI-Project/OZI/commit/a4c7646f01fe9c98a5b8d8788548e2fb33728572))

* (cflite): remove gettext install — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`09b5fef`](https://github.com/OZI-Project/OZI/commit/09b5fefcea7c9a45a64b40c1707957bc85bfda08))

## 2.0.17 (2025-06-09)


### ⬆️ Upgraded Dependencies

*  Bump ozi-core from 1.21.4 to 1.21.5

Bumps [ozi-core](https://github.com/OZI-Project/ozi-core) from 1.21.4 to 1.21.5.
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/main/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.21.4...1.21.5)


updated-dependencies:
- dependency-name: ozi-core
  dependency-version: 1.21.5
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`fbf7ccd`](https://github.com/OZI-Project/OZI/commit/fbf7ccd514617beb39a3fd2b61213de552f85e3e))


### 🐛 Fixed Bugs

*  pytest requirements pinned to 8.3.5 — Eden Ross Duff MSc <ozi.project@outlook.com>
([`64809d5`](https://github.com/OZI-Project/OZI/commit/64809d54912c9a9da95fc6e800db9d0b5946d3e4))


### 🔨 Updated Scripts

*  create_subproject_symlink.py script backported to Python 3.9 — Eden Ross Duff MSc <ozi.project@outlook.com>
([`7c9cece`](https://github.com/OZI-Project/OZI/commit/7c9ceceac9472d9ddd9dd05569ae65816fe77a89))

## 2.0.16 (2025-06-08)


### ⬆️ Upgraded Dependencies

*  Bump ozi-core from 1.21.3 to 1.21.4

Bumps [ozi-core](https://github.com/OZI-Project/ozi-core) from 1.21.3 to 1.21.4.
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/1.21.4/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.21.3...1.21.4)


updated-dependencies:
- dependency-name: ozi-core
  dependency-version: 1.21.4
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`50b012f`](https://github.com/OZI-Project/OZI/commit/50b012fd0ad456113f8d2ecd6f29117c749ae54f))

## 2.0.15 (2025-06-08)


### ⬆️ Upgraded Dependencies

*  Bump ozi-core from 1.21.2 to 1.21.3

Bumps [ozi-core](https://github.com/OZI-Project/ozi-core) from 1.21.2 to 1.21.3.
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/1.21.3/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.21.2...1.21.3)


updated-dependencies:
- dependency-name: ozi-core
  dependency-version: 1.21.3
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`a0445f9`](https://github.com/OZI-Project/OZI/commit/a0445f977bcee568b56510850599deb88cfaa649))

## 2.0.14 (2025-06-08)


### ⬆️ Upgraded Dependencies

*  Bump ozi-core from 1.21.1 to 1.21.2

Bumps [ozi-core](https://github.com/OZI-Project/ozi-core) from 1.21.1 to 1.21.2.
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/1.21.2/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.21.1...1.21.2)


updated-dependencies:
- dependency-name: ozi-core
  dependency-version: 1.21.2
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`28b9628`](https://github.com/OZI-Project/OZI/commit/28b962808b028616a2bf5cfeb63b1458bd9b4679))


### Other


* chore: clean up lint — Eden Ross Duff MSc <ozi.project@outlook.com>
([`2554aa5`](https://github.com/OZI-Project/OZI/commit/2554aa56088171333371aaaba3653bdc9be9a33f))

* chore: clean up lint — Eden Ross Duff MSc <ozi.project@outlook.com>
([`6687546`](https://github.com/OZI-Project/OZI/commit/6687546b93098e2c478d7765d52557ead0a5163e))

## 2.0.13 (2025-06-08)


### ⬆️ Upgraded Dependencies

*  Bump ozi-core from 1.21.0 to 1.21.1

Bumps [ozi-core](https://github.com/OZI-Project/ozi-core) from 1.21.0 to 1.21.1.
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/1.21.1/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.21.0...1.21.1)


updated-dependencies:
- dependency-name: ozi-core
  dependency-version: 1.21.1
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`d70cfa2`](https://github.com/OZI-Project/OZI/commit/d70cfa2118f0951f3d97fe0ee21da716bce07b18))


### Other


* fix: set parser on ozi.__main__ — Eden Ross Duff MSc <ozi.project@outlook.com>
([`03a9b03`](https://github.com/OZI-Project/OZI/commit/03a9b03289e25cf0c7f454ef5eec99f531af7ffd))

## 2.0.12 (2025-06-07)


### ⬆️ Upgraded Dependencies

*  Bump ozi-core from 1.20.5 to 1.21.0

Bumps [ozi-core](https://github.com/OZI-Project/ozi-core) from 1.20.5 to 1.21.0.
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/1.21.0/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.20.5...1.21.0)


updated-dependencies:
- dependency-name: ozi-core
  dependency-version: 1.21.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`b3a92c0`](https://github.com/OZI-Project/OZI/commit/b3a92c051bc1affa5adef845c7abba3be81da036))

## 2.0.11 (2025-06-07)


### 🐛 Fixed Bugs

*  force release — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`a461079`](https://github.com/OZI-Project/OZI/commit/a461079481094ecd4ffeade54c3cfbd15d1a49c8))


### 📝 Updated Documentation

*  add links to readme — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`44876af`](https://github.com/OZI-Project/OZI/commit/44876afa461e94d82b60fb93c2de3fbc3ea270a5))


### Other


* fix: pytest requirements missing pyyaml-ft — Eden Ross Duff MSc <ozi.project@outlook.com>
([`f038c39`](https://github.com/OZI-Project/OZI/commit/f038c39e637fa60df829ec2c38e0b516c989ec7e))

## 2.0.10 (2025-06-07)


### 🐛 Fixed Bugs

*  add pyyaml to pytest requirements — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`0f3b0c5`](https://github.com/OZI-Project/OZI/commit/0f3b0c5699c7c9fae83b0331ea66903ad4fdf660))


### Other


* fix: pytest requirements compiled with support back to Python 3.9 — Eden Ross Duff MSc <ozi.project@outlook.com>
([`3fb29e7`](https://github.com/OZI-Project/OZI/commit/3fb29e75fce60c421ec969a8ed31edd4e44dae5c))

## 2.0.9 (2025-06-07)


### 🐛 Fixed Bugs

*  pytest requirements missing PyYAML-ft — Eden Ross Duff MSc <ozi.project@outlook.com>
([`d30a0b6`](https://github.com/OZI-Project/OZI/commit/d30a0b6b66289e5468b208b31e9f68cf72c5264f))

## 2.0.8 (2025-06-07)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/checkpoint from 1.7.5 to 1.8.2

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.7.5 to 1.8.2.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/301753e6853d6a65055c8df69dafe7df74bd7963...e60a6b3b5a423885e6c3feab1dfc35ed9472b737)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-version: 1.8.2
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`1f14da2`](https://github.com/OZI-Project/OZI/commit/1f14da2729c3504d3e9e917c0556cf330bee2d5c))


### Other


* fix: requirements compiled with support back to Python 3.9 — Eden Ross Duff MSc <ozi.project@outlook.com>
([`23f11b6`](https://github.com/OZI-Project/OZI/commit/23f11b6ea046b2950d654ba17f4ca54771b0faf3))

## 2.0.7 (2025-06-07)


### 🐛 Fixed Bugs

*  workaround broken pip-tools by adding reqs to VCS — Eden Ross Duff MSc <ozi.project@outlook.com>
([`de60857`](https://github.com/OZI-Project/OZI/commit/de60857833fdb4cad66eb63640c2272fdc0f3284))

## 2.0.6 (2025-06-07)


### ⬆️ Upgraded Dependencies

*  Bump ozi-core from 1.20.4 to 1.20.5

Bumps [ozi-core](https://github.com/OZI-Project/ozi-core) from 1.20.4 to 1.20.5.
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/1.20.5/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.20.4...1.20.5)


updated-dependencies:
- dependency-name: ozi-core
  dependency-version: 1.20.5
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`4adb421`](https://github.com/OZI-Project/OZI/commit/4adb421e809d3e25018a5060cfafbf5adc821992))

* (cflite): Bump hypothesis in /.clusterfuzzlite

Bumps [hypothesis](https://github.com/HypothesisWorks/hypothesis) from 6.135.0 to 6.135.1.
- [Release notes](https://github.com/HypothesisWorks/hypothesis/releases)
- [Commits](https://github.com/HypothesisWorks/hypothesis/compare/hypothesis-python-6.135.0...hypothesis-python-6.135.1)


updated-dependencies:
- dependency-name: hypothesis
  dependency-version: 6.135.1
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`9e92581`](https://github.com/OZI-Project/OZI/commit/9e9258154111a73643abf5c118924f8947fa2106))


### Other


* build(cflite): add gettext for localizations in fuzzers — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`75e1d17`](https://github.com/OZI-Project/OZI/commit/75e1d1762dd2bb2d4909763c3d3b3252081a9002))

## 2.0.5 (2025-06-04)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.28.18 to 3.28.19

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.28.18 to 3.28.19.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/ff0a06e83cb2de871e5a09832bc6a81e7276941f...fca7ace96b7d713c7035871441bd52efbe39e27e)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-version: 3.28.19
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`65ccb17`](https://github.com/OZI-Project/OZI/commit/65ccb17cd846e038cac6e6fb39bc3b1dbd88f542))

* (cflite): Bump hypothesis in /.clusterfuzzlite

Bumps [hypothesis](https://github.com/HypothesisWorks/hypothesis) from 6.133.2 to 6.135.0.
- [Release notes](https://github.com/HypothesisWorks/hypothesis/releases)
- [Commits](https://github.com/HypothesisWorks/hypothesis/compare/hypothesis-python-6.133.2...hypothesis-python-6.135.0)


updated-dependencies:
- dependency-name: hypothesis
  dependency-version: 6.135.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`7e15737`](https://github.com/OZI-Project/OZI/commit/7e157372c5bfc95f9f96712ae0f8e95ff6df0381))

* (cflite): Bump pyinstaller in /.clusterfuzzlite

Bumps [pyinstaller](https://github.com/pyinstaller/pyinstaller) from 6.13.0 to 6.14.0.
- [Release notes](https://github.com/pyinstaller/pyinstaller/releases)
- [Changelog](https://github.com/pyinstaller/pyinstaller/blob/develop/doc/CHANGES.rst)
- [Commits](https://github.com/pyinstaller/pyinstaller/compare/v6.13.0...v6.14.0)


updated-dependencies:
- dependency-name: pyinstaller
  dependency-version: 6.14.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`bae5af2`](https://github.com/OZI-Project/OZI/commit/bae5af2a4033ab5c2a0c770ba471e7e88c48c4f5))

*  Update hypothesis[cli,codemods,ghostwriter] requirement

Updates the requirements on [hypothesis[cli,codemods,ghostwriter]](https://github.com/HypothesisWorks/hypothesis) to permit the latest version.
- [Release notes](https://github.com/HypothesisWorks/hypothesis/releases)
- [Commits](https://github.com/HypothesisWorks/hypothesis/compare/hypothesis-python-6.133.0...hypothesis-python-6.135.0)


updated-dependencies:
- dependency-name: hypothesis[cli,codemods,ghostwriter]
  dependency-version: 6.135.0
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`6512d37`](https://github.com/OZI-Project/OZI/commit/6512d373aa8a53bfc86b9b88fe19ec17b0f3dbe5))

*  Update pytest requirement in /ozi/test/pytest

Updates the requirements on [pytest](https://github.com/pytest-dev/pytest) to permit the latest version.
- [Release notes](https://github.com/pytest-dev/pytest/releases)
- [Changelog](https://github.com/pytest-dev/pytest/blob/main/CHANGELOG.rst)
- [Commits](https://github.com/pytest-dev/pytest/compare/8.3.0...8.3.5)


updated-dependencies:
- dependency-name: pytest
  dependency-version: 8.3.5
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`71fd37c`](https://github.com/OZI-Project/OZI/commit/71fd37c4a5faae1c889668428e5ca0eebd3e474a))

## 2.0.4 (2025-06-03)


### ⬆️ Upgraded Dependencies

* (cflite): Bump hypothesis in /.clusterfuzzlite

Bumps [hypothesis](https://github.com/HypothesisWorks/hypothesis) from 6.133.0 to 6.133.2.
- [Release notes](https://github.com/HypothesisWorks/hypothesis/releases)
- [Commits](https://github.com/HypothesisWorks/hypothesis/compare/hypothesis-python-6.133.0...hypothesis-python-6.133.2)


updated-dependencies:
- dependency-name: hypothesis
  dependency-version: 6.133.2
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`0611e00`](https://github.com/OZI-Project/OZI/commit/0611e00498609efc7d76b8db2fde3ee7f0ece7d6))

*  Bump ozi-core from 1.20.3 to 1.20.4

Bumps [ozi-core](https://github.com/OZI-Project/ozi-core) from 1.20.3 to 1.20.4.
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/main/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.20.3...1.20.4)


updated-dependencies:
- dependency-name: ozi-core
  dependency-version: 1.20.4
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`decf0e6`](https://github.com/OZI-Project/OZI/commit/decf0e6fb3b4fedaeccf66af410221bbad31cdd1))

*  Update urllib3 requirement in /ozi/test/pytest

Updates the requirements on [urllib3](https://github.com/urllib3/urllib3) to permit the latest version.
- [Release notes](https://github.com/urllib3/urllib3/releases)
- [Changelog](https://github.com/urllib3/urllib3/blob/main/CHANGES.rst)
- [Commits](https://github.com/urllib3/urllib3/compare/1.26.0...2.4.0)


updated-dependencies:
- dependency-name: urllib3
  dependency-version: 2.4.0
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`ab0eb62`](https://github.com/OZI-Project/OZI/commit/ab0eb628f3ff0c91d0c086d09ca175eabc8a02f7))


### 📝 Updated Documentation

*  Update README — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`0ebdba5`](https://github.com/OZI-Project/OZI/commit/0ebdba5f054d6764f64bc63c8ec09576a1c7413a))


### 🔨 Updated Configuration

*  Update dependabot.yml — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`3d35528`](https://github.com/OZI-Project/OZI/commit/3d35528bbb831b10f45d5aeb10c2e455cb91e8a9))


### Other


* chore: add pull-requests: write to publish — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`5db2ebc`](https://github.com/OZI-Project/OZI/commit/5db2ebc479bf0a3e03aab407ed37e8377c054dab))

* chore: add create-pull-request: true to dist-workflow — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`162c523`](https://github.com/OZI-Project/OZI/commit/162c523c5321dec4356d92ab0594ac5f6d5e7efa))

## 2.0.3 (2025-06-03)


### 🐛 Fixed Bugs

*  update meson.build-postconf_setup_virtual_env-2.0.0.patch

fixes errant double patching — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`0b33d23`](https://github.com/OZI-Project/OZI/commit/0b33d23ec2b17b0331269904e8c23ee96a2783e2))

## 2.0.2 (2025-06-02)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/release from 1.8.4 to 1.8.5

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.8.4 to 1.8.5.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/560c20ace6ea984de7dfa32f7007d139916c7d94...84d51474b41de0c8c98d34431f9c0e282fd72c19)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.8.5
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`a5b4e39`](https://github.com/OZI-Project/OZI/commit/a5b4e39dfb3c13449360d7a79ccf6ede39ba57c9))

*  Bump OZI-Project/release from 1.8.3 to 1.8.4

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.8.3 to 1.8.4.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0a9f46ecacc5bb6a926467a601c8b75bb2deb4ac...560c20ace6ea984de7dfa32f7007d139916c7d94)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.8.4
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`5f90534`](https://github.com/OZI-Project/OZI/commit/5f90534d63e7cc6e8a32afa8fc2ec58857718d22))


### 📌 Pinned Dependencies

*  pytest~=8.3.0 because pytest 8.4 causes issues with coverage+xdist — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`1b4f386`](https://github.com/OZI-Project/OZI/commit/1b4f3868013df2568475d052a112ce048e75aeb8))

## 2.0.1 (2025-06-02)


### ⬆️ Upgraded Dependencies

* (cflite): Bump hypothesis in /.clusterfuzzlite

Bumps [hypothesis](https://github.com/HypothesisWorks/hypothesis) from 6.132.0 to 6.133.0.
- [Release notes](https://github.com/HypothesisWorks/hypothesis/releases)
- [Commits](https://github.com/HypothesisWorks/hypothesis/compare/hypothesis-python-6.132.0...hypothesis-python-6.133.0)


updated-dependencies:
- dependency-name: hypothesis
  dependency-version: 6.133.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`cbc1be2`](https://github.com/OZI-Project/OZI/commit/cbc1be2b390e21ba652b9461b07df879d4da54f7))

*  Update hypothesis[cli,codemods,ghostwriter] requirement

Updates the requirements on [hypothesis[cli,codemods,ghostwriter]](https://github.com/HypothesisWorks/hypothesis) to permit the latest version.
- [Release notes](https://github.com/HypothesisWorks/hypothesis/releases)
- [Commits](https://github.com/HypothesisWorks/hypothesis/compare/hypothesis-python-6.132.0...hypothesis-python-6.133.0)


updated-dependencies:
- dependency-name: hypothesis[cli,codemods,ghostwriter]
  dependency-version: 6.133.0
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`830f531`](https://github.com/OZI-Project/OZI/commit/830f531f4a8ba5a51dcd893e5e99a9814676d159))


### 🐛 Fixed Bugs

*  install glibc-2.35 in fuzzer Dockerfile — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`1d1a4a1`](https://github.com/OZI-Project/OZI/commit/1d1a4a11d072057d429ea7f27b602a87aeb01e2a))

*  pin tomli for fuzzer builds — Eden Ross Duff MSc <ozi.project@outlook.com>
([`51e0d05`](https://github.com/OZI-Project/OZI/commit/51e0d0522e23d35eb95bb89e11e6cce65a5ea866))

*  pin typing-extensions for fuzzer builds — Eden Ross Duff MSc <ozi.project@outlook.com>
([`1f5a4ce`](https://github.com/OZI-Project/OZI/commit/1f5a4ce98b0eb4dcea8afdf0a6ff6cf28bc5400f))

*  pin exceptiongroup for fuzzer builds — Eden Ross Duff MSc <ozi.project@outlook.com>
([`7db5b7c`](https://github.com/OZI-Project/OZI/commit/7db5b7c881ac89bfb30ebbc6da8e8d5c24a2b2f3))

*  add hashes to requirements.txt for fuzzers — Eden Ross Duff MSc <ozi.project@outlook.com>
([`e4c272c`](https://github.com/OZI-Project/OZI/commit/e4c272c48af9aefd0a8e1c40975ed83b41394431))


### Other


* Update build.sh remove bootstrap.sh — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`942cc5e`](https://github.com/OZI-Project/OZI/commit/942cc5ec241b27ad77edaaf5dec11e049fbcd9a5))

* Update Dockerfile — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`c69689f`](https://github.com/OZI-Project/OZI/commit/c69689f4c56be79f3b4582b49eb1a3528756998e))

* Update Dockerfile — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`f54519c`](https://github.com/OZI-Project/OZI/commit/f54519c30ee2d4c48e7c7d032dbdd056269905c9))

* Update Dockerfile — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`d7af08a`](https://github.com/OZI-Project/OZI/commit/d7af08ac5cfdecef5fefa5991da0fe5e6f4270ca))

* Update Dockerfile — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`0f1a368`](https://github.com/OZI-Project/OZI/commit/0f1a3680a76180b5f13c32b0d377b365fbdb7de1))

* Update Dockerfile — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`d1937f7`](https://github.com/OZI-Project/OZI/commit/d1937f78f006754fbfebf99e35fa67f5c661f882))

## 2.0.0 (2025-06-01)


### ⬆️ Upgraded Dependencies

*  Bump ozi-core from 1.20.1 to 1.20.3

Bumps [ozi-core](https://github.com/OZI-Project/ozi-core) from 1.20.1 to 1.20.3.
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/1.20.3/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.20.1...1.20.3)


updated-dependencies:
- dependency-name: ozi-core
  dependency-version: 1.20.3
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`67e5fe2`](https://github.com/OZI-Project/OZI/commit/67e5fe28ae84d5e708658f91834a3124d23b0bb9))

*  Bump ozi-core from 1.19.9 to 1.20.1

Bumps [ozi-core](https://github.com/OZI-Project/ozi-core) from 1.19.9 to 1.20.1.
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/1.20.1/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.19.9...1.20.1)


updated-dependencies:
- dependency-name: ozi-core
  dependency-version: 1.20.1
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`8ff104c`](https://github.com/OZI-Project/OZI/commit/8ff104c26150bd2c0b22873eeb97d98b1d3ac657))

*  Update hypothesis[cli,codemods,ghostwriter] requirement

Updates the requirements on [hypothesis[cli,codemods,ghostwriter]](https://github.com/HypothesisWorks/hypothesis) to permit the latest version.
- [Release notes](https://github.com/HypothesisWorks/hypothesis/releases)
- [Commits](https://github.com/HypothesisWorks/hypothesis/compare/hypothesis-python-6.131.0...hypothesis-python-6.132.0)


updated-dependencies:
- dependency-name: hypothesis[cli,codemods,ghostwriter]
  dependency-version: 6.132.0
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`4bebb9a`](https://github.com/OZI-Project/OZI/commit/4bebb9a4c8aa5fefb0d387100b968428d936ec0b))

*  Update pytest-xdist requirement in /ozi/test/pytest

Updates the requirements on [pytest-xdist](https://github.com/pytest-dev/pytest-xdist) to permit the latest version.
- [Release notes](https://github.com/pytest-dev/pytest-xdist/releases)
- [Changelog](https://github.com/pytest-dev/pytest-xdist/blob/master/CHANGELOG.rst)
- [Commits](https://github.com/pytest-dev/pytest-xdist/compare/v3.6.0...v3.7.0)


updated-dependencies:
- dependency-name: pytest-xdist
  dependency-version: 3.7.0
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`05faaf9`](https://github.com/OZI-Project/OZI/commit/05faaf902f44388d0d81a63eb86f4acfba7dca78))

*  Update flake8-pyi requirement in /ozi/lint/flake8

Updates the requirements on [flake8-pyi](https://github.com/PyCQA/flake8-pyi) to permit the latest version.
- [Release notes](https://github.com/PyCQA/flake8-pyi/releases)
- [Changelog](https://github.com/PyCQA/flake8-pyi/blob/main/CHANGELOG.md)
- [Commits](https://github.com/PyCQA/flake8-pyi/compare/24.9.0...25.5.0)


updated-dependencies:
- dependency-name: flake8-pyi
  dependency-version: 25.5.0
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`9be8baf`](https://github.com/OZI-Project/OZI/commit/9be8baf3f228fc50196bbe95a7ab93f93c7b3e66))

*  Update python-semantic-release requirement

Updates the requirements on [python-semantic-release](https://github.com/python-semantic-release/python-semantic-release) to permit the latest version.
- [Release notes](https://github.com/python-semantic-release/python-semantic-release/releases)
- [Changelog](https://github.com/python-semantic-release/python-semantic-release/blob/master/CHANGELOG.rst)
- [Commits](https://github.com/python-semantic-release/python-semantic-release/compare/v9.21...v10.0.2)


updated-dependencies:
- dependency-name: python-semantic-release
  dependency-version: 10.0.2
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`43b2f68`](https://github.com/OZI-Project/OZI/commit/43b2f689a30d0d66930787e80618b91117c9f0c1))

*  pytest-asyncio~=1.0.0 — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`e90a7ea`](https://github.com/OZI-Project/OZI/commit/e90a7ea35501a2f97d8757de907568d42b549026))


### 💥


*  ozi-spec 1.0 - semantic-release 10.0 — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`aaef750`](https://github.com/OZI-Project/OZI/commit/aaef750ee558d7120ac0ba0dfaf3b271d6e67985))


### Other


* 👷(tool.semantic_release.branches): release/2.x — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`a729de5`](https://github.com/OZI-Project/OZI/commit/a729de554506bb78879fd3cbd588df4c03950e78))

* fix: add setup virtualenv for new projects and patch for current projects

fixes #1133 — Eden Ross Duff MSc <ozi.project@outlook.com>
([`e8ef91b`](https://github.com/OZI-Project/OZI/commit/e8ef91b8cbba5e4b01aa17fe44b4a7035f9f57d6))

* chore: update SECURITY.md

BREAKING CHANGE: ozi-spec 1.0 - semantic-release 10 - remove all changelog and release template files  — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`cc4fe89`](https://github.com/OZI-Project/OZI/commit/cc4fe8958114f89038360110e169c907ecfe8181))

## 1.41.12 (2025-06-01)


### ⬆️ Upgraded Dependencies

*  Update cryptography requirement in /ozi/dist/semantic_release

Updates the requirements on [cryptography](https://github.com/pyca/cryptography) to permit the latest version.
- [Changelog](https://github.com/pyca/cryptography/blob/main/CHANGELOG.rst)
- [Commits](https://github.com/pyca/cryptography/compare/43.0.0...45.0.3)


updated-dependencies:
- dependency-name: cryptography
  dependency-version: 45.0.3
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`ea71987`](https://github.com/OZI-Project/OZI/commit/ea71987b8d14341ee16f7408f0da271851dd7128))

*  Update cryptography requirement in /ozi/dist/twine

Updates the requirements on [cryptography](https://github.com/pyca/cryptography) to permit the latest version.
- [Changelog](https://github.com/pyca/cryptography/blob/main/CHANGELOG.rst)
- [Commits](https://github.com/pyca/cryptography/compare/43.0.0...45.0.3)


updated-dependencies:
- dependency-name: cryptography
  dependency-version: 45.0.3
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`2ce75e0`](https://github.com/OZI-Project/OZI/commit/2ce75e0677b56cc382c26584a82db00cc8b5a7b8))

*  Update cryptography requirement in /ozi/dist/sigstore

Updates the requirements on [cryptography](https://github.com/pyca/cryptography) to permit the latest version.
- [Changelog](https://github.com/pyca/cryptography/blob/main/CHANGELOG.rst)
- [Commits](https://github.com/pyca/cryptography/compare/43.0.0...45.0.3)


updated-dependencies:
- dependency-name: cryptography
  dependency-version: 45.0.3
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`075589b`](https://github.com/OZI-Project/OZI/commit/075589bf5966ce79bf35a0ce02473bc7de881352))

*  Bump OZI-Project/publish from 1.13.8 to 1.14.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.13.8 to 1.14.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/39cc73091234a1dc42b933df3d965318966e65a2...0d8a74931c945399bb0967f77c67055956b9e5c5)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-version: 1.14.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`51807ad`](https://github.com/OZI-Project/OZI/commit/51807adccca61469166832c7e23966f6999bf4fc))

*  Bump OZI-Project/draft from 1.13.5 to 1.14.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.13.5 to 1.14.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/fbf34233ed3d0719d994c2172ac767644c97a2aa...9fcb96b0c50c0da405737413299ede083f1d94cf)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-version: 1.14.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`72cd098`](https://github.com/OZI-Project/OZI/commit/72cd0981af2f2597f5162566e259431c2903e63d))

*  Bump ossf/scorecard-action from 2.4.1 to 2.4.2

Bumps [ossf/scorecard-action](https://github.com/ossf/scorecard-action) from 2.4.1 to 2.4.2.
- [Release notes](https://github.com/ossf/scorecard-action/releases)
- [Changelog](https://github.com/ossf/scorecard-action/blob/main/RELEASE.md)
- [Commits](https://github.com/ossf/scorecard-action/compare/f49aabe0b5af0936a0987cfb85d86b75731b0186...05b42c624433fc40578a4040d5cf5e36ddca8cde)


updated-dependencies:
- dependency-name: ossf/scorecard-action
  dependency-version: 2.4.2
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`6cfa029`](https://github.com/OZI-Project/OZI/commit/6cfa029f29d46f2ae1991c48280cff9b5828b3c9))

*  Bump OZI-Project/checkpoint from 1.7.4 to 1.7.5

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.7.4 to 1.7.5.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/40890b7e9f18621e556892606346aebc8292cfa6...301753e6853d6a65055c8df69dafe7df74bd7963)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-version: 1.7.5
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`f5b26e7`](https://github.com/OZI-Project/OZI/commit/f5b26e784e0fd0f93eab1a3c9a5d3c7bd834721e))


### 🐛 Fixed Bugs

*  Revert "Merge pull request #1655 from OZI-Project/dependabot/pip/ozi/dist/sigstore/cryptography-approx-eq-45.0"

This reverts commit 90b5b2a2c787f527f0c7155e2370f5b1f80f0189, reversing
changes made to 8b09085a141c5e919fee389aad6b39676c8ff8a1.
([`123642d`](https://github.com/OZI-Project/OZI/commit/123642da0718dc4d066dd055198879498313d575))

*  Revert "Merge pull request #1656 from OZI-Project/dependabot/pip/ozi/dist/twine/cryptography-approx-eq-45.0"

This reverts commit 4d8ed75c72077b5f06f5c3018196f1d972e8ff00, reversing
changes made to 90b5b2a2c787f527f0c7155e2370f5b1f80f0189.
([`4bd9f30`](https://github.com/OZI-Project/OZI/commit/4bd9f3087b7afe456f1c17bd3bf873c96527a393))

*  Revert "Merge pull request #1653 from OZI-Project/dependabot/pip/ozi/dist/semantic_release/cryptography-approx-eq-45.0"

This reverts commit e9b7dddbd798f3a27d933a0f472378efd82ea971, reversing
changes made to 4d8ed75c72077b5f06f5c3018196f1d972e8ff00.
([`d40faaf`](https://github.com/OZI-Project/OZI/commit/d40faaf64fb6204b66967681bd588c34865eea79))


### 🔨 Updated Scripts

*  create cflite_cron.yml — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`e6945bb`](https://github.com/OZI-Project/OZI/commit/e6945bb2f0f67943ba66b77ab21aaff07819795c))


### 🔒️


* (StepSecurity): apply security best practices — StepSecurity Bot <bot@stepsecurity.io>
([`7a7af80`](https://github.com/OZI-Project/OZI/commit/7a7af80d67ab49cb1660213babb368f7b401d55d))


### 🔨 Updated Configuration

*  update Dockerfile requirements path — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`69b768c`](https://github.com/OZI-Project/OZI/commit/69b768c89e77eaee4c70bd4794f164ff94ba0dd2))

*  add requirements.txt to cflite build — Eden Ross Duff MSc <ozi.project@outlook.com>
([`f26caf4`](https://github.com/OZI-Project/OZI/commit/f26caf428ad612fe09a713a278eae3cf9ae0012f))

*  set language to python for cflite cron jobs — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`fab703e`](https://github.com/OZI-Project/OZI/commit/fab703e2b4e8ef379d6c53b84e832296bc3d5b2c))

*  update cflite_batch.yml allowed-broken-targets-percentage: 25 — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`990a06f`](https://github.com/OZI-Project/OZI/commit/990a06fc9b3911011c09352aba333ad738f8e488))

*  update fuzzer finding in build.sh — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`02be706`](https://github.com/OZI-Project/OZI/commit/02be706440e1003f1ff2d312a6f3324389e979b4))

*  update build.sh — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`2dcea3c`](https://github.com/OZI-Project/OZI/commit/2dcea3c4e2a951406043f8512456b04deb036832))

*  update cflite_batch.yml remove sanitizers — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`868bc43`](https://github.com/OZI-Project/OZI/commit/868bc430c038327a723c151bd9f93895038280b1))

*  add pytest to cflite Dockerfile — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`229251f`](https://github.com/OZI-Project/OZI/commit/229251f6db2a5fd0cd79c9c57a37999e1e1a6f05))

*  update fuzzer path in build.sh — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`fc1d33d`](https://github.com/OZI-Project/OZI/commit/fc1d33db14f1d2e0271953e2dcf553fdde022bd0))

*  update Dockerfile requirements add pyinstaller — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`8c60e94`](https://github.com/OZI-Project/OZI/commit/8c60e941fec6eef2ef833733c658d8c28e4a124c))

*  update cflite build.sh to use OZI wheel build — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`10fb6da`](https://github.com/OZI-Project/OZI/commit/10fb6dad4fa4b652842331ad4748379e9fe8aba2))

*  update cflite Dockerfile to install tox — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`7efb7a1`](https://github.com/OZI-Project/OZI/commit/7efb7a1c7d4ef448df81694e050bec2da37f087c))

*  Update cflite Dockerfile install atheris — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`dfc9472`](https://github.com/OZI-Project/OZI/commit/dfc9472507b0333e4d915573510af15cdeb87488))

*  Update cflite_batch.yml add workflow_dispatch — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`419522e`](https://github.com/OZI-Project/OZI/commit/419522e07fbefa76ee77a22d560c5356a734a59b))

*  create batch fuzzing workflow — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`ecad0f9`](https://github.com/OZI-Project/OZI/commit/ecad0f964122215b7e6a3a72ea85d6c17f2e0439))

*  Update dependency-review.yml — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`e1dfc07`](https://github.com/OZI-Project/OZI/commit/e1dfc0735a9101750168de8948b64bc900916f00))


### Other


* Update Dockerfile — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`681425e`](https://github.com/OZI-Project/OZI/commit/681425e97d1fc69288e425df1d1d87036e1cd3e5))

* Update dependabot.yml — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`a6b34b4`](https://github.com/OZI-Project/OZI/commit/a6b34b492166592ad89a8da93c3176162ae70b3f))

* fix: cflite webui bootstrap.sh location — Eden Ross Duff MSc <ozi.project@outlook.com>
([`3dee973`](https://github.com/OZI-Project/OZI/commit/3dee973c208b8478c03e5dad5912fd399bbb9b34))

* fix: build.sh data path typo — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`4607e7a`](https://github.com/OZI-Project/OZI/commit/4607e7a4cd056d0c300bf9401cbf1a76637cf2b7))

* fix: add ozi_templates and webui bootstrap script to pyinstaller bundle — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`92069ba`](https://github.com/OZI-Project/OZI/commit/92069ba5caca11f2b87959c97e626e01661b99e4))

* fix: correct binary copy location for fuzzers — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`8d10bb9`](https://github.com/OZI-Project/OZI/commit/8d10bb9720aaa5c14a0265c94041a8fb1e5c5772))

* fix: include webui2 shared lib in fuzzer bundles — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`cdd39f2`](https://github.com/OZI-Project/OZI/commit/cdd39f27878bf4c4ce4d1ece622fb2c97e791a8b))

* Update SECURITY.md — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`c846a89`](https://github.com/OZI-Project/OZI/commit/c846a89b7cd35d2b30d7904b53ac71cb2bf40422))

## 1.41.11 (2025-05-26)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/draft from 1.13.4 to 1.13.5

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.13.4 to 1.13.5.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/84f054f0398fe815ac68f4243f6aafb9f5b85e4a...fbf34233ed3d0719d994c2172ac767644c97a2aa)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-version: 1.13.5
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`8a5c7ee`](https://github.com/OZI-Project/OZI/commit/8a5c7eeb99718a85913d558e0add25b7c7381a7b))

*  Bump OZI-Project/release from 1.7.8 to 1.8.3

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.7.8 to 1.8.3.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0bd5001b3e0b5585643aa8f831a4d504126ad411...0a9f46ecacc5bb6a926467a601c8b75bb2deb4ac)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.8.3
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`5b9e802`](https://github.com/OZI-Project/OZI/commit/5b9e802708760997c94f5827e99a4f38523ad883))

*  Bump OZI-Project/publish from 1.13.7 to 1.13.8

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.13.7 to 1.13.8.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/621f1f7d2691300b8a66b0aaa62a4853359daa89...39cc73091234a1dc42b933df3d965318966e65a2)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-version: 1.13.8
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`58a75ac`](https://github.com/OZI-Project/OZI/commit/58a75acb23ab31edb93bb92a139084fa6cd2f4ec))

*  Bump OZI-Project/checkpoint from 1.7.3 to 1.7.4

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.7.3 to 1.7.4.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1b0b165711dca7c852f4c30fbebea96de3747617...40890b7e9f18621e556892606346aebc8292cfa6)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-version: 1.7.4
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`8ea73e8`](https://github.com/OZI-Project/OZI/commit/8ea73e8d271db176d06e1abcde1b2c4356675ae4))

*  Bump ozi-core from 1.19.8 to 1.19.9

Bumps [ozi-core](https://github.com/OZI-Project/ozi-core) from 1.19.8 to 1.19.9.
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/1.19.9/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.19.8...1.19.9)


updated-dependencies:
- dependency-name: ozi-core
  dependency-version: 1.19.9
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`96305c0`](https://github.com/OZI-Project/OZI/commit/96305c0a6ec202ad1f9b2116362bec12061e2013))

*  Bump github/codeql-action from 3.28.17 to 3.28.18

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.28.17 to 3.28.18.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/60168efe1c415ce0f5521ea06d5c2062adbeed1b...ff0a06e83cb2de871e5a09832bc6a81e7276941f)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-version: 3.28.18
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`ba1b7af`](https://github.com/OZI-Project/OZI/commit/ba1b7af064d8913d43dd1b080acc3fb0d9b29119))


### 🔨 Updated Configuration

*  Update dependabot.yml open-pull-requests-limit — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`d44b51e`](https://github.com/OZI-Project/OZI/commit/d44b51efc8bb6266665224c303c134cc232289f0))

*  update fuzzer target names in build.sh — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`c37b4a7`](https://github.com/OZI-Project/OZI/commit/c37b4a78ebc8a8352324baf3636b08aaf8ed4eef))

*  update clusterfuzz docker file to download ozi-core — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`4ad8de3`](https://github.com/OZI-Project/OZI/commit/4ad8de32e66724b88cf33d68c27a7f7b0accf4c3))

*  update ClusterFuzz Dockerfile — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`c329a06`](https://github.com/OZI-Project/OZI/commit/c329a06d4ab549767bf2b022739243a670f3c3e7))

*  create Dockerfile for clusterFuzzLite — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`114a2d1`](https://github.com/OZI-Project/OZI/commit/114a2d1f96c8d1a0c3390e9ff31cc33819967b96))

*  add clusterfuzzlite build.sh — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`888198c`](https://github.com/OZI-Project/OZI/commit/888198c54c137e86787562386722e087e92be675))

*  add .clusterfuzzlite directory — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`0b3764f`](https://github.com/OZI-Project/OZI/commit/0b3764f3c548f5ef7d435e561a51fd83bb5858d1))


### Other


* Update dependabot.yml — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`64914c2`](https://github.com/OZI-Project/OZI/commit/64914c217e485b6f2d0511c09d930ac2cda440e4))

## 1.41.10 (2025-05-15)


### ⬆️ Upgraded Dependencies

*  Bump ozi-core in the python-packages group across 1 directory

Bumps the python-packages group with 1 update in the / directory: [ozi-core](https://github.com/OZI-Project/ozi-core).


Updates `ozi-core` from 1.19.7 to 1.19.8
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/1.19.8/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.19.7...1.19.8)


updated-dependencies:
- dependency-name: ozi-core
  dependency-version: 1.19.8
  dependency-type: direct:production
  update-type: version-update:semver-patch
  dependency-group: python-packages
... — dependabot[bot] <support@github.com>
([`680c15a`](https://github.com/OZI-Project/OZI/commit/680c15a15a246a7b0a9cacbf8c8a0c3433fb1165))

*  Bump OZI-Project/release from 1.7.7 to 1.7.8

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.7.7 to 1.7.8.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/862f61adc1c28749876fe3d09b386b217ca1cbd6...0bd5001b3e0b5585643aa8f831a4d504126ad411)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.7.8
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`5d0ddb8`](https://github.com/OZI-Project/OZI/commit/5d0ddb88b8021e6d3901e568a6375e14427150ba))

*  Bump ozi-core in the python-packages group across 1 directory

Bumps the python-packages group with 1 update in the / directory: [ozi-core](https://github.com/OZI-Project/ozi-core).


Updates `ozi-core` from 1.19.6 to 1.19.7
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/main/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.19.6...1.19.7)


updated-dependencies:
- dependency-name: ozi-core
  dependency-version: 1.19.7
  dependency-type: direct:production
  update-type: version-update:semver-patch
  dependency-group: python-packages
... — dependabot[bot] <support@github.com>
([`df8c936`](https://github.com/OZI-Project/OZI/commit/df8c9365d37bffa4d03d592324932e95f9ffb209))

*  Bump OZI-Project/release from 1.7.6 to 1.7.7

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.7.6 to 1.7.7.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/14c90775d0efe9f0f69a914d05cc9319bfc632a0...862f61adc1c28749876fe3d09b386b217ca1cbd6)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.7.7
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`7bcb83a`](https://github.com/OZI-Project/OZI/commit/7bcb83a1d3fc6dccb59c64ec8d343f0b640e13f3))

*  Bump ozi-core in the python-packages group across 1 directory

Bumps the python-packages group with 1 update in the / directory: [ozi-core](https://github.com/OZI-Project/ozi-core).


Updates `ozi-core` from 1.19.4 to 1.19.5
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/1.19.5/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.19.4...1.19.5)


updated-dependencies:
- dependency-name: ozi-core
  dependency-version: 1.19.5
  dependency-type: direct:production
  update-type: version-update:semver-patch
  dependency-group: python-packages
... — dependabot[bot] <support@github.com>
([`c4ba889`](https://github.com/OZI-Project/OZI/commit/c4ba889668f350d3e623f4dca877b9c1c66c9052))

*  Bump OZI-Project/release from 1.7.4 to 1.7.6

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.7.4 to 1.7.6.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/7b3bc0282c162a771c69e91decca3e3ba792e221...14c90775d0efe9f0f69a914d05cc9319bfc632a0)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.7.6
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`ba344bf`](https://github.com/OZI-Project/OZI/commit/ba344bf8c7257075fa130a16d7b0c915ccfdb865))

*  Bump OZI-Project/release from 1.6.7 to 1.7.4

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.6.7 to 1.7.4.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/10a57d8906c4969547cfaa3395eb53facb8a5041...7b3bc0282c162a771c69e91decca3e3ba792e221)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.7.4
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`c711d76`](https://github.com/OZI-Project/OZI/commit/c711d76153feb00b220db9e34d3eabae7f8c1fff))

*  Bump actions/dependency-review-action from 4.7.0 to 4.7.1

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.7.0 to 4.7.1.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/38ecb5b593bf0eb19e335c03f97670f792489a8b...da24556b548a50705dd671f47852072ea4c105d9)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-version: 4.7.1
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`67ff7f4`](https://github.com/OZI-Project/OZI/commit/67ff7f4540f22d1c5b8e29204610cc62cdc5f4a3))

*  Bump ozi-core in the python-packages group across 1 directory

Bumps the python-packages group with 1 update in the / directory: [ozi-core](https://github.com/OZI-Project/ozi-core).


Updates `ozi-core` from 1.19.3 to 1.19.4
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/1.19.4/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.19.3...1.19.4)


updated-dependencies:
- dependency-name: ozi-core
  dependency-version: 1.19.4
  dependency-type: direct:production
  update-type: version-update:semver-patch
  dependency-group: python-packages
... — dependabot[bot] <support@github.com>
([`1947d71`](https://github.com/OZI-Project/OZI/commit/1947d71469a12e0b52969b419cd912b0dc70a7b2))


### 🐛 Fixed Bugs

*  update release args — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`0c3882e`](https://github.com/OZI-Project/OZI/commit/0c3882ed3a7e0571ca8f0851e0d80f49a74e26b3))

*  fix tasks using the --ozi internal default — Eden Ross Duff MSc <ozi.project@outlook.com>
([`5c1a04d`](https://github.com/OZI-Project/OZI/commit/5c1a04dc2e51a1c7406f93319e923b775e3bb7cf))

## 1.41.9 (2025-05-13)


### 🐛 Fixed Bugs

*  activate invoke env — Eden Ross Duff MSc <ozi.project@outlook.com>
([`52b482c`](https://github.com/OZI-Project/OZI/commit/52b482c912e3f17ace2f3cc1b121d0a5eb5cf173))

*  ``setup`` invoke task now activates a virtual environment — Eden Ross Duff MSc <ozi.project@outlook.com>
([`e87b8c2`](https://github.com/OZI-Project/OZI/commit/e87b8c2fb2b729911bb3e276a1407dda90e25959))


### ✏️ Corrected Typos

*  fix not needed f-string — Eden Ross Duff MSc <ozi.project@outlook.com>
([`7a5b4ed`](https://github.com/OZI-Project/OZI/commit/7a5b4ed79c47d9682ec9d2ffed4386647a7f2ac1))

## 1.41.8 (2025-05-12)


### 🐛 Fixed Bugs

*  revert add ``--system`` arg to uv pip — Eden Ross Duff MSc <ozi.project@outlook.com>
([`95f34cd`](https://github.com/OZI-Project/OZI/commit/95f34cd2e8d10e3e6dab54ceed76af6625ec9d43))

## 1.41.7 (2025-05-12)


### ⬆️ Upgraded Dependencies

*  Update ozi-build[core,uv] requirement

Updates the requirements on [ozi-build[core,uv]](https://github.com/OZI-Project/OZI.build) to permit the latest version.

Updates `ozi-build[core,uv]` to 2.1.0
- [Release notes](https://github.com/OZI-Project/OZI.build/releases)
- [Changelog](https://github.com/OZI-Project/OZI.build/blob/master/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/OZI.build/compare/2.0.7...2.1.0)


updated-dependencies:
- dependency-name: ozi-build[core,uv]
  dependency-version: 2.1.0
  dependency-type: direct:production
  dependency-group: python-packages
... — dependabot[bot] <support@github.com>
([`7706b34`](https://github.com/OZI-Project/OZI/commit/7706b34c7c90eeb203dba2fe721c9869120fa7ca))

*  Bump OZI-Project/release from 1.6.5 to 1.6.7

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.6.5 to 1.6.7.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/36fe15c47185192e9cf5df744a8d1eb679676e22...10a57d8906c4969547cfaa3395eb53facb8a5041)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.6.7
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`5f3eb0c`](https://github.com/OZI-Project/OZI/commit/5f3eb0cdba831062f032bd3c18f64cbff18ca0b7))

*  Bump OZI-Project/draft from 1.13.3 to 1.13.4

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.13.3 to 1.13.4.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/68b9a0082a1e1fafa581b7cb6488254df5f47a39...84f054f0398fe815ac68f4243f6aafb9f5b85e4a)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-version: 1.13.4
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`1d7992a`](https://github.com/OZI-Project/OZI/commit/1d7992a4704fd91e71e3717ef57c40506f69ed9e))

*  Bump OZI-Project/checkpoint from 1.7.2 to 1.7.3

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.7.2 to 1.7.3.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/ac9e45ece7eecacce1a9acb44ae4443985fe310b...1b0b165711dca7c852f4c30fbebea96de3747617)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-version: 1.7.3
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`36cdc95`](https://github.com/OZI-Project/OZI/commit/36cdc957a4fec1266207fc4d11fc36f86d6b336a))

*  Bump OZI-Project/publish from 1.13.5 to 1.13.7

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.13.5 to 1.13.7.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/2db0b4c8cd2073e42b9aa5f399020b78cfee31e0...621f1f7d2691300b8a66b0aaa62a4853359daa89)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-version: 1.13.7
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`1e4dce4`](https://github.com/OZI-Project/OZI/commit/1e4dce49fc6c6a0fe0895f6366f0b518db1a0ada))


### 🐛 Fixed Bugs

*  add ``--system`` arg to uv pip if CI env is detected — Eden Ross Duff MSc <ozi.project@outlook.com>
([`3672eb0`](https://github.com/OZI-Project/OZI/commit/3672eb0d32cfaab690d16e633c4ece6d02ec38ef))


### Other


* perf(tasks): add ``--wheel-sign-token`` arg to release task — Eden Ross Duff MSc <ozi.project@outlook.com>
([`ce1fa0c`](https://github.com/OZI-Project/OZI/commit/ce1fa0cc218d61fa0c39bb5c91b3b66864172f95))

## 1.41.6 (2025-05-12)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/draft from 1.13.2 to 1.13.3

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.13.2 to 1.13.3.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/92712f8a95c9cb1fa00731f9a29edeb1cd9799b8...68b9a0082a1e1fafa581b7cb6488254df5f47a39)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-version: 1.13.3
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`27b1560`](https://github.com/OZI-Project/OZI/commit/27b15609d9e04ed9009b54540ce0ba925f8d16af))

*  Bump actions/dependency-review-action from 4.6.0 to 4.7.0

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.6.0 to 4.7.0.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/ce3cf9537a52e8119d91fd484ab5b8a807627bf8...38ecb5b593bf0eb19e335c03f97670f792489a8b)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-version: 4.7.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`0290e06`](https://github.com/OZI-Project/OZI/commit/0290e0688b09fdf4e2b59cda94e3f9170ae55710))

*  Bump OZI-Project/publish from 1.13.4 to 1.13.5

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.13.4 to 1.13.5.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/8297bf52054be7cae27ab2770e08d96676fd3162...2db0b4c8cd2073e42b9aa5f399020b78cfee31e0)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-version: 1.13.5
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`5054ab5`](https://github.com/OZI-Project/OZI/commit/5054ab5131cf70810111dd8aec2d276b90a6914c))


### 🔨 Updated Configuration

* add ``--wheel-sign-token`` arg to release task (#1603) — Eden Ross Duff MSc <ozi.project@outlook.com>
([`137f603`](https://github.com/OZI-Project/OZI/commit/137f60370b24cc6495206d790a4d3abf58776288))

## 1.41.5 (2025-05-03)


### 🐛 Fixed Bugs

*  fix freethreaded support — Eden Ross Duff MSc <ozi.project@outlook.com>
([`33ff1a5`](https://github.com/OZI-Project/OZI/commit/33ff1a536b0c24963fc5b125e58f087f68553b3e))

## 1.41.4 (2025-05-03)


### ✨ Improved Performance

* support broadened to included Python 3.9 — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`25900f7`](https://github.com/OZI-Project/OZI/commit/25900f7e822c6a2871762de1e3f158d912704039))

## 1.41.3 (2025-05-03)


### 🐛 Fixed Bugs

*  fix entry_point script — Eden Ross Duff MSc <ozi.project@outlook.com>
([`9f5eefd`](https://github.com/OZI-Project/OZI/commit/9f5eefdc461e6a1a76e329a221c8a4e105d6812a))

## 1.41.2 (2025-05-03)


### ⬆️ Upgraded Dependencies

*  ozi-core==1.19.3 — Eden Ross Duff MSc <ozi.project@outlook.com>
([`852b606`](https://github.com/OZI-Project/OZI/commit/852b606238d1e5e328e8ce5f5fbe335575cc4a59))

*  Bump ozi-core in the python-packages group across 1 directory

Bumps the python-packages group with 1 update in the / directory: [ozi-core](https://github.com/OZI-Project/ozi-core).


Updates `ozi-core` from 1.19.1 to 1.19.2
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/main/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.19.1...1.19.2)


updated-dependencies:
- dependency-name: ozi-core
  dependency-version: 1.19.2
  dependency-type: direct:production
  update-type: version-update:semver-patch
  dependency-group: python-packages
... — dependabot[bot] <support@github.com>
([`0acfc3b`](https://github.com/OZI-Project/OZI/commit/0acfc3b7eb152f51108677812a30dd59eeeb967f))


### 🐛 Fixed Bugs

*  fix main entry_point — Eden Ross Duff MSc <ozi.project@outlook.com>
([`84d2248`](https://github.com/OZI-Project/OZI/commit/84d2248f40055f5bb92f61527809cf48f276166f))

## 1.41.1 (2025-05-03)


### ⬆️ Upgraded Dependencies

*  Bump ozi-core in the python-packages group across 1 directory

Bumps the python-packages group with 1 update in the / directory: [ozi-core](https://github.com/OZI-Project/ozi-core).


Updates `ozi-core` from 1.19.0 to 1.19.1
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/main/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.19.0...1.19.1)


updated-dependencies:
- dependency-name: ozi-core
  dependency-version: 1.19.1
  dependency-type: direct:production
  update-type: version-update:semver-patch
  dependency-group: python-packages
... — dependabot[bot] <support@github.com>
([`9aae41b`](https://github.com/OZI-Project/OZI/commit/9aae41b25596a1f9dffb4ba8e6bb43164de8675a))


### Other


* 🚨 fix lint — Eden Ross Duff MSc <ozi.project@outlook.com>
([`50c455b`](https://github.com/OZI-Project/OZI/commit/50c455b834c910e14ebda17f3bc5038bdeb00549))

* 🚚: move main CLI to ozi-core — Eden Ross Duff MSc <ozi.project@outlook.com>
([`2baaf8b`](https://github.com/OZI-Project/OZI/commit/2baaf8bc09158b3bbacb6437e6b0e594fad76a8a))

## 1.41.0 (2025-05-02)


### 🔒️


* update SECURITY.md — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`cf21dd2`](https://github.com/OZI-Project/OZI/commit/cf21dd20a71578ac83e62ed1f0c1efdb773f4c76))

## 1.40.0 (2025-05-02)


### ✨ Implemented Features

*  force minor version bump — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`e97259d`](https://github.com/OZI-Project/OZI/commit/e97259d806fee7db91ec018d9541303b8e26bbe3))


### Other


* feat: force minor bump — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`ff67c62`](https://github.com/OZI-Project/OZI/commit/ff67c622b174c1a71a03349a868487091bace5f5))

## 1.39.3 (2025-05-02)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/checkpoint from 1.7.1 to 1.7.2

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.7.1 to 1.7.2.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/dbe6f38e4bb6ed375129d0cf718b6d6968340a13...ac9e45ece7eecacce1a9acb44ae4443985fe310b)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-version: 1.7.2
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`63cd675`](https://github.com/OZI-Project/OZI/commit/63cd67554a02c619ff18effaa3c4d26c2e082546))

*  Bump OZI-Project/publish from 1.13.3 to 1.13.4

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.13.3 to 1.13.4.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/df67e9c0f38d22c078568807d2eefed313340e2d...8297bf52054be7cae27ab2770e08d96676fd3162)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-version: 1.13.4
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`d318554`](https://github.com/OZI-Project/OZI/commit/d318554229c87cc5878694b1515d42bc36fcac3c))

*  Bump OZI-Project/release from 1.6.4 to 1.6.5

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.6.4 to 1.6.5.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0b2ba9981ee9eea47a358c0d70c5b3764a61b88c...36fe15c47185192e9cf5df744a8d1eb679676e22)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.6.5
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`052794c`](https://github.com/OZI-Project/OZI/commit/052794ceb62130a97f70cf091eb59b34b2c4adf1))

*  Bump ozi-core in the python-packages group across 1 directory

Bumps the python-packages group with 1 update in the / directory: [ozi-core](https://github.com/OZI-Project/ozi-core).


Updates `ozi-core` from 1.18.3 to 1.19.0
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/main/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.18.3...1.19.0)


updated-dependencies:
- dependency-name: ozi-core
  dependency-version: 1.19.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
  dependency-group: python-packages
... — dependabot[bot] <support@github.com>
([`1097d1e`](https://github.com/OZI-Project/OZI/commit/1097d1e97bac9d4bd8187e9c4bd66cbeb2fa1f67))

*  Bump OZI-Project/draft from 1.13.1 to 1.13.2

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.13.1 to 1.13.2.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/ed08d630ad83cfd14061b78cf695c20eb51984a5...92712f8a95c9cb1fa00731f9a29edeb1cd9799b8)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-version: 1.13.2
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`7604151`](https://github.com/OZI-Project/OZI/commit/76041511488c3c09bc386f92cae8d3fb0eaae37d))

*  Bump github/codeql-action from 3.28.16 to 3.28.17

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.28.16 to 3.28.17.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/28deaeda66b76a05916b6923827895f2b14ab387...60168efe1c415ce0f5521ea06d5c2062adbeed1b)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-version: 3.28.17
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`d062a8f`](https://github.com/OZI-Project/OZI/commit/d062a8fba8981a17e934900c006d4becdb77f084))

## 1.39.2 (2025-04-30)

## 1.39.1 (2025-04-28)

## 1.39.0 (2025-04-27)


### ⬆️ Upgraded Dependencies

*  Bump ozi-core in the python-packages group across 1 directory

Bumps the python-packages group with 1 update in the / directory: [ozi-core](https://github.com/OZI-Project/ozi-core).


Updates `ozi-core` from 1.18.3 to 1.18.4
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/1.18.4/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.18.3...1.18.4)


updated-dependencies:
- dependency-name: ozi-core
  dependency-version: 1.18.4
  dependency-type: direct:production
  update-type: version-update:semver-patch
  dependency-group: python-packages
... — dependabot[bot] <support@github.com>
([`a352571`](https://github.com/OZI-Project/OZI/commit/a35257170871b232ce2cd89d10c50379146a1409))

*  Bump ozi-core in the python-packages group across 1 directory

Bumps the python-packages group with 1 update in the / directory: [ozi-core](https://github.com/OZI-Project/ozi-core).


Updates `ozi-core` from 1.18.2 to 1.18.3
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/1.18.3/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.18.2...1.18.3)


updated-dependencies:
- dependency-name: ozi-core
  dependency-version: 1.18.3
  dependency-type: direct:production
  update-type: version-update:semver-patch
  dependency-group: python-packages
... — dependabot[bot] <support@github.com>
([`f051b16`](https://github.com/OZI-Project/OZI/commit/f051b16893c60709c90ad8fa8e989b8692308d4a))

*  Bump OZI-Project/publish from 1.13.1 to 1.13.3

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.13.1 to 1.13.3.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/26f38aa55610d51537ae92c1e89464a18959ba90...df67e9c0f38d22c078568807d2eefed313340e2d)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-version: 1.13.3
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`80893f0`](https://github.com/OZI-Project/OZI/commit/80893f01b42dcfca4afb8d7c9dacf006ffcef76b))

*  Bump OZI-Project/checkpoint from 1.7.0 to 1.7.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.7.0 to 1.7.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/bec3d96cd1cb3bbce358fbeabc70eb25482bd3bf...dbe6f38e4bb6ed375129d0cf718b6d6968340a13)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-version: 1.7.1
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`7d98ffd`](https://github.com/OZI-Project/OZI/commit/7d98ffddcfb2ea8ed2617549c3cddc5862e34c0f))

*  Bump OZI-Project/release from 1.5.0 to 1.6.4

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.5.0 to 1.6.4.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/924761bcd1ad9c77bbc34363118b2cee4334b8a5...0b2ba9981ee9eea47a358c0d70c5b3764a61b88c)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.6.4
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`5681b51`](https://github.com/OZI-Project/OZI/commit/5681b51d6eec9d283c5c92409eaebc584f0d145b))

*  Bump github/codeql-action from 3.28.15 to 3.28.16

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.28.15 to 3.28.16.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/45775bd8235c68ba998cffa5171334d58593da47...28deaeda66b76a05916b6923827895f2b14ab387)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-version: 3.28.16
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`e653d7b`](https://github.com/OZI-Project/OZI/commit/e653d7bdc673b0a9d53b51d3b0a9b70c0eb95a0c))

*  Bump step-security/harden-runner from 2.11.1 to 2.12.0

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.11.1 to 2.12.0.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/c6295a65d1254861815972266d5933fd6e532bdf...0634a2670c59f64b4a01f0f96f84700a4088b9f0)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-version: 2.12.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`2a50a32`](https://github.com/OZI-Project/OZI/commit/2a50a32107cfcfc03bb96065cd5d9359fa70fe84))

*  Bump the python-packages group across 1 directory with 2 updates

Updates the requirements on [ozi-core](https://github.com/OZI-Project/ozi-core) and [ozi-build[core,uv]](https://github.com/OZI-Project/OZI.build) to permit the latest version.

Updates `ozi-core` from 1.17.6 to 1.18.0
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/1.18.0/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.17.6...1.18.0)

Updates `ozi-build[core,uv]` to 2.0.6
- [Release notes](https://github.com/OZI-Project/OZI.build/releases)
- [Changelog](https://github.com/OZI-Project/OZI.build/blob/master/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/OZI.build/compare/1.13.0...2.0.6)


updated-dependencies:
- dependency-name: ozi-core
  dependency-version: 1.18.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
  dependency-group: python-packages
- dependency-name: ozi-build[core,uv]
  dependency-version: 2.0.6
  dependency-type: direct:production
  dependency-group: python-packages
... — dependabot[bot] <support@github.com>
([`a21e834`](https://github.com/OZI-Project/OZI/commit/a21e834ada4dd384be61683109c987143a10c46c))


### 🐛 Fixed Bugs

*  fix tox test env setup commands — Eden Ross Duff MSc <ozi.project@outlook.com>
([`9ce6c21`](https://github.com/OZI-Project/OZI/commit/9ce6c2143a726b85ad458943190c1a0ed0167a09))

*  skip running patch on OZI repo — Eden Ross Duff MSc <ozi.project@outlook.com>
([`794af69`](https://github.com/OZI-Project/OZI/commit/794af69722871232f2ee25a4d07b8522811edcdd))

*  build requires meson<1.8 — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`256a193`](https://github.com/OZI-Project/OZI/commit/256a1930744aa641474f865e3a90b453df041f3f))

*  fix meson>1.8 test suite options not being enabled — Eden Ross Duff MSc <ozi.project@outlook.com>
([`a8a7758`](https://github.com/OZI-Project/OZI/commit/a8a775840172c17a29b1b75b246d55a78e5544c2))

*  fix build metadata ``requires-external`` — Eden Ross Duff MSc <ozi.project@outlook.com>
([`f484dac`](https://github.com/OZI-Project/OZI/commit/f484dac0966b76badf7557ad5382debefc2f7ad6))

*  fallback to uv in tasks for build — Eden Ross Duff MSc <ozi.project@outlook.com>
([`8875634`](https://github.com/OZI-Project/OZI/commit/8875634efc6a08169d25f5e760306e7956f93872))


### 🔨 Updated Scripts

*  add invoke feature option — Eden Ross Duff MSc <ozi.project@outlook.com>
([`9ff03bb`](https://github.com/OZI-Project/OZI/commit/9ff03bbcd2e6faa60a8b4f3030cce2c48d039aef))

*  fix missing commas — Eden Ross Duff MSc <ozi.project@outlook.com>
([`0e7310b`](https://github.com/OZI-Project/OZI/commit/0e7310bb2d0b59eba5b73d33de90d9b7f34e4680))

*  update dist-workflow.yml to use dist environment — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`f7a2c74`](https://github.com/OZI-Project/OZI/commit/f7a2c74630e28bd3741e2f97c353971483aa65ad))

*  run build task with warn=True — Eden Ross Duff MSc <ozi.project@outlook.com>
([`cf12b51`](https://github.com/OZI-Project/OZI/commit/cf12b51adaba8865f9f749e14f31b07ad2d145e5))

*  simplify build task logic — Eden Ross Duff MSc <ozi.project@outlook.com>
([`91620b4`](https://github.com/OZI-Project/OZI/commit/91620b4d970abde619d79994324be22740adfc75))

*  clean up scripts and meson.build — Eden Ross Duff MSc <ozi.project@outlook.com>
([`4ecb74f`](https://github.com/OZI-Project/OZI/commit/4ecb74f93d1796a8fcde590bc5fae9a887d8e951))


### 📝 Updated Documentation

* update SECURITY.md — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`3f3fa09`](https://github.com/OZI-Project/OZI/commit/3f3fa09f96b49dae6c0d955b02fdf2c9e6320d91))


### ✏️ Corrected Typos

*  remove meson<1.8 from build-system requires — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`ea642ab`](https://github.com/OZI-Project/OZI/commit/ea642abc26e93ecd7a081c984767e9270161c40c))

*  fix typo — Eden Ross Duff MSc <ozi.project@outlook.com>
([`f1eb8b8`](https://github.com/OZI-Project/OZI/commit/f1eb8b8181065de2a70967a5d1314e12cd00ff6c))


### 🔨 Updated Configuration

*  add cdn01.quay.io endpoint to release — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`2105f30`](https://github.com/OZI-Project/OZI/commit/2105f3059b74c6ec9a4a75e7fcf17c9b304fbcd9))


### Other


* fix: skipped build task — Eden Ross Duff MSc <ozi.project@outlook.com>
([`b32dd71`](https://github.com/OZI-Project/OZI/commit/b32dd7181ded3915ae9fcc87ef790a6f2dec04d3))

* chore: update pyproject — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`692d715`](https://github.com/OZI-Project/OZI/commit/692d7159758e64e8a22f7be45340da21cd567e38))

* feat: OZI.build 2.0 — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`75edaef`](https://github.com/OZI-Project/OZI/commit/75edaefa6188fefae68a68bee7c8de3afa200102))

* build: use Quansight-Labs/cffi fork for freethreading support — Eden Ross Duff MSc <ozi.project@outlook.com>
([`1163415`](https://github.com/OZI-Project/OZI/commit/1163415ec4684914fbf4622cc04a34c735252892))

* build: use Quansight-Labs/cffi fork for freethreading support — Eden Ross Duff MSc <ozi.project@outlook.com>
([`c9df5b9`](https://github.com/OZI-Project/OZI/commit/c9df5b9ffd13ebdc5c84d166b36434341a5b13e3))

## 1.38.4 (2025-04-15)


### ⬆️ Upgraded Dependencies

*  Update hypothesis[cli,codemods,ghostwriter] requirement

Updates the requirements on [hypothesis[cli,codemods,ghostwriter]](https://github.com/HypothesisWorks/hypothesis) to permit the latest version.

Updates `hypothesis[cli,codemods,ghostwriter]` to 6.131.0
- [Release notes](https://github.com/HypothesisWorks/hypothesis/releases)
- [Commits](https://github.com/HypothesisWorks/hypothesis/compare/hypothesis-python-6.130.0...hypothesis-python-6.131.0)


updated-dependencies:
- dependency-name: hypothesis[cli,codemods,ghostwriter]
  dependency-version: 6.131.0
  dependency-type: direct:production
  dependency-group: python-packages
... — dependabot[bot] <support@github.com>
([`133b44c`](https://github.com/OZI-Project/OZI/commit/133b44cf51fcedd211a54096cb2c1b1bef5cf282))


### 🔥 Deleted Code or Files

* delete .python-version — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`4cbcb11`](https://github.com/OZI-Project/OZI/commit/4cbcb11cf0e5f1ad20fa8c5f1c6b089549bde856))


### Other


* chore: upgrade ozi-core==1.17.3 to ozi-core==1.17.6 — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`61047de`](https://github.com/OZI-Project/OZI/commit/61047de6c8cc2dcb473b97e3b27a3312f7aece1c))

## 1.38.3 (2025-04-09)

## 1.38.2 (2025-04-04)

## 1.38.1 (2025-04-03)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.28.13 to 3.28.15

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.28.13 to 3.28.15.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/1b549b9259bda1cb5ddde3b41741a82a2d15a841...45775bd8235c68ba998cffa5171334d58593da47)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-version: 3.28.15
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`c5e0e54`](https://github.com/OZI-Project/OZI/commit/c5e0e5403a69b984cbae00d5e8483121889ea831))

*  ozi-core==1.17.3 — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`f5cc0fe`](https://github.com/OZI-Project/OZI/commit/f5cc0fe2a4da76ab7adc377eb82a116212ceeb89))

*  ozi-core==1.17.1 — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`e7052cc`](https://github.com/OZI-Project/OZI/commit/e7052cc65308bb90f34bcb6ab33b4c704cbb1e4c))

*  Bump OZI-Project/checkpoint from 1.6.0 to 1.7.0

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.6.0 to 1.7.0.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/175eae79f299d6dbad474024b5f791368bd5de85...bec3d96cd1cb3bbce358fbeabc70eb25482bd3bf)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-version: 1.7.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`6204a72`](https://github.com/OZI-Project/OZI/commit/6204a726a725d1ea10ebafe7146c8c42a8100e0b))


### 🔨 Updated Configuration

*  add node to external deps — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`e3402c4`](https://github.com/OZI-Project/OZI/commit/e3402c400a1b819cc876284aa52ef0ee83f6f687))


### Other


* fix: create .python-version to workaround dependabot issue — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`968b11e`](https://github.com/OZI-Project/OZI/commit/968b11e48e1fbd865f493d7bc3511b898e848cc5))

* Update dependabot.yml — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`be9b486`](https://github.com/OZI-Project/OZI/commit/be9b486306da34ddaf1d80062c5492d5182e9fc9))

* Update pyproject.toml — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`6a2b5a7`](https://github.com/OZI-Project/OZI/commit/6a2b5a712154894a6bf0d2a01f0b7ded90fa51cf))

* Update SECURITY.md — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`c028554`](https://github.com/OZI-Project/OZI/commit/c0285543030868c9f623eb6e25dec4733e554887))

## 1.38.0 (2025-04-03)


### ⬆️ Upgraded Dependencies

*  ozi-core==1.17.0 — Eden Ross Duff MSc <ozi.project@outlook.com>
([`f3d2d9c`](https://github.com/OZI-Project/OZI/commit/f3d2d9cb6d6b787b7ab1102ff59d3cb4f1c36dea))

*  Update ozi-build[core,uv] requirement


updated-dependencies:
- dependency-name: ozi-build[core,uv]
  dependency-version: 1.13.0
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`0220316`](https://github.com/OZI-Project/OZI/commit/02203161d916b0a84f01b98a658537bd6fbe5d93))

*  Bump OZI-Project/publish from 1.13.0 to 1.13.1

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.13.0 to 1.13.1.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/dedb3175dc5d4bb29bcee5a7b659ad7f42c5c68c...26f38aa55610d51537ae92c1e89464a18959ba90)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-version: 1.13.1
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`e6a4a33`](https://github.com/OZI-Project/OZI/commit/e6a4a33caf49df015cd17f54455a55470838a194))

*  Bump OZI-Project/release from 1.4.0 to 1.5.0

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.4.0 to 1.5.0.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/bfb9d90fbd2af52d511a9e08306d1b787b8dcfca...924761bcd1ad9c77bbc34363118b2cee4334b8a5)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.5.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`764e3ef`](https://github.com/OZI-Project/OZI/commit/764e3ef00f5830de15f2945f1a52996b84b2d67c))

*  Bump OZI-Project/draft from 1.13.0 to 1.13.1

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.13.0 to 1.13.1.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/917b6a5d9a39df52cbdc3a15565c58dfb9b38a10...ed08d630ad83cfd14061b78cf695c20eb51984a5)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-version: 1.13.1
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`19e0da8`](https://github.com/OZI-Project/OZI/commit/19e0da8f56d5d9ac0f0219c5749944db45919619))

*  Bump step-security/harden-runner from 2.11.0 to 2.11.1

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.11.0 to 2.11.1.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/4d991eb9b905ef189e4c376166672c3f2f230481...c6295a65d1254861815972266d5933fd6e532bdf)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`53295e6`](https://github.com/OZI-Project/OZI/commit/53295e60dd744f9358f40dc993dcd4a6abed813f))

*  Bump actions/dependency-review-action from 4.5.0 to 4.6.0

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.5.0 to 4.6.0.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/3b139cfc5fae8b618d3eae3675e383bb1769c019...ce3cf9537a52e8119d91fd484ab5b8a807627bf8)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`f50094f`](https://github.com/OZI-Project/OZI/commit/f50094ffc2a046599bf2bd1e0a072eeaafddd661))

*  Update pytest-cov requirement in /ozi/test/pytest

Updates the requirements on [pytest-cov](https://github.com/pytest-dev/pytest-cov) to permit the latest version.
- [Changelog](https://github.com/pytest-dev/pytest-cov/blob/master/CHANGELOG.rst)
- [Commits](https://github.com/pytest-dev/pytest-cov/compare/v6.0.0...v6.1.0)


updated-dependencies:
- dependency-name: pytest-cov
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`933dcf1`](https://github.com/OZI-Project/OZI/commit/933dcf155ee5c328ce04c02df7854a7753c38610))

*  Update coverage[toml] requirement in /ozi/test/coverage

Updates the requirements on [coverage[toml]](https://github.com/nedbat/coveragepy) to permit the latest version.
- [Release notes](https://github.com/nedbat/coveragepy/releases)
- [Changelog](https://github.com/nedbat/coveragepy/blob/master/CHANGES.rst)
- [Commits](https://github.com/nedbat/coveragepy/compare/7.7.0...7.8.0)


updated-dependencies:
- dependency-name: coverage[toml]
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`97531fd`](https://github.com/OZI-Project/OZI/commit/97531fd71dbacaf9a63ea834ea9b279e46ea094e))

*  Update flake8 requirement in /ozi/lint/flake8

Updates the requirements on [flake8](https://github.com/pycqa/flake8) to permit the latest version.
- [Commits](https://github.com/pycqa/flake8/compare/7.1.0...7.2.0)


updated-dependencies:
- dependency-name: flake8
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`73b3cf3`](https://github.com/OZI-Project/OZI/commit/73b3cf3ecf176c4b6ddf1197a929ea0175e71e7b))

*  Bump github/codeql-action from 3.28.12 to 3.28.13

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.28.12 to 3.28.13.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/5f8171a638ada777af81d42b55959a643bb29017...1b549b9259bda1cb5ddde3b41741a82a2d15a841)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`c6f8e61`](https://github.com/OZI-Project/OZI/commit/c6f8e611158444208df79fa5482337391d3dd22e))

*  Update pytest-asyncio requirement in /ozi/test/pytest

Updates the requirements on [pytest-asyncio](https://github.com/pytest-dev/pytest-asyncio) to permit the latest version.
- [Release notes](https://github.com/pytest-dev/pytest-asyncio/releases)
- [Commits](https://github.com/pytest-dev/pytest-asyncio/compare/v0.25.3...v0.26.0)


updated-dependencies:
- dependency-name: pytest-asyncio
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`662fcdb`](https://github.com/OZI-Project/OZI/commit/662fcdb6edcb6fc8c4e23fe2217d0837863907e6))


### ✨ Implemented Features

*  OZI.build 1.13

Fixes deprecated dist filename format in tarballs. — Eden Ross Duff MSc <ozi.project@outlook.com>
([`63d19db`](https://github.com/OZI-Project/OZI/commit/63d19dbdb8df2917290ad124b502652e1567522c))

## 1.37.0 (2025-03-22)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/checkpoint from 1.5.5 to 1.6.0

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.5.5 to 1.6.0.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/f14cac563125e34d106b3a1e0ddb2773062953e5...175eae79f299d6dbad474024b5f791368bd5de85)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`ca9b835`](https://github.com/OZI-Project/OZI/commit/ca9b83575de032dff48125f1ed433aa106fb75a6))

*  Bump OZI-Project/release from 1.3.4 to 1.4.0

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.3.4 to 1.4.0.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/204e7f8af3396d1a4d77afb66ead74b0804ae058...bfb9d90fbd2af52d511a9e08306d1b787b8dcfca)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`dc23c99`](https://github.com/OZI-Project/OZI/commit/dc23c9920ae6a0a15a005160c2172184e85f4031))

*  Bump OZI-Project/publish from 1.12.0 to 1.13.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.12.0 to 1.13.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/63a52d7e0f5abc79d3fd3f7ecfa7f26efd1c8c69...dedb3175dc5d4bb29bcee5a7b659ad7f42c5c68c)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`121c6dc`](https://github.com/OZI-Project/OZI/commit/121c6dcd391e8b122c3121fc0fec9c9c05bac875))

*  Bump OZI-Project/draft from 1.12.0 to 1.13.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.12.0 to 1.13.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/cbedf57c7d2529c093518f0652cf4f7324cb3755...917b6a5d9a39df52cbdc3a15565c58dfb9b38a10)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`67a861e`](https://github.com/OZI-Project/OZI/commit/67a861ef0b8ab575440f520f129b48302acab9f0))

*  Bump actions/upload-artifact from 4.6.1 to 4.6.2

Bumps [actions/upload-artifact](https://github.com/actions/upload-artifact) from 4.6.1 to 4.6.2.
- [Release notes](https://github.com/actions/upload-artifact/releases)
- [Commits](https://github.com/actions/upload-artifact/compare/4cec3d8aa04e39d1a68397de0c4cd6fb9dce8ec1...ea165f8d65b6e75b540449e92b4886f43607fa02)


updated-dependencies:
- dependency-name: actions/upload-artifact
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`583d861`](https://github.com/OZI-Project/OZI/commit/583d8617dd8c9c860e75cdebfd447c2b287f02ce))

*  Bump github/codeql-action from 3.28.11 to 3.28.12

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.28.11 to 3.28.12.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/6bb031afdd8eb862ea3fc1848194185e076637e5...5f8171a638ada777af81d42b55959a643bb29017)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`76ac5b7`](https://github.com/OZI-Project/OZI/commit/76ac5b7750393aafeff5d253945c8a6e72f46bac))

*  Update hypothesis[cli,codemods,ghostwriter] requirement

Updates the requirements on [hypothesis[cli,codemods,ghostwriter]](https://github.com/HypothesisWorks/hypothesis) to permit the latest version.
- [Release notes](https://github.com/HypothesisWorks/hypothesis/releases)
- [Commits](https://github.com/HypothesisWorks/hypothesis/compare/hypothesis-python-6.129.0...hypothesis-python-6.130.0)


updated-dependencies:
- dependency-name: hypothesis[cli,codemods,ghostwriter]
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`c27caa7`](https://github.com/OZI-Project/OZI/commit/c27caa7470bbd607f946a9410efe850773ce98bc))

*  Update coverage[toml] requirement in /ozi/test/coverage

Updates the requirements on [coverage[toml]](https://github.com/nedbat/coveragepy) to permit the latest version.
- [Release notes](https://github.com/nedbat/coveragepy/releases)
- [Changelog](https://github.com/nedbat/coveragepy/blob/master/CHANGES.rst)
- [Commits](https://github.com/nedbat/coveragepy/compare/7.6.0...7.7.0)


updated-dependencies:
- dependency-name: coverage[toml]
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`3655888`](https://github.com/OZI-Project/OZI/commit/3655888e26050219e71338fe1c2fff82d4ecc408))

*  Update python-semantic-release requirement

Updates the requirements on [python-semantic-release](https://github.com/python-semantic-release/python-semantic-release) to permit the latest version.
- [Release notes](https://github.com/python-semantic-release/python-semantic-release/releases)
- [Changelog](https://github.com/python-semantic-release/python-semantic-release/blob/master/CHANGELOG.rst)
- [Commits](https://github.com/python-semantic-release/python-semantic-release/compare/v9.20...v9.21)


updated-dependencies:
- dependency-name: python-semantic-release
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`ac5d7c5`](https://github.com/OZI-Project/OZI/commit/ac5d7c589756dd9df8eb20da089026a4fa587f6c))

*  Bump github/codeql-action from 3.28.9 to 3.28.11

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.28.9 to 3.28.11.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/9e8d0789d4a0fa9ceb6b1738f7e269594bdd67f0...6bb031afdd8eb862ea3fc1848194185e076637e5)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`6f86fb7`](https://github.com/OZI-Project/OZI/commit/6f86fb7653cf82858d1fe39839931b60f7963c95))

*  Bump OZI-Project/release from 1.3.3 to 1.3.4

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.3.3 to 1.3.4.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/ef531325086db519edaf13b95362051f41bb4802...204e7f8af3396d1a4d77afb66ead74b0804ae058)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`0d0d3cf`](https://github.com/OZI-Project/OZI/commit/0d0d3cfc88d10c157ea514cf1e1142c1c4874e30))

*  Bump actions/upload-artifact from 4.6.0 to 4.6.1

Bumps [actions/upload-artifact](https://github.com/actions/upload-artifact) from 4.6.0 to 4.6.1.
- [Release notes](https://github.com/actions/upload-artifact/releases)
- [Commits](https://github.com/actions/upload-artifact/compare/65c4c4a1ddee5b72f698fdd19549f0f0fb45cf08...4cec3d8aa04e39d1a68397de0c4cd6fb9dce8ec1)


updated-dependencies:
- dependency-name: actions/upload-artifact
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`4617228`](https://github.com/OZI-Project/OZI/commit/4617228f0140a75259776fd171c0857c669c8684))

*  Bump ossf/scorecard-action from 2.4.0 to 2.4.1

Bumps [ossf/scorecard-action](https://github.com/ossf/scorecard-action) from 2.4.0 to 2.4.1.
- [Release notes](https://github.com/ossf/scorecard-action/releases)
- [Changelog](https://github.com/ossf/scorecard-action/blob/main/RELEASE.md)
- [Commits](https://github.com/ossf/scorecard-action/compare/62b2cac7ed8198b15735ed49ab1e5cf35480ba46...f49aabe0b5af0936a0987cfb85d86b75731b0186)


updated-dependencies:
- dependency-name: ossf/scorecard-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`54ac375`](https://github.com/OZI-Project/OZI/commit/54ac375c8272e30ff60fa89be4c17260490b16ad))

*  Update hypothesis[cli,codemods,ghostwriter] requirement

Updates the requirements on [hypothesis[cli,codemods,ghostwriter]](https://github.com/HypothesisWorks/hypothesis) to permit the latest version.
- [Release notes](https://github.com/HypothesisWorks/hypothesis/releases)
- [Commits](https://github.com/HypothesisWorks/hypothesis/compare/hypothesis-python-6.126.0...hypothesis-python-6.129.0)


updated-dependencies:
- dependency-name: hypothesis[cli,codemods,ghostwriter]
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`5969729`](https://github.com/OZI-Project/OZI/commit/596972903883d81232217ada9c432b20db61be9c))

*  Update isort requirement in /ozi/lint/isort

Updates the requirements on [isort](https://github.com/PyCQA/isort) to permit the latest version.
- [Release notes](https://github.com/PyCQA/isort/releases)
- [Changelog](https://github.com/PyCQA/isort/blob/main/CHANGELOG.md)
- [Commits](https://github.com/PyCQA/isort/compare/6.0.0...6.0.1)


updated-dependencies:
- dependency-name: isort
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`4baefde`](https://github.com/OZI-Project/OZI/commit/4baefdef38f461a86f22da7e25f788b011c8a59f))

*  Update cibuildwheel requirement in /ozi/dist/cibuildwheel

Updates the requirements on [cibuildwheel](https://github.com/pypa/cibuildwheel) to permit the latest version.
- [Release notes](https://github.com/pypa/cibuildwheel/releases)
- [Changelog](https://github.com/pypa/cibuildwheel/blob/main/docs/changelog.md)
- [Commits](https://github.com/pypa/cibuildwheel/compare/v2.22...v2.23)


updated-dependencies:
- dependency-name: cibuildwheel
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`bbe2deb`](https://github.com/OZI-Project/OZI/commit/bbe2deba249113d33607f2bbe1e122b6939444bc))


### ✨ Implemented Features

*  python-semantic-release updated from 9.20 to 9.21 — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`081169b`](https://github.com/OZI-Project/OZI/commit/081169b8a54e0b02b255a17d28b104021dc50196))


### Other


* ⬆️ Bump ozi-core from 1.15.1 to 1.16.0 — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`dc7facf`](https://github.com/OZI-Project/OZI/commit/dc7facf0664b77fd6d5118d9c9109ecd7c0c7c0d))

## 1.36.0 (2025-02-21)


### ⬆️ Upgraded Dependencies

*  Bump ozi-core from 1.15.0 to 1.15.1

Bumps [ozi-core](https://github.com/OZI-Project/ozi-core) from 1.15.0 to 1.15.1.
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/1.15.1/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.15.0...1.15.1)


updated-dependencies:
- dependency-name: ozi-core
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`aa20093`](https://github.com/OZI-Project/OZI/commit/aa20093ba90a82cb2a8a7e24bf5f12b0c8bff7ce))

*  Bump OZI-Project/publish from 1.10.1 to 1.12.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.10.1 to 1.12.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/9d10868569d8cf25647f221a223d27cfe545ffb2...63a52d7e0f5abc79d3fd3f7ecfa7f26efd1c8c69)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`35eacc9`](https://github.com/OZI-Project/OZI/commit/35eacc9f206b3ffc70cca7aa6a843ca66d608448))

*  Bump OZI-Project/draft from 1.11.1 to 1.12.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.11.1 to 1.12.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/d593fa1d1df726466bd156d239ed36986d1c2ab9...cbedf57c7d2529c093518f0652cf4f7324cb3755)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`725f002`](https://github.com/OZI-Project/OZI/commit/725f002dae1ae0853c6e951d46fb388ab395a892))

*  Update hypothesis[cli,codemods,ghostwriter] requirement

Updates the requirements on [hypothesis[cli,codemods,ghostwriter]](https://github.com/HypothesisWorks/hypothesis) to permit the latest version.
- [Release notes](https://github.com/HypothesisWorks/hypothesis/releases)
- [Commits](https://github.com/HypothesisWorks/hypothesis/compare/hypothesis-python-6.125.0...hypothesis-python-6.126.0)


updated-dependencies:
- dependency-name: hypothesis[cli,codemods,ghostwriter]
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`3bb2017`](https://github.com/OZI-Project/OZI/commit/3bb20172d81cc6ce2066d22668fd5336ba8f3efc))

*  Bump ozi-core from 1.14.2 to 1.15.0

Bumps [ozi-core](https://github.com/OZI-Project/ozi-core) from 1.14.2 to 1.15.0.
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/1.15.0/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.14.2...1.15.0)


updated-dependencies:
- dependency-name: ozi-core
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`76b232a`](https://github.com/OZI-Project/OZI/commit/76b232ab0a1634c67b908f43c6e1ce1822b5e645))

*  Bump step-security/harden-runner from 2.10.4 to 2.11.0

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.10.4 to 2.11.0.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/cb605e52c26070c328afc4562f0b4ada7618a84e...4d991eb9b905ef189e4c376166672c3f2f230481)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`dff6133`](https://github.com/OZI-Project/OZI/commit/dff6133efb43ab2e6d494ceb6e00b9d564ab4f34))

*  Update ozi-build[core,uv] requirement


updated-dependencies:
- dependency-name: ozi-build[core,uv]
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`12a6918`](https://github.com/OZI-Project/OZI/commit/12a691808879ed3c553b39d4a2ba13dcb1e540fc))

*  Update python-semantic-release requirement

Updates the requirements on [python-semantic-release](https://github.com/python-semantic-release/python-semantic-release) to permit the latest version.
- [Release notes](https://github.com/python-semantic-release/python-semantic-release/releases)
- [Changelog](https://github.com/python-semantic-release/python-semantic-release/blob/master/CHANGELOG.rst)
- [Commits](https://github.com/python-semantic-release/python-semantic-release/compare/v9.19...v9.20)


updated-dependencies:
- dependency-name: python-semantic-release
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`cf1a888`](https://github.com/OZI-Project/OZI/commit/cf1a88867457626162e937e719a0c8dedadf8ce2))


### ✨ Implemented Features

*  semantic-release 9.20 support — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`ca1f4cd`](https://github.com/OZI-Project/OZI/commit/ca1f4cd61ff8d1b33cc5c713a686a4ada8941141))

## 1.35.1 (2025-02-13)


### ⬆️ Upgraded Dependencies

*  Bump ozi-core from 1.14.1 to 1.14.2

Bumps [ozi-core](https://github.com/OZI-Project/ozi-core) from 1.14.1 to 1.14.2.
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/1.14.2/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.14.1...1.14.2)


updated-dependencies:
- dependency-name: ozi-core
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`3a32ec3`](https://github.com/OZI-Project/OZI/commit/3a32ec370aedc08fc85a5ce4607c5f536d2c6305))

## 1.35.0 (2025-02-12)

## 1.34.1 (2025-01-29)


### ⬆️ Upgraded Dependencies

*  Bump ozi-core from 1.13.1 to 1.14.1

Bumps [ozi-core](https://github.com/OZI-Project/ozi-core) from 1.13.1 to 1.14.1.
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/main/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.13.1...1.14.1)


updated-dependencies:
- dependency-name: ozi-core
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`3dfe49b`](https://github.com/OZI-Project/OZI/commit/3dfe49b2adc87d5d051ccd0b69b65d7bdfb1d21c))

*  Update ozi-build[core,uv] requirement


updated-dependencies:
- dependency-name: ozi-build[core,uv]
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`2841e2d`](https://github.com/OZI-Project/OZI/commit/2841e2d9d153edbf860834c82f079e36506994eb))

*  Bump OZI-Project/draft from 1.10.1 to 1.11.1

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.10.1 to 1.11.1.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/d3c4167df5ea92adf74006a4406ae85bbf8926e5...d593fa1d1df726466bd156d239ed36986d1c2ab9)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`930c67a`](https://github.com/OZI-Project/OZI/commit/930c67a219a5e4d0817e9d15ac719d6caefbe88a))

*  Bump OZI-Project/publish from 1.10.0 to 1.10.1

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.10.0 to 1.10.1.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/c409525ed951ad88365aefffdb117c7a762a7f3b...9d10868569d8cf25647f221a223d27cfe545ffb2)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`be1d575`](https://github.com/OZI-Project/OZI/commit/be1d5753978ef5b21f90361f9b713d367bc83fd1))

*  Update python-semantic-release requirement

Updates the requirements on [python-semantic-release](https://github.com/python-semantic-release/python-semantic-release) to permit the latest version.
- [Release notes](https://github.com/python-semantic-release/python-semantic-release/releases)
- [Changelog](https://github.com/python-semantic-release/python-semantic-release/blob/master/CHANGELOG.rst)
- [Commits](https://github.com/python-semantic-release/python-semantic-release/compare/v9.17...v9.19)


updated-dependencies:
- dependency-name: python-semantic-release
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`7d75040`](https://github.com/OZI-Project/OZI/commit/7d75040047382f6b8d268066634a889e14f79a71))

*  Bump github/codeql-action from 3.28.8 to 3.28.9

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.28.8 to 3.28.9.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/dd746615b3b9d728a6a37ca2045b68ca76d4841a...9e8d0789d4a0fa9ceb6b1738f7e269594bdd67f0)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`9276a8e`](https://github.com/OZI-Project/OZI/commit/9276a8ec9a4ec87567bbb741e012eca0922bfe22))

*  Update hypothesis[cli,codemods,ghostwriter] requirement

Updates the requirements on [hypothesis[cli,codemods,ghostwriter]](https://github.com/HypothesisWorks/hypothesis) to permit the latest version.
- [Release notes](https://github.com/HypothesisWorks/hypothesis/releases)
- [Commits](https://github.com/HypothesisWorks/hypothesis/compare/hypothesis-python-6.124.0...hypothesis-python-6.125.1)


updated-dependencies:
- dependency-name: hypothesis[cli,codemods,ghostwriter]
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`0c6c32c`](https://github.com/OZI-Project/OZI/commit/0c6c32c4cff96ce14012ac55c1edced6c33d1cdb))

*  Bump OZI-Project/publish from 1.9.3 to 1.10.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.9.3 to 1.10.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/c35059a13b64575387092e163fa91c2a9f5019da...c409525ed951ad88365aefffdb117c7a762a7f3b)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`e27ca42`](https://github.com/OZI-Project/OZI/commit/e27ca4283742785de287a172eaa3ee293ed1ea56))

*  Bump github/codeql-action from 3.28.6 to 3.28.8

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.28.6 to 3.28.8.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/17a820bf2e43b47be2c72b39cc905417bc1ab6d0...dd746615b3b9d728a6a37ca2045b68ca76d4841a)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`69dc1ee`](https://github.com/OZI-Project/OZI/commit/69dc1ee184d9dfd28fe1a5a9af23eb70b77b9bda))

*  Bump OZI-Project/draft from 1.10.0 to 1.10.1

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.10.0 to 1.10.1.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/44efdab7f2755cdda29697adf8951e25b468a696...d3c4167df5ea92adf74006a4406ae85bbf8926e5)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`a075417`](https://github.com/OZI-Project/OZI/commit/a0754177e93676a8fc1df84d5f14161572a5a466))

*  Bump OZI-Project/publish from 1.9.0 to 1.9.3

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.9.0 to 1.9.3.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/2467f6f7d938a0587d8dbc3f1155bab825f35283...c35059a13b64575387092e163fa91c2a9f5019da)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`197e8c7`](https://github.com/OZI-Project/OZI/commit/197e8c7abf537cbc2b7df716983534c5dab87a7c))

*  Bump OZI-Project/checkpoint from 1.5.4 to 1.5.5

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.5.4 to 1.5.5.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/84a85f725520d5661ed417915ccb0e769973879c...f14cac563125e34d106b3a1e0ddb2773062953e5)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`55442c7`](https://github.com/OZI-Project/OZI/commit/55442c70e1228fc7dd4c2119404d8dffef0db42d))

*  Bump OZI-Project/release from 1.3.1 to 1.3.3

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.3.1 to 1.3.3.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/5fead75f13134fe16226c4eba87ae80b52876ab0...ef531325086db519edaf13b95362051f41bb4802)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`1456370`](https://github.com/OZI-Project/OZI/commit/1456370862511f8fe7bb7ffe6f1554f3379d53c9))

*  Bump ozi-core from 1.13.0 to 1.13.1

Bumps [ozi-core](https://github.com/OZI-Project/ozi-core) from 1.13.0 to 1.13.1.
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/1.13.1/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.13.0...1.13.1)


updated-dependencies:
- dependency-name: ozi-core
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`62a77a4`](https://github.com/OZI-Project/OZI/commit/62a77a47ae3913872557dce15b9e6b0d9a020fa3))

*  Update black requirement in /ozi/lint/black

Updates the requirements on [black](https://github.com/psf/black) to permit the latest version.
- [Release notes](https://github.com/psf/black/releases)
- [Changelog](https://github.com/psf/black/blob/main/CHANGES.md)
- [Commits](https://github.com/psf/black/compare/24.10.0...25.1.0)


updated-dependencies:
- dependency-name: black
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`43436dd`](https://github.com/OZI-Project/OZI/commit/43436dd6bc14ba8ecacb96e17c281f27ef33a447))

*  pytest-asyncio~=0.25.3 — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`0001961`](https://github.com/OZI-Project/OZI/commit/0001961836469fd02fc00a38e7bb19d896411ba7))

*  Update black requirement in /ozi/lint/black

Updates the requirements on [black](https://github.com/psf/black) to permit the latest version.
- [Release notes](https://github.com/psf/black/releases)
- [Changelog](https://github.com/psf/black/blob/main/CHANGES.md)
- [Commits](https://github.com/psf/black/compare/24.10.0...25.1.0)


updated-dependencies:
- dependency-name: black
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`d7aa9e8`](https://github.com/OZI-Project/OZI/commit/d7aa9e822305fe0b84a8d0b4543172e26165212f))


### ✨ Implemented Features

*  semantic-release 9.19 support — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`ba9cdd9`](https://github.com/OZI-Project/OZI/commit/ba9cdd9de126a3242a863c414d46218f7adfc406))


### Other


* 🚨 run black — rjdbcm <ozi.project@outlook.com>
([`bcc5ba7`](https://github.com/OZI-Project/OZI/commit/bcc5ba750f76a6c645f30a0a99973dfeb8aae029))

* Update SECURITY.md — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`2434766`](https://github.com/OZI-Project/OZI/commit/2434766b08451dbf1fcf60e3a11dde7c46ae7494))

## 1.34.0 (2025-01-28)

## 1.33.3 (2025-01-27)

## 1.33.2 (2025-01-27)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/draft from 1.9.0 to 1.10.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.9.0 to 1.10.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/31451b7f6a49b6ef70270b59ff70585d76677012...44efdab7f2755cdda29697adf8951e25b468a696)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`1d66bdb`](https://github.com/OZI-Project/OZI/commit/1d66bdb0df9b7c0b3eeeb10baeb52e9e0f3e49e4))

*  Bump OZI-Project/publish from 1.8.0 to 1.9.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.8.0 to 1.9.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/025b6cb35f983387bb0981661eae0beddb8282fe...2467f6f7d938a0587d8dbc3f1155bab825f35283)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`cf45e14`](https://github.com/OZI-Project/OZI/commit/cf45e14b0503f63ada1e8d276b7b0ff79434c07d))

*  Bump github/codeql-action from 3.28.5 to 3.28.6

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.28.5 to 3.28.6.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/f6091c0113d1dcf9b98e269ee48e8a7e51b7bdd4...17a820bf2e43b47be2c72b39cc905417bc1ab6d0)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`45829a1`](https://github.com/OZI-Project/OZI/commit/45829a1b918db18daf1a2c4164afd4a573295852))

*  Update python-semantic-release requirement

Updates the requirements on [python-semantic-release](https://github.com/python-semantic-release/python-semantic-release) to permit the latest version.
- [Release notes](https://github.com/python-semantic-release/python-semantic-release/releases)
- [Changelog](https://github.com/python-semantic-release/python-semantic-release/blob/master/CHANGELOG.rst)
- [Commits](https://github.com/python-semantic-release/python-semantic-release/compare/v9.16...v9.17)


updated-dependencies:
- dependency-name: python-semantic-release
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`847b994`](https://github.com/OZI-Project/OZI/commit/847b994407f6c42e0b61cf49cd00a6f2ae458680))

*  Bump ozi-core from 1.12.4 to 1.13.0

Bumps [ozi-core](https://github.com/OZI-Project/ozi-core) from 1.12.4 to 1.13.0.
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/1.13.0/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.12.4...1.13.0)


updated-dependencies:
- dependency-name: ozi-core
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`98712eb`](https://github.com/OZI-Project/OZI/commit/98712eb68cdc9f5bec04ab948af8b38d7a36bdb8))

*  Bump ozi-core from 1.12.3 to 1.12.4

Bumps [ozi-core](https://github.com/OZI-Project/ozi-core) from 1.12.3 to 1.12.4.
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/1.12.4/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.12.3...1.12.4)


updated-dependencies:
- dependency-name: ozi-core
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`800912d`](https://github.com/OZI-Project/OZI/commit/800912dee9b801fcf065f96d2eacec43a7bfafff))

*  Bump step-security/harden-runner from 2.10.3 to 2.10.4

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.10.3 to 2.10.4.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/c95a14d0e5bab51a9f56296a4eb0e416910cd350...cb605e52c26070c328afc4562f0b4ada7618a84e)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`a44d2e8`](https://github.com/OZI-Project/OZI/commit/a44d2e8b11501e1f09a90fa90cc169563ad282e9))

*  Bump github/codeql-action from 3.28.4 to 3.28.5

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.28.4 to 3.28.5.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/ee117c905ab18f32fa0f66c2fe40ecc8013f3e04...f6091c0113d1dcf9b98e269ee48e8a7e51b7bdd4)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`8564565`](https://github.com/OZI-Project/OZI/commit/856456542a4275b55a4bf849ce45d5577fa64961))

*  Bump twine from 6.0.1 to 6.1.0 in /ozi/dist/twine

Bumps [twine](https://github.com/pypa/twine) from 6.0.1 to 6.1.0.
- [Release notes](https://github.com/pypa/twine/releases)
- [Changelog](https://github.com/pypa/twine/blob/main/docs/changelog.rst)
- [Commits](https://github.com/pypa/twine/compare/6.0.1...6.1.0)


updated-dependencies:
- dependency-name: twine
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`a0e7de9`](https://github.com/OZI-Project/OZI/commit/a0e7de905412cfee276f9e496cc084f555672a86))

*  Bump github/codeql-action from 3.28.1 to 3.28.4

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.28.1 to 3.28.4.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/b6a472f63d85b9c78a3ac5e89422239fc15e9b3c...ee117c905ab18f32fa0f66c2fe40ecc8013f3e04)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`d4c90e1`](https://github.com/OZI-Project/OZI/commit/d4c90e1cb8ba85b1abf3411e1ff0cce9e2e0df72))

*  Bump pypa/gh-action-pypi-publish from 1.12.3 to 1.12.4

Bumps [pypa/gh-action-pypi-publish](https://github.com/pypa/gh-action-pypi-publish) from 1.12.3 to 1.12.4.
- [Release notes](https://github.com/pypa/gh-action-pypi-publish/releases)
- [Commits](https://github.com/pypa/gh-action-pypi-publish/compare/67339c736fd9354cd4f8cb0b744f2b82a74b5c70...76f52bc884231f62b9a034ebfe128415bbaabdfc)


updated-dependencies:
- dependency-name: pypa/gh-action-pypi-publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`8844a10`](https://github.com/OZI-Project/OZI/commit/8844a1019eed187dc29be649a173d53cb18cdb7d))


### 📌 Pinned Dependencies

*  isort~=6.0.0 — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`740518b`](https://github.com/OZI-Project/OZI/commit/740518b165caf78b8adf115f03a9ba72e4d73ab1))


### Other


* build: pin ozi-core version — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`4c69de2`](https://github.com/OZI-Project/OZI/commit/4c69de247f2db641555743a14d338c9221ca7a72))

## 1.33.1 (2025-01-18)


### ⬆️ Upgraded Dependencies

*  Update ozi-core requirement from ~=1.12.1 to ~=1.12.2 — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`de7e700`](https://github.com/OZI-Project/OZI/commit/de7e7001c41a2fbe0f15556fb471b874ff3e5793))

## 1.33.0 (2025-01-17)


### ⬆️ Upgraded Dependencies

*  Update flake8-type-checking requirement in /ozi/lint/flake8

Updates the requirements on [flake8-type-checking](https://github.com/snok/flake8-type-checking) to permit the latest version.
- [Release notes](https://github.com/snok/flake8-type-checking/releases)
- [Commits](https://github.com/snok/flake8-type-checking/compare/v2.9.0...v3.0.0)


updated-dependencies:
- dependency-name: flake8-type-checking
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`6d27b01`](https://github.com/OZI-Project/OZI/commit/6d27b01e6b9fc0cd353724a583a26e6ffbb0686c))

## 1.32.0 (2025-01-14)


### ⬆️ Upgraded Dependencies

*  Bump actions/upload-artifact from 4.5.0 to 4.6.0

Bumps [actions/upload-artifact](https://github.com/actions/upload-artifact) from 4.5.0 to 4.6.0.
- [Release notes](https://github.com/actions/upload-artifact/releases)
- [Commits](https://github.com/actions/upload-artifact/compare/6f51ac03b9356f520e9adb1b1b7802705f340c2b...65c4c4a1ddee5b72f698fdd19549f0f0fb45cf08)


updated-dependencies:
- dependency-name: actions/upload-artifact
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`8120f04`](https://github.com/OZI-Project/OZI/commit/8120f04a5d7b99027e2cb5b2feae9369d0f6bb00))

*  Bump github/codeql-action from 3.28.0 to 3.28.1

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.28.0 to 3.28.1.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/48ab28a6f5dbc2a99bf1e0131198dd8f1df78169...b6a472f63d85b9c78a3ac5e89422239fc15e9b3c)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`5a173d1`](https://github.com/OZI-Project/OZI/commit/5a173d10d658e57e034f115280472717567169de))

*  Bump OZI-Project/draft from 1.8.0 to 1.9.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.8.0 to 1.9.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/ae5afb49d75af6437247b504812f049e5607d342...31451b7f6a49b6ef70270b59ff70585d76677012)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`b0c8bf6`](https://github.com/OZI-Project/OZI/commit/b0c8bf680721832d06cc71b5909a41c55e650969))

*  Bump OZI-Project/publish from 1.7.3 to 1.8.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.7.3 to 1.8.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/fd7b8704941103ceec5a24f80d0999d2209ed8f2...025b6cb35f983387bb0981661eae0beddb8282fe)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`75b54da`](https://github.com/OZI-Project/OZI/commit/75b54da410b82e62df7bd5adb6f29edf67437706))

*  Bump OZI-Project/checkpoint from 1.5.3 to 1.5.4

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.5.3 to 1.5.4.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/e8968b10918a82bf03e196f5feac1669ccdf98e2...84a85f725520d5661ed417915ccb0e769973879c)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`850d9a6`](https://github.com/OZI-Project/OZI/commit/850d9a61d77c50a5a22db61d31f7d308370ac2d7))

*  Update python-semantic-release requirement

Updates the requirements on [python-semantic-release](https://github.com/python-semantic-release/python-semantic-release) to permit the latest version.
- [Release notes](https://github.com/python-semantic-release/python-semantic-release/releases)
- [Changelog](https://github.com/python-semantic-release/python-semantic-release/blob/master/CHANGELOG.md)
- [Commits](https://github.com/python-semantic-release/python-semantic-release/compare/v9.15...v9.16.1)


updated-dependencies:
- dependency-name: python-semantic-release
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`d7f39f4`](https://github.com/OZI-Project/OZI/commit/d7f39f48d1ceadc5a527e63d43dfb96aa8b83389))

*  Update hypothesis[cli,codemods,ghostwriter] requirement

Updates the requirements on [hypothesis[cli,codemods,ghostwriter]](https://github.com/HypothesisWorks/hypothesis) to permit the latest version.
- [Release notes](https://github.com/HypothesisWorks/hypothesis/releases)
- [Commits](https://github.com/HypothesisWorks/hypothesis/compare/hypothesis-python-6.123.0...hypothesis-python-6.124.0)


updated-dependencies:
- dependency-name: hypothesis[cli,codemods,ghostwriter]
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`06abc10`](https://github.com/OZI-Project/OZI/commit/06abc1029f688f30c023d71e777aace97a4b9dc8))

*  Update ozi-core requirement from ~=1.11.2 to ~=1.12.1

Updates the requirements on [ozi-core](https://github.com/OZI-Project/ozi-core) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/1.12.1/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.11.2...1.12.1)


updated-dependencies:
- dependency-name: ozi-core
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`1925b08`](https://github.com/OZI-Project/OZI/commit/1925b085e1d718fc759dffa90a4756def489a0b4))

*  Bump OZI-Project/publish from 1.7.2 to 1.7.3

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.7.2 to 1.7.3.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/67952e32de84496a2ed2729ffbc612a63d4ede47...fd7b8704941103ceec5a24f80d0999d2209ed8f2)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`2b8f4e2`](https://github.com/OZI-Project/OZI/commit/2b8f4e26722a79858004de94f7e40343e4427fa4))

*  Bump OZI-Project/draft from 1.7.0 to 1.8.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.7.0 to 1.8.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/c0d23e778c413e1f5c7ca9555a1ec190c9e48cbd...ae5afb49d75af6437247b504812f049e5607d342)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`4158193`](https://github.com/OZI-Project/OZI/commit/4158193796efd07a9d11e3955f0a7555e5e3e867))

*  Bump OZI-Project/checkpoint from 1.4.0 to 1.5.3

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.4.0 to 1.5.3.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/5eb7b6ec9ba2eec71a0418270d92e9a6d81d285f...e8968b10918a82bf03e196f5feac1669ccdf98e2)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`6183b78`](https://github.com/OZI-Project/OZI/commit/6183b789662e398209d202f7db47c930b5930282))

*  Bump OZI-Project/release from 1.1.2 to 1.3.1

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.1.2 to 1.3.1.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0e2db492d3d36479eadc1ba15e509e911816bc39...5fead75f13134fe16226c4eba87ae80b52876ab0)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`c19cb94`](https://github.com/OZI-Project/OZI/commit/c19cb94a00d5a93f75c6086f12d38d05870e8d3b))

*  Bump step-security/harden-runner from 2.10.2 to 2.10.3

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.10.2 to 2.10.3.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/0080882f6c36860b6ba35c610c98ce87d4e2f26f...c95a14d0e5bab51a9f56296a4eb0e416910cd350)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`bd5113f`](https://github.com/OZI-Project/OZI/commit/bd5113f16f7a72621bc3e26c99528c4e4577056b))

*  Update flake8-pytest-style requirement in /ozi/lint/flake8

Updates the requirements on [flake8-pytest-style](https://github.com/m-burst/flake8-pytest-style) to permit the latest version.
- [Commits](https://github.com/m-burst/flake8-pytest-style/compare/v2.0.0...v2.1.0)


updated-dependencies:
- dependency-name: flake8-pytest-style
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`ba09738`](https://github.com/OZI-Project/OZI/commit/ba09738bb885c604f94a7ac83174510f35c2c164))

*  Update ozi-core requirement from ~=1.10.0 to ~=1.11.2

Updates the requirements on [ozi-core](https://github.com/OZI-Project/ozi-core) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/1.11.2/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.10.0...1.11.2)


updated-dependencies:
- dependency-name: ozi-core
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`629e72e`](https://github.com/OZI-Project/OZI/commit/629e72ea3c724d557c8e13296ca31a1389516a66))


### Other


* Update SECURITY.md — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`1d52fd5`](https://github.com/OZI-Project/OZI/commit/1d52fd546c1c1249d2a3a87eb9e5f478db3e471f))

## 1.31.4 (2025-01-12)


### 🐛 Fixed Bugs

*  fix symlink in build — rjdbcm <ozi.project@outlook.com>
([`3d925c3`](https://github.com/OZI-Project/OZI/commit/3d925c38854bf9b2ee1be099e2943959efe9e1e6))

## 1.31.3 (2025-01-12)


### 🐛 Fixed Bugs

*  create_subproject_symlink now runs as a postconf script — rjdbcm <ozi.project@outlook.com>
([`9bd1746`](https://github.com/OZI-Project/OZI/commit/9bd1746155d71e394f5865bfb81beb7b8e454571))

## 1.31.2 (2025-01-12)


### 🐛 Fixed Bugs

*  fix subproject symlink script target — rjdbcm <ozi.project@outlook.com>
([`a1f0f0c`](https://github.com/OZI-Project/OZI/commit/a1f0f0c5dbc2ff8ce0d7135e1b05c1f065498570))

## 1.31.1 (2025-01-12)

## 1.31.0 (2025-01-01)


### Other


* fix: ignore deprecated branch ValidationError — rjdbcm <ozi.project@outlook.com>
([`e790fdc`](https://github.com/OZI-Project/OZI/commit/e790fdc7b5eb2a927db6222ca803ffa46c794201))

* Update pyproject.toml — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`7c41335`](https://github.com/OZI-Project/OZI/commit/7c41335aaa38aa85544c94cbef6bba6c3a573b42))

## 1.30.0 (2024-12-31)


### ⬆️ Upgraded Dependencies

*  Update ozi-core requirement from ~=1.9.1 to ~=1.10.0

Updates the requirements on [ozi-core](https://github.com/OZI-Project/ozi-core) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/main/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.9.1...1.10.0)


updated-dependencies:
- dependency-name: ozi-core
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`6a65cfa`](https://github.com/OZI-Project/OZI/commit/6a65cfa74a8a9c3a8e32a0316b1c2875845e864d))

*  Update ozi-build[core,uv] requirement


updated-dependencies:
- dependency-name: ozi-build[core,uv]
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`bb39345`](https://github.com/OZI-Project/OZI/commit/bb393458aeb430fe6960049616a3b272c004c80f))

*  Update ozi-build[core,uv] requirement from ~=1.8.2 to ~=1.9.2


updated-dependencies:
- dependency-name: ozi-build[core,uv]
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`6bf8e5b`](https://github.com/OZI-Project/OZI/commit/6bf8e5b7f8e32385d2edc8dba44034f62f828c1d))

*  Update ozi-core requirement from ~=1.8.0 to ~=1.9.1

Updates the requirements on [ozi-core](https://github.com/OZI-Project/ozi-core) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/1.9.1/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.8.0...1.9.1)


updated-dependencies:
- dependency-name: ozi-core
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`f63e9dc`](https://github.com/OZI-Project/OZI/commit/f63e9dc30228f0e99ef6c0b75d7718b0cd73b1ce))


### 🐛 Fixed Bugs

*  tox workflow OZI.build updated to 1.10.0 — rjdbcm <ozi.project@outlook.com>
([`baa5655`](https://github.com/OZI-Project/OZI/commit/baa565513bc0863e7513afc9ccb8ab4f9b82a1f4))


### 🔨 Updated Scripts

* (deps): add ``pathvalidate`` dependency and validate user-provided filepaths — rjdbcm <ozi.project@outlook.com>
([`9590353`](https://github.com/OZI-Project/OZI/commit/959035317153bb2cc5e7a8a55b37cd9b72d11451))

*  add create_subproject_symlink.py script — rjdbcm <ozi.project@outlook.com>
([`7e6923f`](https://github.com/OZI-Project/OZI/commit/7e6923fd26201ab7f46c87c141394d365a3a4194))


### Other


* 1.30.0

Automatically generated by python-semantic-release
([`7c84d24`](https://github.com/OZI-Project/OZI/commit/7c84d244c6b94ba688a6114649ef24467f051a10))

* Update SECURITY.md — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`692234e`](https://github.com/OZI-Project/OZI/commit/692234ea046a290a0d722a6a92ea6ddbb1d35228))

* fix: set platform for pathvalidate to auto — rjdbcm <ozi.project@outlook.com>
([`512e194`](https://github.com/OZI-Project/OZI/commit/512e1949ca184014d833b9f08eba90d287e6dc22))

* Update SECURITY.md — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`7b6c967`](https://github.com/OZI-Project/OZI/commit/7b6c967343cd39e472e655602e80cd612b1f36f0))

## 1.29.1 (2024-12-23)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.27.9 to 3.28.0

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.27.9 to 3.28.0.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/df409f7d9260372bd5f19e5b04e83cb3c43714ae...48ab28a6f5dbc2a99bf1e0131198dd8f1df78169)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`e1c78da`](https://github.com/OZI-Project/OZI/commit/e1c78daca9e58093208a4f49de3b71b8f10b3b2c))

*  Update hypothesis[cli,codemods,ghostwriter] requirement

Updates the requirements on [hypothesis[cli,codemods,ghostwriter]](https://github.com/HypothesisWorks/hypothesis) to permit the latest version.
- [Release notes](https://github.com/HypothesisWorks/hypothesis/releases)
- [Commits](https://github.com/HypothesisWorks/hypothesis/compare/hypothesis-python-6.122.0...hypothesis-python-6.123.0)


updated-dependencies:
- dependency-name: hypothesis[cli,codemods,ghostwriter]
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`04c8977`](https://github.com/OZI-Project/OZI/commit/04c89771f56ba533a6a7d58250f4e88595d80756))


### 🔥 Deleted Code or Files

* delete .github/workflows/purge-artifacts.yml — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`b1fad1c`](https://github.com/OZI-Project/OZI/commit/b1fad1cfa959ce30032b834c430c9b9408a0089e))


### 🔨 Updated Configuration

* (StepSecurity): Harden GitHub Actions — StepSecurity Bot <bot@stepsecurity.io>
([`796cd81`](https://github.com/OZI-Project/OZI/commit/796cd8136290e6538774be4923633cb280405db5))


### Other


* 1.29.1

Automatically generated by python-semantic-release
([`427983f`](https://github.com/OZI-Project/OZI/commit/427983f75013a3e3fbbb66e2ab2bfe53a637cffc))

* Update SECURITY.md — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`4621e2a`](https://github.com/OZI-Project/OZI/commit/4621e2a8712e22055b6ed774e30d419ff3b46afb))

## 1.29.0 (2024-12-20)


### ⬆️ Upgraded Dependencies

*  bump OZI-Project/draft from 1.6.3 to 1.7.0 (#1358)

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.6.3 to 1.7.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/b462b01f7f92a361d92233a8c2d326276c2d91a3...c0d23e778c413e1f5c7ca9555a1ec190c9e48cbd)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
Co-authored-by: dependabot[bot] <49699333+dependabot[bot]@users.noreply.github.com>
([`3d495ec`](https://github.com/OZI-Project/OZI/commit/3d495eca5b4e0f341b2496b1deecd55cbddb0d3e))

* bump OZI-Project/publish from 1.7.1 to 1.7.2 (#1359)

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.7.1 to 1.7.2.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.7.1...1.7.2)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
Co-authored-by: dependabot[bot] <49699333+dependabot[bot]@users.noreply.github.com>
([`cca0829`](https://github.com/OZI-Project/OZI/commit/cca082973d4cdf23db92d5300adb2a09fa2e6a21))

* bump actions/upload-artifact from 4.4.3 to 4.5.0 (#1360)

Bumps [actions/upload-artifact](https://github.com/actions/upload-artifact) from 4.4.3 to 4.5.0.
- [Release notes](https://github.com/actions/upload-artifact/releases)
- [Commits](https://github.com/actions/upload-artifact/compare/b4b15b8c7c6ac21ea08fcf65892d2ee8f75cf882...6f51ac03b9356f520e9adb1b1b7802705f340c2b)


updated-dependencies:
- dependency-name: actions/upload-artifact
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
Co-authored-by: dependabot[bot] <49699333+dependabot[bot]@users.noreply.github.com>
([`ad0330a`](https://github.com/OZI-Project/OZI/commit/ad0330ae611d84d659ad0ff127dcc6b89a375bf8))

*  update ozi-core requirement from ~=1.7.0 to ~=1.8.0 (#1362)

Updates the requirements on [ozi-core](https://github.com/OZI-Project/ozi-core) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/main/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.7.0...1.8.0)


updated-dependencies:
- dependency-name: ozi-core
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
Co-authored-by: dependabot[bot] <49699333+dependabot[bot]@users.noreply.github.com>
([`6479ecf`](https://github.com/OZI-Project/OZI/commit/6479ecfdcfceda27f260dd66ba8d23102ef99ba6))


### ✨ Implemented Features

* spec v0.16 — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`db34bf2`](https://github.com/OZI-Project/OZI/commit/db34bf2b7c750a9b5343d4e194f5a781e06cbca7))


### 🔨 Updated Configuration

*  remove duplicate metadata for OZI.build 1.8.2 — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`8a1be77`](https://github.com/OZI-Project/OZI/commit/8a1be773209f07bf68568048353115b494dce1a0))


### Other


* 1.29.0

Automatically generated by python-semantic-release
([`658f7a8`](https://github.com/OZI-Project/OZI/commit/658f7a898bad142dbbdcf4eab22609fbc83e551c))

* Update dist-workflow.yml — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`263c668`](https://github.com/OZI-Project/OZI/commit/263c668a01679446aad23d75acc890a1025e78b8))

* Update dependabot.yml — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`681b8fa`](https://github.com/OZI-Project/OZI/commit/681b8faabe25f6fe8bfb6319468d93ebf85157f0))

## 1.28.0 (2024-12-17)


### 🔨 Updated Scripts

*  dump meson-log then test log — rjdbcm <ozi.project@outlook.com>
([`586ed55`](https://github.com/OZI-Project/OZI/commit/586ed55de4996192f7384c154152a367a7631e20))

*  print checkpoint logs from within the task
([`fea7d05`](https://github.com/OZI-Project/OZI/commit/fea7d05e74f9e64f7881c31697a88e064e427dbb))


### 📌 Pinned Dependencies

*  set twine to version 6.0.1 matching gh-action-pypi-publish — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`1b56d17`](https://github.com/OZI-Project/OZI/commit/1b56d175fc6aebe06a577dd9353bc15981dcc43a))


### ✨ Implemented Features

*  spec v0.15 — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`3eb0518`](https://github.com/OZI-Project/OZI/commit/3eb0518125998cdc6fd024672564551bd98f7d33))


### Other


* 1.28.0

Automatically generated by python-semantic-release
([`9221609`](https://github.com/OZI-Project/OZI/commit/922160938d97e1eba33747f9925916779f1594b3))

* Update dist-workflow.yml — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`c49fd7d`](https://github.com/OZI-Project/OZI/commit/c49fd7d33b6abe9b411eb452c3ca391b0b5748cb))

* Update dist-workflow.yml — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`13cc46f`](https://github.com/OZI-Project/OZI/commit/13cc46f0aa2875d343a8d4ce6afc98cde4704b1a))

* Update dev-workflow.yml — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`fc4c9d7`](https://github.com/OZI-Project/OZI/commit/fc4c9d7b4d8f1183931a0a71ecade22c2f26aba7))

* Bump OZI-Project/checkpoint from 1.2.1 to 1.3.0

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.2.1 to 1.3.0.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/32b9310f480343c946214e3ea4b637202eaa312a...94fd5184fa20bc409fb39e2529ba432626101c18)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`73482d5`](https://github.com/OZI-Project/OZI/commit/73482d5a84a91d2ab63eb14938b4d7f9d95f23e5))

* run black — rjdbcm <ozi.project@outlook.com>
([`e946e00`](https://github.com/OZI-Project/OZI/commit/e946e0057bc164b092aa5d7864d8a86a7afe439a))

* Update ozi-core requirement from ~=1.6.0 to ~=1.7.0

Updates the requirements on [ozi-core](https://github.com/OZI-Project/ozi-core) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/1.7.0/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.6.0...1.7.0)


updated-dependencies:
- dependency-name: ozi-core
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`c1b6b6f`](https://github.com/OZI-Project/OZI/commit/c1b6b6f583fac520ce03edbd81980af82f3f91d4))

* Bump OZI-Project/release from 1.0.5 to 1.1.2

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.0.5 to 1.1.2.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/1a3cb28a9a9d51fa8e333740a8b863c0f23ab3da...0e2db492d3d36479eadc1ba15e509e911816bc39)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`0f43e37`](https://github.com/OZI-Project/OZI/commit/0f43e3719a88ffbbeed9a124812bf954076544b4))

* Bump OZI-Project/publish from 1.6.0 to 1.7.1

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.6.0 to 1.7.1.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/e5fa598dca4f35b10e8071e1050c332c3263e11d...8e64c6d501bee7b5b0db5247cd761085d411d1bf)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`8e8f306`](https://github.com/OZI-Project/OZI/commit/8e8f306614a2472d15f8682617b6534952ebb470))

* Bump OZI-Project/checkpoint from 1.2.1 to 1.4.0

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.2.1 to 1.4.0.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/32b9310f480343c946214e3ea4b637202eaa312a...5eb7b6ec9ba2eec71a0418270d92e9a6d81d285f)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`6447223`](https://github.com/OZI-Project/OZI/commit/644722303c57fa65e8e2510db4693ad189f76740))

* Bump OZI-Project/draft from 1.6.0 to 1.6.3

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.6.0 to 1.6.3.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/71345732b81be9a093d4dd6409030b5d3e91e1ea...b462b01f7f92a361d92233a8c2d326276c2d91a3)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`38d3906`](https://github.com/OZI-Project/OZI/commit/38d39068b4c6004eafa8e24c180214b8b464cfeb))

* Update dev-workflow.yml — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`e431088`](https://github.com/OZI-Project/OZI/commit/e4310885c063b596bd8d8c557b29717ba6700012))

* Create purge-artifacts.yml — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`cf583e0`](https://github.com/OZI-Project/OZI/commit/cf583e0ff1ec44b27508223d83c4c68bc3edeb0f))

* Bump github/codeql-action from 3.27.6 to 3.27.9

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.27.6 to 3.27.9.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/aa578102511db1f4524ed59b8cc2bae4f6e88195...df409f7d9260372bd5f19e5b04e83cb3c43714ae)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`a05492d`](https://github.com/OZI-Project/OZI/commit/a05492d09f1289bcdac7a886a82c0105f420007f))

* Update flake8-bugbear requirement in /ozi/lint/flake8

Updates the requirements on [flake8-bugbear](https://github.com/PyCQA/flake8-bugbear) to permit the latest version.
- [Release notes](https://github.com/PyCQA/flake8-bugbear/releases)
- [Commits](https://github.com/PyCQA/flake8-bugbear/compare/24.10.31...24.12.12)


updated-dependencies:
- dependency-name: flake8-bugbear
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`eb1f7ce`](https://github.com/OZI-Project/OZI/commit/eb1f7ce9f8ba8ad93253e970b1267439b5fd9da4))

* Update SECURITY.md — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`ddf56fe`](https://github.com/OZI-Project/OZI/commit/ddf56fef35ed4960f62656b802fe6fd1c6b92c03))

## 1.27.0 (2024-12-11)


### ⬆️ Upgraded Dependencies

*  Update python-semantic-release requirement

Updates the requirements on [python-semantic-release](https://github.com/python-semantic-release/python-semantic-release) to permit the latest version.
- [Release notes](https://github.com/python-semantic-release/python-semantic-release/releases)
- [Changelog](https://github.com/python-semantic-release/python-semantic-release/blob/master/CHANGELOG.md)
- [Commits](https://github.com/python-semantic-release/python-semantic-release/compare/v9.14...v9.15)


updated-dependencies:
- dependency-name: python-semantic-release
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`f331294`](https://github.com/OZI-Project/OZI/commit/f331294f04e901c6862adc9618a8bc3e57ac9e91))


### Other


* 1.27.0

Automatically generated by python-semantic-release
([`df7c98d`](https://github.com/OZI-Project/OZI/commit/df7c98d90cb1ed054b0055e381d2e779c8b23122))

* Bump OZI-Project/publish from 1.5.0 to 1.6.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.5.0 to 1.6.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/3ff1ebdd9edd89b30c126e0cf78e2d9754c0f9fa...e5fa598dca4f35b10e8071e1050c332c3263e11d)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`fe3467d`](https://github.com/OZI-Project/OZI/commit/fe3467dd59d2b92fae32daac5fe97b30334808c2))

* Bump OZI-Project/draft from 1.5.0 to 1.6.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.5.0 to 1.6.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/e872ff9cded28eb22d937ba3fd9abfe4fc489239...71345732b81be9a093d4dd6409030b5d3e91e1ea)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`e3251bc`](https://github.com/OZI-Project/OZI/commit/e3251bc13041c22eb325424060f707faf7cc9308))

* Update ozi-core requirement from ~=1.5.23 to ~=1.6.0

Updates the requirements on [ozi-core](https://github.com/OZI-Project/ozi-core) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/1.6.0/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.5.23...1.6.0)


updated-dependencies:
- dependency-name: ozi-core
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`a8c10b9`](https://github.com/OZI-Project/OZI/commit/a8c10b9aeb7e5437dc49aa147827f6e79aadceab))

* Update ozi-build[core,uv] requirement from ~=1.7.2 to ~=1.8.0

Updates the requirements on [ozi-build[core,uv]](https://github.com/OZI-Project/OZI.build) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/OZI.build/releases)
- [Commits](https://github.com/OZI-Project/OZI.build/compare/1.7.2...1.8.0)


updated-dependencies:
- dependency-name: ozi-build[core,uv]
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`045f178`](https://github.com/OZI-Project/OZI/commit/045f178b77cf0133d821a8687b871b9868ac9124))

## 1.26.1 (2024-12-07)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.27.5 to 3.27.6

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.27.5 to 3.27.6.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/f09c1c0a94de965c15400f5634aa42fac8fb8f88...aa578102511db1f4524ed59b8cc2bae4f6e88195)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`3a0de5f`](https://github.com/OZI-Project/OZI/commit/3a0de5f72281c2c0b198de7ab7cf95a57eb70aa7))

*  ozi-core~=1.5.23 — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`d707fdf`](https://github.com/OZI-Project/OZI/commit/d707fdffe6f70f926bd73d8d9b45b47ead62303f))


### 🔨 Updated Scripts

*  extract utility functions from release task — rjdbcm <ozi.project@outlook.com>
([`78aae0c`](https://github.com/OZI-Project/OZI/commit/78aae0c4c04a20d067b992d903dce473477b8317))


### Other


* 1.26.1

Automatically generated by python-semantic-release
([`d45798e`](https://github.com/OZI-Project/OZI/commit/d45798eac3cebde5a69c55e5ef9260781bf2c996))

* build: update tox OZI.build version to 1.7.2 — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`958186c`](https://github.com/OZI-Project/OZI/commit/958186cfe18c814281c9160f66455303af2d820c))

* Update ozi-build[core,uv] requirement from ~=1.6.1 to ~=1.7.2

Updates the requirements on [ozi-build[core,uv]](https://github.com/OZI-Project/OZI.build) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/OZI.build/releases)
- [Commits](https://github.com/OZI-Project/OZI.build/commits)


updated-dependencies:
- dependency-name: ozi-build[core,uv]
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`1fe70e3`](https://github.com/OZI-Project/OZI/commit/1fe70e36b49e10adcee3dd3db8c0b5d52f8dbab1))

* Update SECURITY.md — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`766ac6c`](https://github.com/OZI-Project/OZI/commit/766ac6c59cf5d15d8ea66484103f3b86f496a570))

* Update .codeclimate.yml — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`f59455b`](https://github.com/OZI-Project/OZI/commit/f59455bc35f3dfc8962a0440562965ce87ba463d))

* Update tasks.py — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`be4a809`](https://github.com/OZI-Project/OZI/commit/be4a8098bef0998d104ceb07c1a952b3cccde60e))

## 1.26.0 (2024-12-01)


### ⬆️ Upgraded Dependencies

*  ozi-core~=1.5.22 — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`7be5070`](https://github.com/OZI-Project/OZI/commit/7be5070b9ab9d12125bdd116e3aa42a9a78dc01c))


### 🐛 Fixed Bugs

*  ignore errant feature bump commit pattern  — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`163a093`](https://github.com/OZI-Project/OZI/commit/163a0935e956fc88be407c9cde1cbb145c56176d))

*  retry release — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`7df65f7`](https://github.com/OZI-Project/OZI/commit/7df65f774b6b90d0b95c41f61d72d22e83dc94eb))


### Other


* 1.26.0

Automatically generated by python-semantic-release
([`449191a`](https://github.com/OZI-Project/OZI/commit/449191a0d58cc70905e5fcdd944ca4e59d27b583))

* 1.26.0

Automatically generated by python-semantic-release
([`1efd366`](https://github.com/OZI-Project/OZI/commit/1efd366f4b467057d4e223141816ae14cf89d993))

* cryptography~=43.0 — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`bc2cfb6`](https://github.com/OZI-Project/OZI/commit/bc2cfb693635aa77b855b185d06eb7de6037fa6a))

* cryptography~=43.0 — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`a4ee818`](https://github.com/OZI-Project/OZI/commit/a4ee8186dc5399c50f33caeb664894319274715d))

* cryptography~=43.0 — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`201df3a`](https://github.com/OZI-Project/OZI/commit/201df3ad1bf885fffc413002fd9df4fb68bb095b))

* 1.24.10

Automatically generated by python-semantic-release
([`9e858f8`](https://github.com/OZI-Project/OZI/commit/9e858f882510094a8bad2ef50311c90a9c05f01c))

## 1.25.6 (2024-11-28)


### Other


* 1.25.6

Automatically generated by python-semantic-release
([`9328ded`](https://github.com/OZI-Project/OZI/commit/9328dedb4b6b116462135362bf060c04d6d24d68))

## 1.25.5 (2024-11-26)


### ⬆️ Upgraded Dependencies

*  Update cryptography requirement in /ozi/dist/cibuildwheel

Updates the requirements on [cryptography](https://github.com/pyca/cryptography) to permit the latest version.
- [Changelog](https://github.com/pyca/cryptography/blob/main/CHANGELOG.rst)
- [Commits](https://github.com/pyca/cryptography/compare/43.0.0...44.0.0)


updated-dependencies:
- dependency-name: cryptography
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`c19cf65`](https://github.com/OZI-Project/OZI/commit/c19cf65d7ff773a2f9380a00f4768f38dd30d1d7))

*  Update cryptography requirement in /ozi/dist/semantic_release

Updates the requirements on [cryptography](https://github.com/pyca/cryptography) to permit the latest version.
- [Changelog](https://github.com/pyca/cryptography/blob/main/CHANGELOG.rst)
- [Commits](https://github.com/pyca/cryptography/compare/43.0.0...44.0.0)


updated-dependencies:
- dependency-name: cryptography
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`5912fa0`](https://github.com/OZI-Project/OZI/commit/5912fa059f372b649890cda181aa5bda039be746))

*  Update cryptography requirement in /ozi/dist/sigstore

Updates the requirements on [cryptography](https://github.com/pyca/cryptography) to permit the latest version.
- [Changelog](https://github.com/pyca/cryptography/blob/main/CHANGELOG.rst)
- [Commits](https://github.com/pyca/cryptography/compare/43.0.0...44.0.0)


updated-dependencies:
- dependency-name: cryptography
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`f1285eb`](https://github.com/OZI-Project/OZI/commit/f1285eb1de1adcdcc6e67c7d4be25c24a8ef7afa))

*  Update hypothesis[cli,codemods,ghostwriter] requirement

Updates the requirements on [hypothesis[cli,codemods,ghostwriter]](https://github.com/HypothesisWorks/hypothesis) to permit the latest version.
- [Release notes](https://github.com/HypothesisWorks/hypothesis/releases)
- [Commits](https://github.com/HypothesisWorks/hypothesis/compare/hypothesis-python-6.120.0...hypothesis-python-6.122.0)


updated-dependencies:
- dependency-name: hypothesis[cli,codemods,ghostwriter]
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`2e192c2`](https://github.com/OZI-Project/OZI/commit/2e192c2a37f9f73d6a062fa82500217161099c1a))

*  Update bandit[toml] requirement in /ozi/lint/bandit

Updates the requirements on [bandit[toml]](https://github.com/PyCQA/bandit) to permit the latest version.
- [Release notes](https://github.com/PyCQA/bandit/releases)
- [Commits](https://github.com/PyCQA/bandit/compare/1.7.0...1.8.0)


updated-dependencies:
- dependency-name: bandit[toml]
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`0177aa2`](https://github.com/OZI-Project/OZI/commit/0177aa202a2ad938f7e9e3931bee77a0c3eb5408))

*  Update hypothesis[cli,codemods,ghostwriter] requirement

Updates the requirements on [hypothesis[cli,codemods,ghostwriter]](https://github.com/HypothesisWorks/hypothesis) to permit the latest version.
- [Release notes](https://github.com/HypothesisWorks/hypothesis/releases)
- [Commits](https://github.com/HypothesisWorks/hypothesis/compare/hypothesis-python-6.119.0...hypothesis-python-6.120.0)


updated-dependencies:
- dependency-name: hypothesis[cli,codemods,ghostwriter]
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`8c5754c`](https://github.com/OZI-Project/OZI/commit/8c5754c3e7561b206339d14381eb81f28f3b2d2e))

*  Update cibuildwheel requirement in /ozi/dist/cibuildwheel

Updates the requirements on [cibuildwheel](https://github.com/pypa/cibuildwheel) to permit the latest version.
- [Release notes](https://github.com/pypa/cibuildwheel/releases)
- [Changelog](https://github.com/pypa/cibuildwheel/blob/main/docs/changelog.md)
- [Commits](https://github.com/pypa/cibuildwheel/compare/v2.21...v2.22)


updated-dependencies:
- dependency-name: cibuildwheel
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`ee6d69b`](https://github.com/OZI-Project/OZI/commit/ee6d69b5333d45be3129103e11103075dc77979b))


### Other


* 1.25.5

Automatically generated by python-semantic-release
([`02d54f2`](https://github.com/OZI-Project/OZI/commit/02d54f27e1e1e54ac8370ad879e09d8ff0f31751))

* build(dist): cryptography~=43.0 — rjdbcm <ozi.project@outlook.com>
([`9bddaa9`](https://github.com/OZI-Project/OZI/commit/9bddaa9a8d8fcd8e8a83de0b5e4db8f2d263552d))

* build(dist): cryptography~=43.0 — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`0cedb3e`](https://github.com/OZI-Project/OZI/commit/0cedb3e34763606eb93d8ed81698418dc8c05247))

* Create .codeclimate.yml — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`4fbf939`](https://github.com/OZI-Project/OZI/commit/4fbf9395685992b35d0f81d26d1e0d3a6dfd1bb2))

## 1.25.4 (2024-11-25)


### ⬆️ Upgraded Dependencies

* ozi-core~=1.5.21 — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`2aaaa72`](https://github.com/OZI-Project/OZI/commit/2aaaa72a2fa089490f9443d861b4393cade10fdc))


### Other


* 1.25.4

Automatically generated by python-semantic-release
([`111fd6b`](https://github.com/OZI-Project/OZI/commit/111fd6b88ea3cb549cfeba35c5bdf8b2ca54850e))

## 1.25.3 (2024-11-25)


### ⬆️ Upgraded Dependencies

* ozi-core~=1.5.20 — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`96e1767`](https://github.com/OZI-Project/OZI/commit/96e17673ed2f77d1c96b1225978087053e3399a1))


### Other


* 1.25.3

Automatically generated by python-semantic-release
([`0b8a5f2`](https://github.com/OZI-Project/OZI/commit/0b8a5f2796a61cdbc47db58a5997707a732b17d0))

* Update SECURITY.md — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`8ad9b7c`](https://github.com/OZI-Project/OZI/commit/8ad9b7c98a4939a39888b5b1d2e0e3837f142869))

## 1.25.2 (2024-11-21)


### ⬆️ Upgraded Dependencies

*  Bump step-security/harden-runner from 2.10.1 to 2.10.2

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.10.1 to 2.10.2.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/91182cccc01eb5e619899d80e4e971d6181294a7...0080882f6c36860b6ba35c610c98ce87d4e2f26f)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`9b23f16`](https://github.com/OZI-Project/OZI/commit/9b23f16f4dbf0e4a552cbb559b01e1395549e792))

*  Bump github/codeql-action from 3.27.4 to 3.27.5

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.27.4 to 3.27.5.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/ea9e4e37992a54ee68a9622e985e60c8e8f12d9f...f09c1c0a94de965c15400f5634aa42fac8fb8f88)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`3b7a3d2`](https://github.com/OZI-Project/OZI/commit/3b7a3d257dcf78bc8407d33668bc7401c6dd7a19))

*  Bump actions/dependency-review-action from 4.4.0 to 4.5.0

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.4.0 to 4.5.0.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/4081bf99e2866ebe428fc0477b69eb4fcda7220a...3b139cfc5fae8b618d3eae3675e383bb1769c019)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`4977ae5`](https://github.com/OZI-Project/OZI/commit/4977ae55954d79fa436721f1952c208502aff2d6))

* ozi-core~=1.5.16, add ``--uninstall-user-files`` option to ``ozi`` — rjdbcm <ozi.project@outlook.com>
([`8022dae`](https://github.com/OZI-Project/OZI/commit/8022daee1b46a4131912e31cfef84bafda3a1182))


### Other


* 1.25.2

Automatically generated by python-semantic-release
([`5764dfe`](https://github.com/OZI-Project/OZI/commit/5764dfeb57543b3b1cfb8a1c68c7f76d45af65fb))

* run black — rjdbcm <ozi.project@outlook.com>
([`2f1c2fe`](https://github.com/OZI-Project/OZI/commit/2f1c2fec4a7b8faa61dbae2d47c3bac6c20ca524))

## 1.25.1 (2024-11-15)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.27.3 to 3.27.4

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.27.3 to 3.27.4.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/396bb3e45325a47dd9ef434068033c6d5bb0d11a...ea9e4e37992a54ee68a9622e985e60c8e8f12d9f)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`a8c4da9`](https://github.com/OZI-Project/OZI/commit/a8c4da9800700809b624d09867894199301a452d))

*  Update hypothesis[cli,codemods,ghostwriter] requirement

Updates the requirements on [hypothesis[cli,codemods,ghostwriter]](https://github.com/HypothesisWorks/hypothesis) to permit the latest version.
- [Release notes](https://github.com/HypothesisWorks/hypothesis/releases)
- [Commits](https://github.com/HypothesisWorks/hypothesis/compare/hypothesis-python-6.118.0...hypothesis-python-6.119.0)


updated-dependencies:
- dependency-name: hypothesis[cli,codemods,ghostwriter]
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`bea54ec`](https://github.com/OZI-Project/OZI/commit/bea54ec140bb089a1842ec134939b5c83a350742))


### Other


* 1.25.1

Automatically generated by python-semantic-release
([`5b45ded`](https://github.com/OZI-Project/OZI/commit/5b45ded995e226585219345a94b6cb323734d9cf))

* Update SECURITY.md — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`cb23644`](https://github.com/OZI-Project/OZI/commit/cb236448e9a2b606e3f50a513e2e727025f7c9f5))

## 1.25.0 (2024-11-15)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/publish

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 5e8ac4ee1e29644949dc641c8c52d31fa2ed01fd to 3ff1ebdd9edd89b30c126e0cf78e2d9754c0f9fa.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/5e8ac4ee1e29644949dc641c8c52d31fa2ed01fd...3ff1ebdd9edd89b30c126e0cf78e2d9754c0f9fa)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`b5c1b68`](https://github.com/OZI-Project/OZI/commit/b5c1b6827f82e752969bc33ab99c79a19e251e81))

*  Bump OZI-Project/draft from 1.4.1 to 1.5.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.4.1 to 1.5.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/9b883f1803600651f4cf46c98c767c5efe9bad48...e872ff9cded28eb22d937ba3fd9abfe4fc489239)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`8ffe9bd`](https://github.com/OZI-Project/OZI/commit/8ffe9bda7a8057462bba8b2cf65f41dae5d2a1c7))

*  Bump OZI-Project/release from 1.0.4 to 1.0.5

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.0.4 to 1.0.5.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/74350f112641257ed33f06f83c3e6fc7ae92059b...1a3cb28a9a9d51fa8e333740a8b863c0f23ab3da)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`13460ed`](https://github.com/OZI-Project/OZI/commit/13460ed9d3b99f89415310862d442ac7e68a9087))

*  Update ozi-core requirement from ~=1.4.6 to ~=1.5.0

Updates the requirements on [ozi-core](https://github.com/OZI-Project/ozi-core) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/1.5.0/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.4.6...1.5.0)


updated-dependencies:
- dependency-name: ozi-core
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`361f75c`](https://github.com/OZI-Project/OZI/commit/361f75c627284df8815da9a0637471bf73af48ca))

*  Bump OZI-Project/checkpoint from 1.1.3 to 1.2.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.1.3 to 1.2.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/b6d5ac262ad76c8bc51d7474d630260e0403117c...32b9310f480343c946214e3ea4b637202eaa312a)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`46006d8`](https://github.com/OZI-Project/OZI/commit/46006d8c89b6402e25160bd6b1f39f82df66287c))

*  Bump github/codeql-action from 3.27.2 to 3.27.3

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.27.2 to 3.27.3.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/9278e421667d5d90a2839487a482448c4ec7df4d...396bb3e45325a47dd9ef434068033c6d5bb0d11a)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`7d915e4`](https://github.com/OZI-Project/OZI/commit/7d915e48ac0f8bd4aa609aeaf85b7bf45181081f))

*  Bump github/codeql-action from 3.27.1 to 3.27.2

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.27.1 to 3.27.2.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/4f3212b61783c3c68e8309a0f18a699764811cda...9278e421667d5d90a2839487a482448c4ec7df4d)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`6894b8d`](https://github.com/OZI-Project/OZI/commit/6894b8d7aee496d91910381b3ec58423a221f5e9))

*  Update python-semantic-release requirement

Updates the requirements on [python-semantic-release](https://github.com/python-semantic-release/python-semantic-release) to permit the latest version.
- [Release notes](https://github.com/python-semantic-release/python-semantic-release/releases)
- [Changelog](https://github.com/python-semantic-release/python-semantic-release/blob/master/CHANGELOG.md)
- [Commits](https://github.com/python-semantic-release/python-semantic-release/compare/v9.12...v9.14)


updated-dependencies:
- dependency-name: python-semantic-release
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`99a6663`](https://github.com/OZI-Project/OZI/commit/99a6663f4b205a8d0a9de1e051a45eb734ce7343))


### 📌 Pinned Dependencies

* (twine): cryptography~=43.0 — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`899334d`](https://github.com/OZI-Project/OZI/commit/899334dbae9d81b485b3635d07d4588b268c2e6e))


### Other


* 1.25.0

Automatically generated by python-semantic-release
([`d89b118`](https://github.com/OZI-Project/OZI/commit/d89b1182be3ab33da926181190b2152a9fce0408))

* 1.24.9

Automatically generated by python-semantic-release
([`d9ab9c2`](https://github.com/OZI-Project/OZI/commit/d9ab9c243a5902a632993ff773c436f09f4f114a))

## 1.24.8 (2024-11-12)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/checkpoint from 1.1.1 to 1.1.3

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.1.1 to 1.1.3.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/ac0c03fc08ac2e7e4b4fbdf02249109384596313...b6d5ac262ad76c8bc51d7474d630260e0403117c)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`1d53518`](https://github.com/OZI-Project/OZI/commit/1d5351897b2acd2e7794908db628d568aa5491cc))

*  Bump OZI-Project/draft from 1.4.0 to 1.4.1

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.4.0 to 1.4.1.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/d797368c9870f3ca16373680b52db1ed4c333f21...9b883f1803600651f4cf46c98c767c5efe9bad48)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`c9d04cc`](https://github.com/OZI-Project/OZI/commit/c9d04ccd47defd2a67a48b6dd6887138ff6e126f))

*  Bump github/codeql-action from 3.27.0 to 3.27.1

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.27.0 to 3.27.1.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/662472033e021d55d94146f66f6058822b0b39fd...4f3212b61783c3c68e8309a0f18a699764811cda)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`bf24dfd`](https://github.com/OZI-Project/OZI/commit/bf24dfddeabac508c3b6ca2dcea6ec3b5b927e33))

*  Bump OZI-Project/publish

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from c5720ae47546df65ca1dcffd5a097f266928b453 to 5e8ac4ee1e29644949dc641c8c52d31fa2ed01fd.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/c5720ae47546df65ca1dcffd5a097f266928b453...5e8ac4ee1e29644949dc641c8c52d31fa2ed01fd)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`a5e5eda`](https://github.com/OZI-Project/OZI/commit/a5e5edaa689e7b505b8691c47cbf3c7421918286))

*  Update ozi-build[core,uv] requirement from ~=1.5.2 to ~=1.6.1


updated-dependencies:
- dependency-name: ozi-build[core,uv]
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`0bdf4fd`](https://github.com/OZI-Project/OZI/commit/0bdf4fd8c90744b6e7e55b3911469c1c8478efa8))

*  Update hypothesis[cli,codemods,ghostwriter] requirement

Updates the requirements on [hypothesis[cli,codemods,ghostwriter]](https://github.com/HypothesisWorks/hypothesis) to permit the latest version.
- [Release notes](https://github.com/HypothesisWorks/hypothesis/releases)
- [Commits](https://github.com/HypothesisWorks/hypothesis/compare/hypothesis-python-6.116.0...hypothesis-python-6.118.0)


updated-dependencies:
- dependency-name: hypothesis[cli,codemods,ghostwriter]
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`5ab6874`](https://github.com/OZI-Project/OZI/commit/5ab687475ed071857d76e51c124718588b4e98ad))

*  Bump OZI-Project/publish from 1.4.1 to 1.4.2

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.4.1 to 1.4.2.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/42b2c7502712c4bfec2bebf507c01282ce769912...c5720ae47546df65ca1dcffd5a097f266928b453)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`ccd2165`](https://github.com/OZI-Project/OZI/commit/ccd2165cbc95b3944929a317551ef6a8a2add94b))


### 🐛 Fixed Bugs

* 🚸: improved cross-platform compatibility of scripts and tasks.py tasks — rjdbcm <ozi.project@outlook.com>
([`d4eb0f3`](https://github.com/OZI-Project/OZI/commit/d4eb0f3bd2da6dcd006ed57037992b842674a86f))


### Other


* 1.24.8

Automatically generated by python-semantic-release
([`a835365`](https://github.com/OZI-Project/OZI/commit/a835365fe01eed7e3595250e86a2161001e9b0e0))

## 1.24.7 (2024-11-07)


### ✏️ Corrected Typos

*  fix quotes
([`4a0af75`](https://github.com/OZI-Project/OZI/commit/4a0af75b8f84d088efd6e753239ca39c18bafb1b))


### Other


* 1.24.7

Automatically generated by python-semantic-release
([`78fe4e4`](https://github.com/OZI-Project/OZI/commit/78fe4e4d09212ae243091f98022de9f0b4bc00dc))

## 1.24.6 (2024-11-07)


### ✏️ Corrected Typos

*  fix rewrite task — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`998d74b`](https://github.com/OZI-Project/OZI/commit/998d74b1ee21c704979bd58276c5a1ebd44a7aad))


### Other


* 1.24.6

Automatically generated by python-semantic-release
([`550cc7b`](https://github.com/OZI-Project/OZI/commit/550cc7b1844bf9a734c6fe00ca13f1980d89f29d))

## 1.24.5 (2024-11-06)


### 🐛 Fixed Bugs

*  force patch — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`c8ce3a4`](https://github.com/OZI-Project/OZI/commit/c8ce3a4e4b86442d5f647b6951c3f22a2f8ee79d))


### Other


* 1.24.5

Automatically generated by python-semantic-release
([`fc3f99c`](https://github.com/OZI-Project/OZI/commit/fc3f99cc1f18105e340416d62f92c7c42add0634))

* Bump OZI-Project/publish from 1.4.0 to 1.4.1

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.4.0 to 1.4.1.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/a8bb776353d5b9f9bd678ef5ab2cd38bf5d4ad0f...42b2c7502712c4bfec2bebf507c01282ce769912)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`1692320`](https://github.com/OZI-Project/OZI/commit/1692320d8ce85c1796c8190f8353e80a5c705b2e))

* 1.24.5

Automatically generated by python-semantic-release
([`4e85662`](https://github.com/OZI-Project/OZI/commit/4e8566251be4853f518b3f4d1b9796f3a650a54b))

* 👷 add github.com:443 endpoint to publish — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`57273a2`](https://github.com/OZI-Project/OZI/commit/57273a2c8a7972443b57485fc1537c9d44329100))

* 1.24.5

Automatically generated by python-semantic-release
([`d1636ab`](https://github.com/OZI-Project/OZI/commit/d1636ab5d4fcd481e755f14e0ffd700fdecc1039))

* perf: add a rewrite task to invoke tasklist — rjdbcm <ozi.project@outlook.com>
([`d5355e0`](https://github.com/OZI-Project/OZI/commit/d5355e015b12a059aa2b92af137164508ad6b51f))

* Update SECURITY.md — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`a713129`](https://github.com/OZI-Project/OZI/commit/a713129b2c39e92fe514dc479cd283a99b2531e8))

## 1.24.4 (2024-11-02)


### ⬆️ Upgraded Dependencies

*  Update ozi-core requirement from ~=1.4.5 to ~=1.4.6 — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`be0441f`](https://github.com/OZI-Project/OZI/commit/be0441fb680c4c439905ed8018dfdf17990eb0dc))

*  Update hypothesis[cli,codemods,ghostwriter] requirement

Updates the requirements on [hypothesis[cli,codemods,ghostwriter]](https://github.com/HypothesisWorks/hypothesis) to permit the latest version.
- [Release notes](https://github.com/HypothesisWorks/hypothesis/releases)
- [Commits](https://github.com/HypothesisWorks/hypothesis/compare/hypothesis-python-6.115.0...hypothesis-python-6.116.0)


updated-dependencies:
- dependency-name: hypothesis[cli,codemods,ghostwriter]
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`785d000`](https://github.com/OZI-Project/OZI/commit/785d00092120a82b8fb07d6f6f3a506d3e76688e))

*  Update flake8-bugbear requirement in /ozi/lint/flake8

Updates the requirements on [flake8-bugbear](https://github.com/PyCQA/flake8-bugbear) to permit the latest version.
- [Release notes](https://github.com/PyCQA/flake8-bugbear/releases)
- [Commits](https://github.com/PyCQA/flake8-bugbear/compare/24.8.19...24.10.31)


updated-dependencies:
- dependency-name: flake8-bugbear
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`ed183a1`](https://github.com/OZI-Project/OZI/commit/ed183a1bf13738b4e4a63e56a71ae6b027e2b11e))


### Other


* 1.24.4

Automatically generated by python-semantic-release
([`1a63e62`](https://github.com/OZI-Project/OZI/commit/1a63e6288be54a73e31d9b9942e32ede3ba74357))

## 1.24.3 (2024-10-31)


### ⬆️ Upgraded Dependencies

*  Update pytest-cov requirement in /ozi/test/pytest

Updates the requirements on [pytest-cov](https://github.com/pytest-dev/pytest-cov) to permit the latest version.
- [Changelog](https://github.com/pytest-dev/pytest-cov/blob/master/CHANGELOG.rst)
- [Commits](https://github.com/pytest-dev/pytest-cov/compare/v5.0.0...v6.0.0)


updated-dependencies:
- dependency-name: pytest-cov
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`8812526`](https://github.com/OZI-Project/OZI/commit/8812526ee072511a7d00645094cc314853ef4ac9))


### 🔨 Updated Scripts

*  add rekor.sigstore.dev:443 endpoint — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`c165656`](https://github.com/OZI-Project/OZI/commit/c1656563a7f3340e23b93763d37d59680687a404))

*  add fulcio.sigstore.dev:443 endpoint — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`3e247f3`](https://github.com/OZI-Project/OZI/commit/3e247f3963194e2347447ff24f47b8cd5fc85cb0))

*  add tuf-repo-cdn.sigstore.dev:443 endpoint — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`ea939d5`](https://github.com/OZI-Project/OZI/commit/ea939d580d7f14c33ce0a46747061e45371af5c4))


### Other


* 1.24.3

Automatically generated by python-semantic-release
([`061c378`](https://github.com/OZI-Project/OZI/commit/061c378801c78ca191267c103dc2cc7682e5615e))

* 1.24.3

Automatically generated by python-semantic-release
([`31adc82`](https://github.com/OZI-Project/OZI/commit/31adc82eff9d6cfb6c9b9fef5ba40c4cd940b780))

* 1.24.3

Automatically generated by python-semantic-release
([`adbe6a0`](https://github.com/OZI-Project/OZI/commit/adbe6a067e38a7c3299de9113daeff49275e19fe))

* 1.24.3

Automatically generated by python-semantic-release
([`6a45dfb`](https://github.com/OZI-Project/OZI/commit/6a45dfb1e5d568ee5a030319b00204a1c84bd4f4))

## 1.24.2 (2024-10-29)


### ⬆️ Upgraded Dependencies

*  Update ozi-core requirement from ~=1.4.4 to ~=1.4.5 — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`b4b1a80`](https://github.com/OZI-Project/OZI/commit/b4b1a804fc32e57395cf6c223d58b20a5679a516))


### Other


* 1.24.2

Automatically generated by python-semantic-release
([`9e5cad7`](https://github.com/OZI-Project/OZI/commit/9e5cad786cb6ca245171f0d0c22829f8fe145e55))

## 1.24.1 (2024-10-28)


### ⬆️ Upgraded Dependencies

*  Update flake8-comprehensions requirement in /ozi/lint/flake8

Updates the requirements on [flake8-comprehensions](https://github.com/adamchainz/flake8-comprehensions) to permit the latest version.
- [Changelog](https://github.com/adamchainz/flake8-comprehensions/blob/main/CHANGELOG.rst)
- [Commits](https://github.com/adamchainz/flake8-comprehensions/compare/3.15.0...3.16.0)


updated-dependencies:
- dependency-name: flake8-comprehensions
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`ef1d7ec`](https://github.com/OZI-Project/OZI/commit/ef1d7ec2ee698b2063dae3d0fb24ffb282352bc9))

*  Update flake8-no-pep420 requirement in /ozi/lint/flake8

Updates the requirements on [flake8-no-pep420](https://github.com/adamchainz/flake8-no-pep420) to permit the latest version.
- [Changelog](https://github.com/adamchainz/flake8-no-pep420/blob/main/CHANGELOG.rst)
- [Commits](https://github.com/adamchainz/flake8-no-pep420/compare/2.7.0...2.8.0)


updated-dependencies:
- dependency-name: flake8-no-pep420
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`558b5d9`](https://github.com/OZI-Project/OZI/commit/558b5d955fa28de88dea6f4864f9a68bf1bf200f))

*  Update pytest-randomly requirement in /ozi/test/pytest

Updates the requirements on [pytest-randomly](https://github.com/pytest-dev/pytest-randomly) to permit the latest version.
- [Changelog](https://github.com/pytest-dev/pytest-randomly/blob/main/CHANGELOG.rst)
- [Commits](https://github.com/pytest-dev/pytest-randomly/compare/3.15.0...3.16.0)


updated-dependencies:
- dependency-name: pytest-randomly
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`44c93ee`](https://github.com/OZI-Project/OZI/commit/44c93ee3db376adc4f5ef9555059bf1e8f44f6de))

*  Update flake8-tidy-imports requirement in /ozi/lint/flake8

Updates the requirements on [flake8-tidy-imports](https://github.com/adamchainz/flake8-tidy-imports) to permit the latest version.
- [Changelog](https://github.com/adamchainz/flake8-tidy-imports/blob/main/CHANGELOG.rst)
- [Commits](https://github.com/adamchainz/flake8-tidy-imports/compare/4.10.0...4.11.0)


updated-dependencies:
- dependency-name: flake8-tidy-imports
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`e91c960`](https://github.com/OZI-Project/OZI/commit/e91c9600ce5ff4f0ee2e41ca11927f67d3c0c2ff))

*  Bump actions/dependency-review-action from 4.3.5 to 4.4.0

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.3.5 to 4.4.0.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/a6993e2c61fd5dc440b409aa1d6904921c5e1894...4081bf99e2866ebe428fc0477b69eb4fcda7220a)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`a05e35e`](https://github.com/OZI-Project/OZI/commit/a05e35e7c8920b80eb7254bfb0012284f08d1dd3))

*  Update ozi-core requirement from ~=1.4.2 to ~=1.4.4 — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`a96518b`](https://github.com/OZI-Project/OZI/commit/a96518bf52307434fa46647448b0194cbc586708))

*  Bump OZI-Project/checkpoint from 1.1.0 to 1.1.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.1.0 to 1.1.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/9548ffcc24d2016c7d0f6c1a6742f0cd65039884...ac0c03fc08ac2e7e4b4fbdf02249109384596313)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`48e2ed1`](https://github.com/OZI-Project/OZI/commit/48e2ed13b65c5f6716d2f8f7bad4b5a3805f748e))


### Other


* 1.24.1

Automatically generated by python-semantic-release
([`c167fe4`](https://github.com/OZI-Project/OZI/commit/c167fe49c5834e6e45fc06a930cb66363188caae))

* 👷 fix duplicate dependabot PRs — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`ed13f0a`](https://github.com/OZI-Project/OZI/commit/ed13f0a582c99fc88a552228b5e85ef98e01f157))

* Update SECURITY.md — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`fbc965b`](https://github.com/OZI-Project/OZI/commit/fbc965bf438cc7afb77f54adcc6f92bb3515eccf))

* Update SECURITY.md — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`68963d3`](https://github.com/OZI-Project/OZI/commit/68963d39f0547644012228054a53033c59fc60c8))

## 1.24.0 (2024-10-25)


### Other


* 1.24.0

Automatically generated by python-semantic-release
([`1ee2626`](https://github.com/OZI-Project/OZI/commit/1ee26263231c8fcf3523a44a2e7b56c2b8a6aaac))

## 1.23.4 (2024-10-25)


### ⬆️ Upgraded Dependencies

*  Update ozi-core requirement from ~=1.3.7 to ~=1.4.2

Updates the requirements on [ozi-core](https://github.com/OZI-Project/ozi-core) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/1.4.2/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.3.7...1.4.2)


updated-dependencies:
- dependency-name: ozi-core
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`f3cdfce`](https://github.com/OZI-Project/OZI/commit/f3cdfcea985bd1359fc541538e8a782d66f786d9))


### 🐛 Fixed Bugs

*  check that cibuildwheel result is not None — rjdbcm <ozi.project@outlook.com>
([`0199167`](https://github.com/OZI-Project/OZI/commit/019916742fbf4229ac7f5381003fb5fd4e0a56b4))


### Other


* 1.23.4

Automatically generated by python-semantic-release
([`032f883`](https://github.com/OZI-Project/OZI/commit/032f883e400407b38b59e83bbd44ab7acb91dda9))

* 🚨(tasks.py): ignore method complexity ``release()`` — rjdbcm <ozi.project@outlook.com>
([`8928939`](https://github.com/OZI-Project/OZI/commit/892893946a5ae77691ab3a4ae103621dbfe8116e))

## 1.23.3 (2024-10-24)


### ⬆️ Upgraded Dependencies

*  Bump actions/checkout from 4.2.1 to 4.2.2

Bumps [actions/checkout](https://github.com/actions/checkout) from 4.2.1 to 4.2.2.
- [Release notes](https://github.com/actions/checkout/releases)
- [Changelog](https://github.com/actions/checkout/blob/main/CHANGELOG.md)
- [Commits](https://github.com/actions/checkout/compare/eef61447b9ff4aafe5dcd4e0bbf5d482be7e7871...11bd71901bbe5b1630ceea73d27597364c9af683)


updated-dependencies:
- dependency-name: actions/checkout
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`ad36548`](https://github.com/OZI-Project/OZI/commit/ad365485088cd46957abed9ffaae1f917a1210c0))

*  Bump OZI-Project/checkpoint from 1.0.2 to 1.1.0

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.0.2 to 1.1.0.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/fff79a1993b9a0822e7b594dcbdb164a7cff4292...9548ffcc24d2016c7d0f6c1a6742f0cd65039884)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`1d9fe07`](https://github.com/OZI-Project/OZI/commit/1d9fe073bcbb8fc9a697a54f133b03bebe8d89c8))

*  ozi-core~=1.3.7 - fixes ozi-fix output — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`581e95a`](https://github.com/OZI-Project/OZI/commit/581e95aa58e2028123c07d8e767671475d72b272))

*  Bump actions/dependency-review-action from 4.3.4 to 4.3.5

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.3.4 to 4.3.5.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/5a2ce3f5b92ee19cbb1541a4984c76d921601d7c...a6993e2c61fd5dc440b409aa1d6904921c5e1894)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`9796567`](https://github.com/OZI-Project/OZI/commit/979656716945a9b69f84d0da0a1aa5c33868368f))

*  Bump github/codeql-action from 3.26.13 to 3.27.0

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.26.13 to 3.27.0.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/f779452ac5af1c261dce0346a8f964149f49322b...662472033e021d55d94146f66f6058822b0b39fd)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`a5e3f05`](https://github.com/OZI-Project/OZI/commit/a5e3f05559d23144c61e56f1912b4ae2d393b0b0))


### 🔨 Updated Scripts

* (tasks.py): only build wheel directly if cibuildwheel fails or is disabled — rjdbcm <ozi.project@outlook.com>
([`4565807`](https://github.com/OZI-Project/OZI/commit/45658071cc8a0c1e1c2f4e375bf473909e62db37))

* (tasks.py): only build wheel directly if cibuildwheel fails or is disabled — rjdbcm <ozi.project@outlook.com>
([`36931d7`](https://github.com/OZI-Project/OZI/commit/36931d73346feef91a6fada190e24dc0ea8ddf37))


### Other


* 1.23.3

Automatically generated by python-semantic-release
([`ea18cb4`](https://github.com/OZI-Project/OZI/commit/ea18cb4a8fa746ce4d9b645d2ffd9f5de2fe45e9))

* run black — rjdbcm <ozi.project@outlook.com>
([`4771d47`](https://github.com/OZI-Project/OZI/commit/4771d47df74434547ba3bc54244df56a51c8e824))

## 1.23.2 (2024-10-19)


### ⬆️ Upgraded Dependencies

*  ozi-core~=1.3.6 - fixes ``ozi-fix`` output — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`8c401cb`](https://github.com/OZI-Project/OZI/commit/8c401cb55770318983fd3874562977bad0fc40a9))


### Other


* 1.23.2

Automatically generated by python-semantic-release
([`b92fcfa`](https://github.com/OZI-Project/OZI/commit/b92fcfa00139284c69bc9e19fb6a998909763d54))

## 1.23.1 (2024-10-18)


### ⬆️ Upgraded Dependencies

*  Update python-semantic-release requirement

Updates the requirements on [python-semantic-release](https://github.com/python-semantic-release/python-semantic-release) to permit the latest version.
- [Release notes](https://github.com/python-semantic-release/python-semantic-release/releases)
- [Changelog](https://github.com/python-semantic-release/python-semantic-release/blob/master/CHANGELOG.md)
- [Commits](https://github.com/python-semantic-release/python-semantic-release/compare/v9.11...v9.12)


updated-dependencies:
- dependency-name: python-semantic-release
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`826cdae`](https://github.com/OZI-Project/OZI/commit/826cdaeb15167c51fa62e753288a0a925f68c153))

*  Bump OZI-Project/draft from 1.3.0 to 1.4.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.3.0 to 1.4.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/abc015e6e3bc08e765025befc25f2bd355ddb79d...d797368c9870f3ca16373680b52db1ed4c333f21)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`f83bc5a`](https://github.com/OZI-Project/OZI/commit/f83bc5ad08d497ed209eb3a84ef8972faebfdd35))

*  Bump OZI-Project/publish from 1.3.0 to 1.4.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.3.0 to 1.4.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/50e1883d3f02c37133eb0b38d726dff6b63554a0...a8bb776353d5b9f9bd678ef5ab2cd38bf5d4ad0f)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`216b6c9`](https://github.com/OZI-Project/OZI/commit/216b6c99cbf626296a7282cab22e9226ce5e45b9))

*  ozi-core~=1.3.4 — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`bfdb2f8`](https://github.com/OZI-Project/OZI/commit/bfdb2f88a1d9fe1a544e60387a7638b7d2f66bbb))


### Other


* 1.23.1

Automatically generated by python-semantic-release
([`aea95ce`](https://github.com/OZI-Project/OZI/commit/aea95cec80860e803ff367110320a6a35816aaa1))

* Update SECURITY.md — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`10c9e77`](https://github.com/OZI-Project/OZI/commit/10c9e77fef98988eaeec3bfb9e6743c6e15e9069))

## 1.23.0 (2024-10-14)


### ⬇️ Downgraded Dependencies

*  sigstore~=3.0

This should always match the version in sigstore/sigstore-gh-action used in OZI-Project/release and OZI-Project/checkpoint. — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`b8c5c88`](https://github.com/OZI-Project/OZI/commit/b8c5c8828d1b9ee7f67d985ca2856222c26699da))


### ⬆️ Upgraded Dependencies

*  ozi-core~=1.3.1 — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`26b789a`](https://github.com/OZI-Project/OZI/commit/26b789afa82b059cf9842323e2e670c05ad4ce0c))

*  Bump OZI-Project/checkpoint from 1.0.1 to 1.0.2

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.0.1 to 1.0.2.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/38b742bcf99a1eae353d2f750d23f7a0c0e2174d...fff79a1993b9a0822e7b594dcbdb164a7cff4292)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`74b4dc9`](https://github.com/OZI-Project/OZI/commit/74b4dc90b4835c8b3089cdd9ff990c331205ec5e))

*  Bump OZI-Project/release from 1.0.3 to 1.0.4

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.0.3 to 1.0.4.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/d764d82aa0900effc1590b0281ff35d67be592fd...74350f112641257ed33f06f83c3e6fc7ae92059b)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`814fa9d`](https://github.com/OZI-Project/OZI/commit/814fa9d7502a2a7e5687166a410802678d7f6a52))

*  Update python-semantic-release requirement

Updates the requirements on [python-semantic-release](https://github.com/python-semantic-release/python-semantic-release) to permit the latest version.
- [Release notes](https://github.com/python-semantic-release/python-semantic-release/releases)
- [Changelog](https://github.com/python-semantic-release/python-semantic-release/blob/master/CHANGELOG.md)
- [Commits](https://github.com/python-semantic-release/python-semantic-release/compare/v9.10...v9.11)


updated-dependencies:
- dependency-name: python-semantic-release
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`017f3c1`](https://github.com/OZI-Project/OZI/commit/017f3c183e473d83c0c50569a07c507e243b9a5c))

*  Update hypothesis[cli,codemods,ghostwriter] requirement

Updates the requirements on [hypothesis[cli,codemods,ghostwriter]](https://github.com/HypothesisWorks/hypothesis) to permit the latest version.
- [Release notes](https://github.com/HypothesisWorks/hypothesis/releases)
- [Commits](https://github.com/HypothesisWorks/hypothesis/compare/hypothesis-python-6.114.0...hypothesis-python-6.115.0)


updated-dependencies:
- dependency-name: hypothesis[cli,codemods,ghostwriter]
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`7d04ec9`](https://github.com/OZI-Project/OZI/commit/7d04ec9fc20e929de3db4b39978c36ec534049dc))

*  Bump OZI-Project/draft from 1.1.0 to 1.3.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.1.0 to 1.3.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/23eab64fb44d03215598b6fffcfff890bfb7ec4b...abc015e6e3bc08e765025befc25f2bd355ddb79d)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`19fcdc3`](https://github.com/OZI-Project/OZI/commit/19fcdc3230437de0e2709579b198c7b851bc373d))

*  Bump OZI-Project/publish from 1.1.0 to 1.3.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.1.0 to 1.3.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/6a44652f29d676922cf9e10d3ebc39b723078729...50e1883d3f02c37133eb0b38d726dff6b63554a0)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`4bd9f2a`](https://github.com/OZI-Project/OZI/commit/4bd9f2a27a1652b9bfb5639f03bdb1f110ac421c))

*  Bump github/codeql-action from 3.26.12 to 3.26.13

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.26.12 to 3.26.13.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/c36620d31ac7c881962c3d9dd939c40ec9434f2b...f779452ac5af1c261dce0346a8f964149f49322b)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`2a8c000`](https://github.com/OZI-Project/OZI/commit/2a8c000e26bc288ef695cad2510ad82f537a5b39))

*  Update ozi-core requirement from ~=1.2.15 to ~=1.3.0

Updates the requirements on [ozi-core](https://github.com/OZI-Project/ozi-core) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/1.3.0/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.2.15...1.3.0)


updated-dependencies:
- dependency-name: ozi-core
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`d0cd865`](https://github.com/OZI-Project/OZI/commit/d0cd865a00d2da0029eaba5df0384724a0e29738))

*  Update hypothesis[cli,codemods,ghostwriter] requirement

Updates the requirements on [hypothesis[cli,codemods,ghostwriter]](https://github.com/HypothesisWorks/hypothesis) to permit the latest version.
- [Release notes](https://github.com/HypothesisWorks/hypothesis/releases)
- [Commits](https://github.com/HypothesisWorks/hypothesis/compare/hypothesis-python-6.112.0...hypothesis-python-6.114.1)


updated-dependencies:
- dependency-name: hypothesis[cli,codemods,ghostwriter]
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`307724b`](https://github.com/OZI-Project/OZI/commit/307724b6a8ec5e9e19505f562936beab1b0eec46))


### ✨ Implemented Features

*  semantic-release 9.11 — rjdbcm <ozi.project@outlook.com>
([`89fb58a`](https://github.com/OZI-Project/OZI/commit/89fb58a06504dad07b555a3fe688a7618eca2573))


### Other


* 1.23.0

Automatically generated by python-semantic-release
([`2316395`](https://github.com/OZI-Project/OZI/commit/231639596264916a9fdb75241369dfb40642d3e2))

## 1.22.8 (2024-10-10)


### ⬆️ Upgraded Dependencies

*  ozi-core~=1.2.15

default to en locale — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`bc2c28a`](https://github.com/OZI-Project/OZI/commit/bc2c28a04d63d78699367a8a4674bda0fd359eb1))


### Other


* 1.22.8

Automatically generated by python-semantic-release
([`29aee9a`](https://github.com/OZI-Project/OZI/commit/29aee9ac77f4dfdd104efd4c0e645c6f464ce7ff))

## 1.22.7 (2024-10-10)


### ⬆️ Upgraded Dependencies

*  ozi-core~=1.2.14 — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`5c10bdc`](https://github.com/OZI-Project/OZI/commit/5c10bdcece1d2b6e2744fb5f67b69c0683223226))


### 🌐


* fix broken disclaimer — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`e4a9f42`](https://github.com/OZI-Project/OZI/commit/e4a9f422631a403ca974090ff04614094519137d))


### Other


* 1.22.7

Automatically generated by python-semantic-release
([`d0a060d`](https://github.com/OZI-Project/OZI/commit/d0a060d148870eff93acf9eaff93d298dce65b39))

## 1.22.6 (2024-10-09)


### ⬆️ Upgraded Dependencies

*  ozi-core~=1.2.13 — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`a4b14d8`](https://github.com/OZI-Project/OZI/commit/a4b14d83c7c0b83f6af0ab71eb8d31df4f3bfc16))

*  Bump actions/upload-artifact from 4.4.2 to 4.4.3

Bumps [actions/upload-artifact](https://github.com/actions/upload-artifact) from 4.4.2 to 4.4.3.
- [Release notes](https://github.com/actions/upload-artifact/releases)
- [Commits](https://github.com/actions/upload-artifact/compare/84480863f228bb9747b473957fcc9e309aa96097...b4b15b8c7c6ac21ea08fcf65892d2ee8f75cf882)


updated-dependencies:
- dependency-name: actions/upload-artifact
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`9f816ea`](https://github.com/OZI-Project/OZI/commit/9f816ea7b7f0e63bdfe88519ae7ab65299fc3b22))

*  ozi-core~=1.2.13 — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`1889462`](https://github.com/OZI-Project/OZI/commit/18894626dcb03f6be87cbb6a5415edac8b4cd7f9))


### Other


* 1.22.6

Automatically generated by python-semantic-release
([`b733718`](https://github.com/OZI-Project/OZI/commit/b733718bc1066a5c3cc4e4631bb92f11678286c4))

## 1.22.5 (2024-10-09)


### ⬆️ Upgraded Dependencies

*  ozi-core~=1.2.12 — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`3a0d320`](https://github.com/OZI-Project/OZI/commit/3a0d32009d73b6b88cd927ad1c509f40f6cbd3f5))

*  Update python-semantic-release requirement

Updates the requirements on [python-semantic-release](https://github.com/python-semantic-release/python-semantic-release) to permit the latest version.
- [Release notes](https://github.com/python-semantic-release/python-semantic-release/releases)
- [Changelog](https://github.com/python-semantic-release/python-semantic-release/blob/master/CHANGELOG.md)
- [Commits](https://github.com/python-semantic-release/python-semantic-release/compare/v9.8.0...v9.10)


updated-dependencies:
- dependency-name: python-semantic-release
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`d2475d7`](https://github.com/OZI-Project/OZI/commit/d2475d74c37a48c092d620536286c5fb9fa8afe1))


### Other


* 1.22.5

Automatically generated by python-semantic-release
([`74d208e`](https://github.com/OZI-Project/OZI/commit/74d208e25608380988d677db8d780bfd2c5a0432))

* 📄: fix main license detection — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`db874b3`](https://github.com/OZI-Project/OZI/commit/db874b34672a696d37c22ff342c7a3b1430dde6c))

* Update SECURITY.md — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`cf61868`](https://github.com/OZI-Project/OZI/commit/cf61868eb4c34d79b10fdeba2c17895235b44aed))

## 1.22.4 (2024-10-08)


### ⬆️ Upgraded Dependencies

*  ozi-core~=1.2.11 — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`7ddeecc`](https://github.com/OZI-Project/OZI/commit/7ddeeccd373f17371eeeb8094c65f24fd3b3d3f1))

*  Update black requirement in /ozi/lint/black

Updates the requirements on [black](https://github.com/psf/black) to permit the latest version.
- [Release notes](https://github.com/psf/black/releases)
- [Changelog](https://github.com/psf/black/blob/main/CHANGES.md)
- [Commits](https://github.com/psf/black/compare/24.8.0...24.10.0)


updated-dependencies:
- dependency-name: black
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`8cb36ee`](https://github.com/OZI-Project/OZI/commit/8cb36eeccbda4e842c71fd9b7c48399366246b79))

*  Bump actions/upload-artifact from 4.4.0 to 4.4.2

Bumps [actions/upload-artifact](https://github.com/actions/upload-artifact) from 4.4.0 to 4.4.2.
- [Release notes](https://github.com/actions/upload-artifact/releases)
- [Commits](https://github.com/actions/upload-artifact/compare/50769540e7f4bd5e21e526ee35c689e35e0d6874...84480863f228bb9747b473957fcc9e309aa96097)


updated-dependencies:
- dependency-name: actions/upload-artifact
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`ee0ca3c`](https://github.com/OZI-Project/OZI/commit/ee0ca3c47647f21c564c000fe6a8b1d57da8af1d))

*  Bump actions/checkout from 4.2.0 to 4.2.1

Bumps [actions/checkout](https://github.com/actions/checkout) from 4.2.0 to 4.2.1.
- [Release notes](https://github.com/actions/checkout/releases)
- [Changelog](https://github.com/actions/checkout/blob/main/CHANGELOG.md)
- [Commits](https://github.com/actions/checkout/compare/d632683dd7b4114ad314bca15554477dd762a938...eef61447b9ff4aafe5dcd4e0bbf5d482be7e7871)


updated-dependencies:
- dependency-name: actions/checkout
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`0cdc2f3`](https://github.com/OZI-Project/OZI/commit/0cdc2f3c5c2a8f865bf1cb8ce4293e5221a85792))

*  Bump github/codeql-action from 3.26.9 to 3.26.12

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.26.9 to 3.26.12.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/461ef6c76dfe95d5c364de2f431ddbd31a417628...c36620d31ac7c881962c3d9dd939c40ec9434f2b)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`764a3c0`](https://github.com/OZI-Project/OZI/commit/764a3c0ecd6b1392a582f14d4cb308e59db68bda))

*  Update python-semantic-release requirement

Updates the requirements on [python-semantic-release](https://github.com/python-semantic-release/python-semantic-release) to permit the latest version.
- [Release notes](https://github.com/python-semantic-release/python-semantic-release/releases)
- [Changelog](https://github.com/python-semantic-release/python-semantic-release/blob/master/CHANGELOG.md)
- [Commits](https://github.com/python-semantic-release/python-semantic-release/compare/v9.8.0...v9.9)


updated-dependencies:
- dependency-name: python-semantic-release
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`9d4ad19`](https://github.com/OZI-Project/OZI/commit/9d4ad195c4af5868802bc5d93e5a54b50259369b))


### Other


* 1.22.4

Automatically generated by python-semantic-release
([`08faaa1`](https://github.com/OZI-Project/OZI/commit/08faaa1d8d9c04eac3ba74f5f9596d459dd27e96))

## 1.22.3 (2024-10-06)


### ⬆️ Upgraded Dependencies

*  ozi-core~=1.2.7 — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`71a5a2c`](https://github.com/OZI-Project/OZI/commit/71a5a2c7fdf491e5fd04c22d12dcfb2f60a87431))


### Other


* 1.22.3

Automatically generated by python-semantic-release
([`8b7b0af`](https://github.com/OZI-Project/OZI/commit/8b7b0af481dd8dc615d869633103b5d7b5555258))

## 1.22.2 (2024-10-06)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/draft from 1.0.0 to 1.1.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.0.0 to 1.1.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/7e8ad70f472504510e169567e97db01bdafe2533...23eab64fb44d03215598b6fffcfff890bfb7ec4b)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`85a0aba`](https://github.com/OZI-Project/OZI/commit/85a0aba449c12d520446e29b8e7568fa450ff9fb))

*  Bump OZI-Project/release from 1.0.0 to 1.0.3

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.0.0 to 1.0.3.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/98248899bb8b235e3198105f080093ea5b9751d8...d764d82aa0900effc1590b0281ff35d67be592fd)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`fe98f9d`](https://github.com/OZI-Project/OZI/commit/fe98f9de3289b580ad185c934be92e848e72e398))

*  Bump actions/checkout from 4.1.7 to 4.2.0

Bumps [actions/checkout](https://github.com/actions/checkout) from 4.1.7 to 4.2.0.
- [Release notes](https://github.com/actions/checkout/releases)
- [Changelog](https://github.com/actions/checkout/blob/main/CHANGELOG.md)
- [Commits](https://github.com/actions/checkout/compare/692973e3d937129bcbf40652eb9f2f61becf3332...d632683dd7b4114ad314bca15554477dd762a938)


updated-dependencies:
- dependency-name: actions/checkout
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`81d6751`](https://github.com/OZI-Project/OZI/commit/81d67514d0f00f68b88afcc343957dee0bf21836))

*  ozi-core~=1.2.6

Adds i18n translation API. — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`059c68e`](https://github.com/OZI-Project/OZI/commit/059c68e831f46189bbae9fd5eb6fa47f105bbf2e))

*  Bump OZI-Project/checkpoint from 1.0.0 to 1.0.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.0.0 to 1.0.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/b53cf4f0aeb004d5980b72675fba6a38dcc66674...38b742bcf99a1eae353d2f750d23f7a0c0e2174d)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`f0d368a`](https://github.com/OZI-Project/OZI/commit/f0d368abcc80fe199070f13cc2c1fa02ccec166e))

*  Bump OZI-Project/publish from 1.0.0 to 1.1.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.0.0 to 1.1.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/55904e4f59084e7c6ccfad7b158db52a360e1f54...6a44652f29d676922cf9e10d3ebc39b723078729)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`b86b851`](https://github.com/OZI-Project/OZI/commit/b86b8511df0d86dcba4b707ed8a30fa49756c937))


### 🌐


*  complete localization of CLI

Includes simplified Chinese translation. — rjdbcm <ozi.project@outlook.com>
([`4006c35`](https://github.com/OZI-Project/OZI/commit/4006c35d2c52b86031e00149e0c9094cc3d40712))


### 🔨 Updated Scripts

*  clean up build files — rjdbcm <ozi.project@outlook.com>
([`def02f1`](https://github.com/OZI-Project/OZI/commit/def02f136eb1cecc4bdbb80c744b029e60b11603))


### Other


* 1.22.2

Automatically generated by python-semantic-release
([`394e803`](https://github.com/OZI-Project/OZI/commit/394e803999ba78241d571d9239b41a10abdf78d8))

* 🚨(mypy): ignore missing import ``ozi_core._i18n`` — rjdbcm <ozi.project@outlook.com>
([`f1ac4d8`](https://github.com/OZI-Project/OZI/commit/f1ac4d8257d5a08ec22bae4f5546b05651290252))

* 🚨 run isort — rjdbcm <ozi.project@outlook.com>
([`8379b0e`](https://github.com/OZI-Project/OZI/commit/8379b0e946b2f32e83fc4c26e9c22897966c7665))

## 1.22.1 (2024-09-25)


### ⬆️ Upgraded Dependencies

*  Update sigstore requirement in /ozi/dist/sigstore

Updates the requirements on [sigstore](https://github.com/sigstore/sigstore-python) to permit the latest version.
- [Release notes](https://github.com/sigstore/sigstore-python/releases)
- [Changelog](https://github.com/sigstore/sigstore-python/blob/main/CHANGELOG.md)
- [Commits](https://github.com/sigstore/sigstore-python/compare/v3.2.0...v3.3.0)


updated-dependencies:
- dependency-name: sigstore
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`e7b384d`](https://github.com/OZI-Project/OZI/commit/e7b384da421ec697f71d7c95ecb6aeadece07381))

*  Bump github/codeql-action from 3.26.7 to 3.26.9

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.26.7 to 3.26.9.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/8214744c546c1e5c8f03dde8fab3a7353211988d...461ef6c76dfe95d5c364de2f431ddbd31a417628)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`24926b9`](https://github.com/OZI-Project/OZI/commit/24926b99dac94f7d1ecf6bb878f994cc4ee1ce3a))

*  Update flake8-pyi requirement in /ozi/lint/flake8

Updates the requirements on [flake8-pyi](https://github.com/PyCQA/flake8-pyi) to permit the latest version.
- [Release notes](https://github.com/PyCQA/flake8-pyi/releases)
- [Changelog](https://github.com/PyCQA/flake8-pyi/blob/main/CHANGELOG.md)
- [Commits](https://github.com/PyCQA/flake8-pyi/compare/24.6.0...24.9.0)


updated-dependencies:
- dependency-name: flake8-pyi
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`5eafb78`](https://github.com/OZI-Project/OZI/commit/5eafb78c01967ea4f8f81497dddf8e338128e309))


### Other


* 1.22.1

Automatically generated by python-semantic-release
([`d614256`](https://github.com/OZI-Project/OZI/commit/d61425615cf87d2ef1b4a38035b64d8cfcd7dc48))

## 1.22.0 (2024-09-18)


### Other


* 1.22.0

Automatically generated by python-semantic-release
([`257f9f3`](https://github.com/OZI-Project/OZI/commit/257f9f3d71679e5def35065235bec05e1c3305d6))

## 1.21.0 (2024-09-11)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.26.6 to 3.26.7

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.26.6 to 3.26.7.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/4dd16135b69a43b6c8efb853346f8437d92d3c93...8214744c546c1e5c8f03dde8fab3a7353211988d)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`264f68a`](https://github.com/OZI-Project/OZI/commit/264f68ab5cf96a8dbe7afd0821de3fdedce01395))

*  Update ozi-core requirement from ~=1.1.1 to ~=1.2.0

Updates the requirements on [ozi-core](https://github.com/OZI-Project/ozi-core) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/1.2.0/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.1.1...1.2.0)


updated-dependencies:
- dependency-name: ozi-core
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`063e04a`](https://github.com/OZI-Project/OZI/commit/063e04a0646ee616b64aad501442cf4f1b3ae129))

*  Update cibuildwheel requirement in /ozi/dist/cibuildwheel

Updates the requirements on [cibuildwheel](https://github.com/pypa/cibuildwheel) to permit the latest version.
- [Release notes](https://github.com/pypa/cibuildwheel/releases)
- [Changelog](https://github.com/pypa/cibuildwheel/blob/main/docs/changelog.md)
- [Commits](https://github.com/pypa/cibuildwheel/compare/v2.20...v2.21)


updated-dependencies:
- dependency-name: cibuildwheel
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`56eaba2`](https://github.com/OZI-Project/OZI/commit/56eaba2e9cdf26a99fe3272c0ef7923aabca96e7))


### 🔨 Updated Configuration

* (semantic-release): change args to ``--help`` — rjdbcm <ozi.project@outlook.com>
([`db51734`](https://github.com/OZI-Project/OZI/commit/db51734b7557a6bda2e6ad3f438ee598fb263673))


### Other


* 1.21.0

Automatically generated by python-semantic-release
([`bc05f26`](https://github.com/OZI-Project/OZI/commit/bc05f26a7442370e8c45d2665cccefde5e1ff8ac))

* Update pyproject.toml — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`3708ccc`](https://github.com/OZI-Project/OZI/commit/3708cccd61934722d24e03b01b8c2463adadfcc4))

* Bump OZI-Project/checkpoint from 0.3.1 to 1.0.0

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.3.1 to 1.0.0.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/0.3.1...b53cf4f0aeb004d5980b72675fba6a38dcc66674)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] <support@github.com>
([`d29e853`](https://github.com/OZI-Project/OZI/commit/d29e853f38f0dd4dcc25ce78bcd77f625ecbee08))

* Bump step-security/harden-runner from 2.8.0 to 2.10.1

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.8.0 to 2.10.1.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/v2.8.0...91182cccc01eb5e619899d80e4e971d6181294a7)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`42744a6`](https://github.com/OZI-Project/OZI/commit/42744a663318752c5bdbdb99b8eed3d4e9f26de7))

* Update ozi-core requirement from ~=1.0.12 to ~=1.1.1

Updates the requirements on [ozi-core](https://github.com/OZI-Project/ozi-core) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-core/releases)
- [Changelog](https://github.com/OZI-Project/ozi-core/blob/1.1.1/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-core/compare/1.0.12...1.1.1)


updated-dependencies:
- dependency-name: ozi-core
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`aad5eae`](https://github.com/OZI-Project/OZI/commit/aad5eae09a0f0561820fa88d123a3c0062c9a13d))

* 👷(Python 3.13): use ``hypothesis[cli,codemods,ghostwriter]`` instead of ``hypothesis[all]`` — rjdbcm <ozi.project@outlook.com>
([`93c51ed`](https://github.com/OZI-Project/OZI/commit/93c51edd371a33aec1eafe69f0c4ec1e366bf247))

## 1.20.8 (2024-09-08)


### Other


* 1.20.8

Automatically generated by python-semantic-release
([`bdf19b5`](https://github.com/OZI-Project/OZI/commit/bdf19b5f8ec5cd702574888732dcc1340f730abc))

* Update README — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`2c4dd7b`](https://github.com/OZI-Project/OZI/commit/2c4dd7bfc34e313857a5ac4705513809d52c0eb3))

* 1.20.8

Automatically generated by python-semantic-release
([`413fc3e`](https://github.com/OZI-Project/OZI/commit/413fc3eb4bd8085f829601db677e76f4b6c421ad))

* 1.20.8

Automatically generated by python-semantic-release
([`d82f76c`](https://github.com/OZI-Project/OZI/commit/d82f76c1f6c7ec90a00893db46898f8a116d43dc))

* 1.20.8

Automatically generated by python-semantic-release
([`bff2064`](https://github.com/OZI-Project/OZI/commit/bff2064e46e8faa0678ed8e2ca2decc95e0f4e89))

* 1.20.8

Automatically generated by python-semantic-release
([`3df81b1`](https://github.com/OZI-Project/OZI/commit/3df81b14122223e688ea67333b51da36287efef4))

* Update dist-workflow.yml — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`3c1bc09`](https://github.com/OZI-Project/OZI/commit/3c1bc09c46977479a941020a4479e4c9b6ee4e8c))

* 1.20.8

Automatically generated by python-semantic-release
([`58cbae3`](https://github.com/OZI-Project/OZI/commit/58cbae35974e3db2d149c1ae2e3dcdc040b7f5a4))

* 1.20.8

Automatically generated by python-semantic-release
([`fdb14d3`](https://github.com/OZI-Project/OZI/commit/fdb14d328112d51966cb595bd78e8bcdad045a10))

* Update meson.options — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`43b3f5e`](https://github.com/OZI-Project/OZI/commit/43b3f5e6afd83ae4d458f754d33e7e9bc3e0935a))

* 1.20.8

Automatically generated by python-semantic-release
([`7a98098`](https://github.com/OZI-Project/OZI/commit/7a980987e8c8a060f8db9395d63457a2fd0f4857))

* 1.20.8

Automatically generated by python-semantic-release
([`bedc581`](https://github.com/OZI-Project/OZI/commit/bedc581ef93364340bb31f9d86ed55d6e2b1d6c7))

* 1.20.8

Automatically generated by python-semantic-release
([`b9ef355`](https://github.com/OZI-Project/OZI/commit/b9ef35501233da97ff87e1eaed14839240f0a786))

## 1.20.7 (2024-09-06)


### ⬆️ Upgraded Dependencies

* ozi-core~=1.0.12 — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`cbb437d`](https://github.com/OZI-Project/OZI/commit/cbb437df0f227ded9c572162ee7d434ec196ee01))

*  Bump OZI-Project/draft from 0.3.9 to 0.3.11

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.9 to 0.3.11.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/d9421ff8095e084639f3b03673b110033452c9e0...7e8ad70f472504510e169567e97db01bdafe2533)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`128a11d`](https://github.com/OZI-Project/OZI/commit/128a11d428f2e987a21c9f3b15f0e70750a0016f))

*  Bump OZI-Project/release from 0.8.10 to 0.8.11

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.8.10 to 0.8.11.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/7edb07c74e124270a29b2cd5d32ce7c9fdfc0b22...4277e29de16b07dac4a89c8f7970c2da65554d17)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`eaf36ba`](https://github.com/OZI-Project/OZI/commit/eaf36ba536030798b1c94c0bd439b845b4adb710))

*  Update hypothesis[all] requirement in /ozi/test/pytest

Updates the requirements on [hypothesis[all]](https://github.com/HypothesisWorks/hypothesis) to permit the latest version.
- [Release notes](https://github.com/HypothesisWorks/hypothesis/releases)
- [Commits](https://github.com/HypothesisWorks/hypothesis/compare/hypothesis-python-6.108.0...hypothesis-python-6.112.0)


updated-dependencies:
- dependency-name: hypothesis[all]
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`db96e80`](https://github.com/OZI-Project/OZI/commit/db96e808fff15fe6fdaf47b9a418d2a17d9a46e6))

*  Update flake8-bugbear requirement in /ozi/lint/flake8

Updates the requirements on [flake8-bugbear](https://github.com/PyCQA/flake8-bugbear) to permit the latest version.
- [Release notes](https://github.com/PyCQA/flake8-bugbear/releases)
- [Commits](https://github.com/PyCQA/flake8-bugbear/compare/24.4.21...24.8.19)


updated-dependencies:
- dependency-name: flake8-bugbear
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`1b3be62`](https://github.com/OZI-Project/OZI/commit/1b3be62545555ccb26fea9670e493bbc8071d4a9))

*  Update sigstore requirement in /ozi/dist/sigstore

Updates the requirements on [sigstore](https://github.com/sigstore/sigstore-python) to permit the latest version.
- [Release notes](https://github.com/sigstore/sigstore-python/releases)
- [Changelog](https://github.com/sigstore/sigstore-python/blob/main/CHANGELOG.md)
- [Commits](https://github.com/sigstore/sigstore-python/compare/v3.1.0...v3.2.0)


updated-dependencies:
- dependency-name: sigstore
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`00329a4`](https://github.com/OZI-Project/OZI/commit/00329a4780b417730023e3da6ad2a81cbdf59491))

*  Bump OZI-Project/publish from 0.1.10 to 0.1.11

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.10 to 0.1.11.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/cc463a2e9d2e928559e3edb4bd7f0fbcbefd1f11...55904e4f59084e7c6ccfad7b158db52a360e1f54)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`4b16333`](https://github.com/OZI-Project/OZI/commit/4b1633327ed9f172460427fca44ec22cb68a91c6))


### 🐛 Fixed Bugs

* (invoke): run CIBW with warn=True — rjdbcm <ozi.project@outlook.com>
([`16da34b`](https://github.com/OZI-Project/OZI/commit/16da34b251fc39f15c75fa9c164a52721e63dd10))

*  fix CIBW build selector — rjdbcm <ozi.project@outlook.com>
([`88adb35`](https://github.com/OZI-Project/OZI/commit/88adb35f5a796ab8e89a3936e9fa18b8100471a3))

*  set env var for CIBW build selection — rjdbcm <ozi.project@outlook.com>
([`5e0ffb6`](https://github.com/OZI-Project/OZI/commit/5e0ffb6c70a0a98109dd135f183b8eec45c4d168))

* (invoke): use ``--only`` to target interpreter version in cibuildwheel release — rjdbcm <ozi.project@outlook.com>
([`b467c71`](https://github.com/OZI-Project/OZI/commit/b467c71db4271b731aba977b0b803a6d3309521c))

* (meson.options): remove twine and cibuildwheel from ``plugin-only`` — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`a536aaa`](https://github.com/OZI-Project/OZI/commit/a536aaaf606572be093c164529e41d9d28976c35))

*  fix missing sign-checkpoint setup — rjdbcm <ozi.project@outlook.com>
([`ce0c854`](https://github.com/OZI-Project/OZI/commit/ce0c854cf4ea7b6a153bce31d687d50c70c0dd2f))

* fix tasks.py for use in CI — rjdbcm <ozi.project@outlook.com>
([`10b6732`](https://github.com/OZI-Project/OZI/commit/10b6732eb5c76272f4a99956b2b33a52b8d83c88))


### 🔨 Updated Scripts

* (meson.options): add ``cibuildwheel`` to ``dist-suite`` — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`a3bd757`](https://github.com/OZI-Project/OZI/commit/a3bd757acd9e892c2f483fcce1b28181dad3515f))

*  use official workflows for semantic-release steps — rjdbcm <ozi.project@outlook.com>
([`fa315cc`](https://github.com/OZI-Project/OZI/commit/fa315ccfffa5dbc1b849e424889ca4eac60877ac))

*  special invoke --ozi arg in this repo — rjdbcm <ozi.project@outlook.com>
([`bf2566f`](https://github.com/OZI-Project/OZI/commit/bf2566f86ea0c75805a4677224ad41de0551c89c))

*  add --ozi option for building OZI itself — rjdbcm <ozi.project@outlook.com>
([`2c2a961`](https://github.com/OZI-Project/OZI/commit/2c2a961e9afd4e859ad2fa8ff4de8c0fc9356608))

*  add python download endpoints — rjdbcm <ozi.project@outlook.com>
([`7fb56fa`](https://github.com/OZI-Project/OZI/commit/7fb56fa4e2729f47a9c6796f61641add1e66131e))

*  add api.deps.dev:443 endpoint — rjdbcm <ozi.project@outlook.com>
([`c65a5c4`](https://github.com/OZI-Project/OZI/commit/c65a5c422a8350ecfce7c4d201571c8873c35ef1))

*  add pypi.org endpoint — rjdbcm <ozi.project@outlook.com>
([`5c33b4d`](https://github.com/OZI-Project/OZI/commit/5c33b4d760384a925f9306c62633181aa9918c12))

* (invoke): dont sign release by default — rjdbcm <ozi.project@outlook.com>
([`3f2c641`](https://github.com/OZI-Project/OZI/commit/3f2c641f140f1b109bc7a1678dc74a193e40beb1))

*  add oauth2.sigstore.dev:443 endpoint to allowed — rjdbcm <ozi.project@outlook.com>
([`c22767a`](https://github.com/OZI-Project/OZI/commit/c22767ad02dfa81229bb1e358d90ceb034ff15da))

*  use prerelease github actions internally — rjdbcm <ozi.project@outlook.com>
([`14bc5fe`](https://github.com/OZI-Project/OZI/commit/14bc5fe5bd4bb58001b4f2dd3f5f2df0159ab701))

* (pyproject.toml): remove dependabot incompatible key — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`b588b0a`](https://github.com/OZI-Project/OZI/commit/b588b0a1d253096b7d9eed0b2854554a4c2bb21c))


### 🔨 Updated Configuration

* (meson.options): add twine and cibuildwheel args — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`ac3382f`](https://github.com/OZI-Project/OZI/commit/ac3382f33046752bef0000aaa9690eacbd118fef))


### Other


* 1.20.7

Automatically generated by python-semantic-release
([`486538c`](https://github.com/OZI-Project/OZI/commit/486538c8bed6be9e90badd364a9e7973946d3144))

* [StepSecurity] ci: Harden GitHub Actions — StepSecurity Bot <bot@stepsecurity.io>
([`523057b`](https://github.com/OZI-Project/OZI/commit/523057b72006869ecce4cb16030d890a11b508d7))

* 🚨 run fix — rjdbcm <ozi.project@outlook.com>
([`b10059a`](https://github.com/OZI-Project/OZI/commit/b10059aafb805751c07be2d737a04c2a39c45dc0))

* Update pyproject.toml — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`dd86f15`](https://github.com/OZI-Project/OZI/commit/dd86f1538a67ee6b02d736fafd2433fe428d8fac))

* Update meson.options — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`7dcb641`](https://github.com/OZI-Project/OZI/commit/7dcb6418be8a30c56fc95ed8b740052a56cf9465))

* 🚨 run ``tox -e fix`` — rjdbcm <ozi.project@outlook.com>
([`4d6f9c4`](https://github.com/OZI-Project/OZI/commit/4d6f9c465e4a8af6a4cd9bbc9c6d2aa8f7f39440))

* Update dependabot.yml — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`394cbaf`](https://github.com/OZI-Project/OZI/commit/394cbafcb7f6a5732397abc24aec687fe605b6a6))

* Update dependabot.yml — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`4a8a362`](https://github.com/OZI-Project/OZI/commit/4a8a36219cd91bf4a00008c328a5880026b175fd))

* Update dependabot.yml — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`f6bf4d8`](https://github.com/OZI-Project/OZI/commit/f6bf4d84a51c418d3761b3aa9ff0df77921cf17e))

* Update dependabot.yml — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`df0db94`](https://github.com/OZI-Project/OZI/commit/df0db948e1fba6c2933cdd51af0afa439958e41e))

* Update dependabot.yml — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`08fc950`](https://github.com/OZI-Project/OZI/commit/08fc950de2f3ab227dc938e54a820b1918681bb7))

* Update dependabot.yml — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`dde6a0c`](https://github.com/OZI-Project/OZI/commit/dde6a0c536b7bd44eed59400300f16ef28392ed2))

* Update dependabot.yml — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`927b539`](https://github.com/OZI-Project/OZI/commit/927b5398a3461f212f3faab473318c3ca352c478))

* Update dependabot.yml — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`ad22cf2`](https://github.com/OZI-Project/OZI/commit/ad22cf224024f0423e535d53ddb6808e6cc5214e))

## 1.20.6 (2024-09-03)


### ⬆️ Upgraded Dependencies

*  ozi-core~=1.0.11 — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`8f57998`](https://github.com/OZI-Project/OZI/commit/8f57998c0b556d1051c64e5f03a8985faafcdd76))

*  Bump actions/upload-artifact from 4.3.6 to 4.4.0

Bumps [actions/upload-artifact](https://github.com/actions/upload-artifact) from 4.3.6 to 4.4.0.
- [Release notes](https://github.com/actions/upload-artifact/releases)
- [Commits](https://github.com/actions/upload-artifact/compare/834a144ee995460fba8ed112a2fc961b36a5ec5a...50769540e7f4bd5e21e526ee35c689e35e0d6874)


updated-dependencies:
- dependency-name: actions/upload-artifact
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`4074c60`](https://github.com/OZI-Project/OZI/commit/4074c6007b779003c8e36a67e4c4300e3c5c1266))


### Other


* 1.20.6

Automatically generated by python-semantic-release
([`329e7af`](https://github.com/OZI-Project/OZI/commit/329e7af59b08ff7fdae171967d1df6923f61c9f5))

## 1.20.5 (2024-08-31)


### ⬆️ Upgraded Dependencies

*  ozi-core~=1.0.10

Fixes the issue of README symlinks being broken — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`019d736`](https://github.com/OZI-Project/OZI/commit/019d73650702841eb98a6a5d5a8d950f1d76cf48))


### Other


* 1.20.5

Automatically generated by python-semantic-release
([`e553195`](https://github.com/OZI-Project/OZI/commit/e553195e202a5dd9337813830d3c677255244f4a))

## 1.20.4 (2024-08-31)


### ⬆️ Upgraded Dependencies

*  ozi-core~=1.0.9

Fixes the issue of not detecting readme content type in CI  — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`e01ec0f`](https://github.com/OZI-Project/OZI/commit/e01ec0fd32eb0a39b1fb4195d98b6c9d6a9ec4dc))


### Other


* 1.20.4

Automatically generated by python-semantic-release
([`af00870`](https://github.com/OZI-Project/OZI/commit/af0087039ca24d5be246b4678e44c9f4bf0de5c9))

## 1.20.3 (2024-08-31)


### 🚸 Improved Usability

*  add deptry config — rjdbcm <ozi.project@outlook.com>
([`e3b69d4`](https://github.com/OZI-Project/OZI/commit/e3b69d474e9e0d65756df33602148e0dd3bf35f5))


### Other


* 1.20.3

Automatically generated by python-semantic-release
([`ba98eff`](https://github.com/OZI-Project/OZI/commit/ba98eff698f8229b0d6c79ec49be011a4e937118))

## 1.20.2 (2024-08-30)


### 🔨 Updated Scripts

*  remove requirements.in render — rjdbcm <ozi.project@outlook.com>
([`5504d8e`](https://github.com/OZI-Project/OZI/commit/5504d8ebcbb152c731681661fd1678d03f97fd67))

*  remove requirements.in — rjdbcm <ozi.project@outlook.com>
([`fb0db90`](https://github.com/OZI-Project/OZI/commit/fb0db90a2e2f09035a969812b29cdfc8cd81ba04))


### Other


* 1.20.2

Automatically generated by python-semantic-release
([`80d40f0`](https://github.com/OZI-Project/OZI/commit/80d40f0b2fe82f00993985046cb9fda7993ecb71))

## 1.20.1 (2024-08-30)


### ⬆️ Upgraded Dependencies

*  Update ozi-core requirement from ~=0.3.1 to ~=1.0.6


updated-dependencies:
- dependency-name: ozi-core
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`24adff3`](https://github.com/OZI-Project/OZI/commit/24adff32caaf773709e616af4d452b93a4813def))

*  Bump github/codeql-action from 3.26.5 to 3.26.6

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.26.5 to 3.26.6.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/2c779ab0d087cd7fe7b826087247c2c81f27bfa6...4dd16135b69a43b6c8efb853346f8437d92d3c93)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`3e84044`](https://github.com/OZI-Project/OZI/commit/3e84044ce8a9aef594170c903e1369f96c46304b))


### Other


* 1.20.1

Automatically generated by python-semantic-release
([`6e29306`](https://github.com/OZI-Project/OZI/commit/6e293061e374c8fc18a0fc0ff3c4fa187518305d))

## 1.20.0 (2024-08-29)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.26.4 to 3.26.5

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.26.4 to 3.26.5.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/f0f3afee809481da311ca3a6ff1ff51d81dbeb24...2c779ab0d087cd7fe7b826087247c2c81f27bfa6)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`d67a23f`](https://github.com/OZI-Project/OZI/commit/d67a23f5c14dc96405677b6ddc7cde7f70394096))


### 🐛 Fixed Bugs

*  add length() check to deps install
([`c223d71`](https://github.com/OZI-Project/OZI/commit/c223d71c118d1dfac26b98d59307b23dc672bf94))

*  add length() check to deps install — rjdbcm <ozi.project@outlook.com>
([`5f2b441`](https://github.com/OZI-Project/OZI/commit/5f2b4411e03ac6cbb54ffdbdf19c342e6e7f6fe4))

*  revert: fix postconf install script copy on configure — rjdbcm <ozi.project@outlook.com>
([`29b7b00`](https://github.com/OZI-Project/OZI/commit/29b7b00d0f8d497d8c22144cc54ba8055f9c6739))

*  fix postconf install script copy on configure — rjdbcm <ozi.project@outlook.com>
([`1674d2b`](https://github.com/OZI-Project/OZI/commit/1674d2b130d62e9bee19f6bedee1f70deb456e95))

*  set variable install_dependencies in meson — rjdbcm <ozi.project@outlook.com>
([`a591db2`](https://github.com/OZI-Project/OZI/commit/a591db279ac2fd952ffa7b3c9b63cc25de9f1148))

*  set variable install_dependencies in meson — rjdbcm <ozi.project@outlook.com>
([`f6faa33`](https://github.com/OZI-Project/OZI/commit/f6faa3331d575567921e9997fe7438bffba4e8ff))

*  revert the revert — rjdbcm <ozi.project@outlook.com>
([`5951997`](https://github.com/OZI-Project/OZI/commit/5951997fd2bc059cd6be94299322d414509120de))

*  revert METADATA unlink — rjdbcm <ozi.project@outlook.com>
([`1755bd7`](https://github.com/OZI-Project/OZI/commit/1755bd777c57404200d689ce23042bb97c44dab6))


### 🚸 Improved Usability

*  backward compatible fix for OZI.build 1.3+ — rjdbcm <ozi.project@outlook.com>
([`cae39ae`](https://github.com/OZI-Project/OZI/commit/cae39ae8db622373351a59203eb7813dcd18e08e))


### ✨ Implemented Features

*  use OZI.build 1.4

moves all metadata into project and tool.ozi-build — rjdbcm <ozi.project@outlook.com>
([`ff8aa92`](https://github.com/OZI-Project/OZI/commit/ff8aa92a9c63063c6730c28c8b3747ab98d9ebe3))


### Other


* 1.20.0

Automatically generated by python-semantic-release
([`d60dcca`](https://github.com/OZI-Project/OZI/commit/d60dccac8e51f3d5e16844a9d6d019bd76fe1fc3))

* 🚨 run black — rjdbcm <ozi.project@outlook.com>
([`a681472`](https://github.com/OZI-Project/OZI/commit/a6814720fd832edc84278561970f13bf9ce0f01d))

* fix: add new style dep install — rjdbcm <ozi.project@outlook.com>
([`503364e`](https://github.com/OZI-Project/OZI/commit/503364e74dc9a90b5a943e5dcde9296963588cec))

## 1.19.2 (2024-08-24)


### ⬆️ Upgraded Dependencies

*  ozi-core~=0.3.1 — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`d37e527`](https://github.com/OZI-Project/OZI/commit/d37e527afc9c277d598213a455864e3b7bdfcb27))

*  Bump OZI-Project/draft from 0.3.8 to 0.3.9

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.8 to 0.3.9.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/38dfc0df2b189018bbae0b016c61ac1d704c2626...d9421ff8095e084639f3b03673b110033452c9e0)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`3ef9970`](https://github.com/OZI-Project/OZI/commit/3ef997053ef6ec0d6cb61c230e8bf100b6aee2ab))


### Other


* 1.19.2

Automatically generated by python-semantic-release
([`5a2b492`](https://github.com/OZI-Project/OZI/commit/5a2b49256914d1de6947c52893a6a76638bdba1b))

## 1.19.1 (2024-08-23)


### 🐛 Fixed Bugs

*  fix invoke call — rjdbcm <ozi.project@outlook.com>
([`7e33e8e`](https://github.com/OZI-Project/OZI/commit/7e33e8e715a832b3eef2d63b37500295d3a0c923))

*  fix invoke setup call ozi bootstrap — rjdbcm <ozi.project@outlook.com>
([`47e3e15`](https://github.com/OZI-Project/OZI/commit/47e3e1593ac92df036d6c8f83c90617341f9da5b))

*  turn off blastpipe for now — rjdbcm <ozi.project@outlook.com>
([`880ad78`](https://github.com/OZI-Project/OZI/commit/880ad78f23eb871b7f17687a7e3d697ee48e4b73))

*  fix invoke meson option setting — rjdbcm <ozi.project@outlook.com>
([`c8bedb4`](https://github.com/OZI-Project/OZI/commit/c8bedb4563afe03d94f297bb5070fa14d74c343b))


### 🏷️


*  pyright fixes — rjdbcm <ozi.project@outlook.com>
([`972be3c`](https://github.com/OZI-Project/OZI/commit/972be3c368a42086243ffbf8c9480a1a431763d4))


### Other


* 1.19.1

Automatically generated by python-semantic-release
([`335e895`](https://github.com/OZI-Project/OZI/commit/335e8958f6d974f11787b1112a526898b0e5b036))

* 🚨 run black — rjdbcm <ozi.project@outlook.com>
([`f572c2d`](https://github.com/OZI-Project/OZI/commit/f572c2df50a63bac02d0a238c39085c19addb926))

## 1.19.0 (2024-08-23)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.26.2 to 3.26.4

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.26.2 to 3.26.4.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/429e1977040da7a23b6822b13c129cd1ba93dbb2...f0f3afee809481da311ca3a6ff1ff51d81dbeb24)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`1f42519`](https://github.com/OZI-Project/OZI/commit/1f42519ed48456ab34ed1604887e76dd904545c4))

*  Bump OZI-Project/publish from 0.1.9 to 0.1.10

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.9 to 0.1.10.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/e53fb3caac6d0530d1cc3d05d0c3e3a6b6fb1c67...cc463a2e9d2e928559e3edb4bd7f0fbcbefd1f11)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`46bbcfa`](https://github.com/OZI-Project/OZI/commit/46bbcfa17229a34e705dc9cbff92be4f3e153dac))

*  Bump OZI-Project/release from 0.8.9 to 0.8.10

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.8.9 to 0.8.10.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/f4172eb60419c98b5cf18c89d78cde8b553f5d15...7edb07c74e124270a29b2cd5d32ce7c9fdfc0b22)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`766723b`](https://github.com/OZI-Project/OZI/commit/766723bf834209690744443ad615eb7de423ab93))

*  Bump OZI-Project/checkpoint from 0.5.1 to 0.5.2

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.5.1 to 0.5.2.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/bfd6e529455ff6ec099bfd16be2ab86fa0332a71...cd1117d2d6d352e52d9dfdb603b8ebd7ef964908)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`d9bc0ae`](https://github.com/OZI-Project/OZI/commit/d9bc0ae90e0b4a578a9e67c939e51c4da2f2e206))


### 🔨 Updated Scripts

*  clean up requirements for ozi-core 0.3 — rjdbcm <ozi.project@outlook.com>
([`645cc12`](https://github.com/OZI-Project/OZI/commit/645cc129df27bc254b587cfb7289685fab13a104))

*  finalize tasks.py — rjdbcm <ozi.project@outlook.com>
([`788d0a4`](https://github.com/OZI-Project/OZI/commit/788d0a4b5b40392393dfd6b96244df7845ba945b))


### ✨ Implemented Features

*  add invoke tasks and improve tox entrypoints

Using the invoke backend speeds up our checkpoints by 30%.
ozi-spec 0.7 adds invoke to build-system dependencies.
ozi-templates 2.9 improves tox checkpoint testenvs to use invoke and improved support for uv.
Prior to now pip installed all dependencies for tox checkpoints, even with ``--enable-uv``. — rjdbcm <ozi.project@outlook.com>
([`f6b0982`](https://github.com/OZI-Project/OZI/commit/f6b098240a5aee34db5d7002383d74d56ad700f9))


### Other


* 1.19.0

Automatically generated by python-semantic-release
([`256e81a`](https://github.com/OZI-Project/OZI/commit/256e81a7dd97a60bf707f8dfd3a2432f57288be0))

## 1.18.6 (2024-08-18)


### ⬆️ Upgraded Dependencies

*  update ozi-core requirement from ~=0.2.3 to ~=0.2.4 — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`808016b`](https://github.com/OZI-Project/OZI/commit/808016b1127e29eac83c49a7c14a925890fd4d2d))


### Other


* 1.18.6

Automatically generated by python-semantic-release
([`b92aa5c`](https://github.com/OZI-Project/OZI/commit/b92aa5cffd496e93b656302daf7ee548809476d0))

## 1.18.5 (2024-08-18)


### ⬆️ Upgraded Dependencies

*  update ozi-core requirement from ~=0.2.2 to ~=0.2.3 — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`eb17028`](https://github.com/OZI-Project/OZI/commit/eb17028143ebab42015820fe663e696dcb7a25f0))


### Other


* 1.18.5

Automatically generated by python-semantic-release
([`d867b2a`](https://github.com/OZI-Project/OZI/commit/d867b2ae2371a7ea158aac093534ad2d7c8a1463))

## 1.18.4 (2024-08-17)


### 🐛 Fixed Bugs

*  fix pip path get — rjdbcm <ozi.project@outlook.com>
([`f61033e`](https://github.com/OZI-Project/OZI/commit/f61033ed22a8f404c68e729eb109ea6c99ce11d7))


### Other


* 1.18.4

Automatically generated by python-semantic-release
([`0ade82b`](https://github.com/OZI-Project/OZI/commit/0ade82b56bf6810cbc8af6b61b28a1ffe6634bb7))

* 1.18.4

Automatically generated by python-semantic-release
([`fd27864`](https://github.com/OZI-Project/OZI/commit/fd27864690c69fe4b9f090d0b3470da93c9ad331))

## 1.18.3 (2024-08-17)


### 🐛 Fixed Bugs

*  fix backward compatibility with non-uv packages — rjdbcm <ozi.project@outlook.com>
([`e343072`](https://github.com/OZI-Project/OZI/commit/e343072754b61e98acb21f73765e3bd2aa644512))


### Other


* 1.18.3

Automatically generated by python-semantic-release
([`7b2d25a`](https://github.com/OZI-Project/OZI/commit/7b2d25a925db434c7cf2c283cca118c91775e41b))

## 1.18.2 (2024-08-17)


### 🐛 Fixed Bugs

*  fix uv backend fallback to pip-tools — rjdbcm <ozi.project@outlook.com>
([`c548e87`](https://github.com/OZI-Project/OZI/commit/c548e8732913f8777d05d71333ea76b608381497))


### Other


* 1.18.2

Automatically generated by python-semantic-release
([`4115c17`](https://github.com/OZI-Project/OZI/commit/4115c17c6e1bd0ba5cd6f12ea9e457f918d9d9e0))

## 1.18.1 (2024-08-17)


### 🐛 Fixed Bugs

*  fix missing pip subcommands — rjdbcm <ozi.project@outlook.com>
([`8f6ea9b`](https://github.com/OZI-Project/OZI/commit/8f6ea9bf46115d18aee97682014667b394d3cc2f))


### Other


* 1.18.1

Automatically generated by python-semantic-release
([`7e7a947`](https://github.com/OZI-Project/OZI/commit/7e7a947084af1c7b1c34d14e20e3eb39f874e451))

## 1.18.0 (2024-08-16)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.26.1 to 3.26.2

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.26.1 to 3.26.2.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/29d86d22a34ea372b1bbf3b2dced2e25ca6b3384...429e1977040da7a23b6822b13c129cd1ba93dbb2)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`5f2df5e`](https://github.com/OZI-Project/OZI/commit/5f2df5eca276088a3656b259923f2fb7d50b7a2c))


### Other


* 1.18.0

Automatically generated by python-semantic-release
([`9a22731`](https://github.com/OZI-Project/OZI/commit/9a227319bac48fd78cbee01a1850c0dc82506c2f))

## 1.17.20 (2024-08-15)


### ⬆️ Upgraded Dependencies

*  Update ozi-core requirement from ~=0.1.21 to ~=0.2.2


updated-dependencies:
- dependency-name: ozi-core
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`06f02f7`](https://github.com/OZI-Project/OZI/commit/06f02f75da2095dce749f653d86186e1f0d742e4))

*  invoke~=2.2 over 2.0 — rjdbcm <ozi.project@outlook.com>
([`1a2a795`](https://github.com/OZI-Project/OZI/commit/1a2a7951032c23a22e35a63098f5c4b7b622c43c))


### 🔨 Updated Scripts

* (requirements/sigstore): add ``--prerelease=allow`` if using ``uv`` — rjdbcm <ozi.project@outlook.com>
([`531176e`](https://github.com/OZI-Project/OZI/commit/531176e5fb2a0aaf7614c505ca7d7524bef40270))


### 🏷️


*  ``type: ignore`` on ``invoke.call`` — rjdbcm <ozi.project@outlook.com>
([`955a299`](https://github.com/OZI-Project/OZI/commit/955a2996b00622cde87d804ffe01c1a120bd1830))


### ✏️ Corrected Typos

*  add missing build assets — rjdbcm <ozi.project@outlook.com>
([`3c29987`](https://github.com/OZI-Project/OZI/commit/3c29987f9ab2eb592fdc285d086fd1ab48868293))


### ✨ Implemented Features

*  OZI spec 0.6

Adds cibuildwheel and twine and dist plugins. — rjdbcm <ozi.project@outlook.com>
([`66a7f90`](https://github.com/OZI-Project/OZI/commit/66a7f900ef6b2f752c27688b7dfb41ec2d8ea069))


### 🔨 Updated Configuration

* (tox) add testenv dep ``uv`` — rjdbcm <ozi.project@outlook.com>
([`f73b37b`](https://github.com/OZI-Project/OZI/commit/f73b37b88341d6ee7a79e725c81a93a1d18ced28))

*  Development Status :: 4 - Beta — rjdbcm <ozi.project@outlook.com>
([`9313ea6`](https://github.com/OZI-Project/OZI/commit/9313ea60f86e7bc43170675e4cec4c8cfdd98c91))


### Other


* 1.17.20

Automatically generated by python-semantic-release
([`175fbe1`](https://github.com/OZI-Project/OZI/commit/175fbe1a9bffaa6e6f64317dace8e28aadb9577f))

## 1.17.19 (2024-08-15)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.26.0 to 3.26.1

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.26.0 to 3.26.1.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/eb055d739abdc2e8de2e5f4ba1a8b246daa779aa...29d86d22a34ea372b1bbf3b2dced2e25ca6b3384)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`57baab1`](https://github.com/OZI-Project/OZI/commit/57baab185518cd4203e65a9f2ec12e5f75d58352))


### 🔨 Updated Scripts

* 🔧 add invoke tasks to tox CI/CD setup for self-hosted publishing. — rjdbcm <ozi.project@outlook.com>
([`e0550e2`](https://github.com/OZI-Project/OZI/commit/e0550e232dac9c0cc99630de523e408da323d98f))

*  add SLSA dependency wrapfile — rjdbcm <ozi.project@outlook.com>
([`68c5f71`](https://github.com/OZI-Project/OZI/commit/68c5f7118a7a17dc0a2ef25057811e32d37c1cbe))


### ➕ Added Dependencies

*  invoke~=2.0, types-invoke~=2.0 — rjdbcm <ozi.project@outlook.com>
([`6512849`](https://github.com/OZI-Project/OZI/commit/65128497fde9e5200bbda3daf981b40dd793a709))


### Other


* 1.17.19

Automatically generated by python-semantic-release
([`f167d70`](https://github.com/OZI-Project/OZI/commit/f167d708cf7992e7e6eb0461b1ca56fd3f92a59e))

## 1.17.18 (2024-08-13)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/release from 0.8.5 to 0.8.9

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.8.5 to 0.8.9.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/b4279d73f1dff27e0c651f95ca20bc753b889ca9...f4172eb60419c98b5cf18c89d78cde8b553f5d15)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`33f19c0`](https://github.com/OZI-Project/OZI/commit/33f19c0288318b7cb8959b77f49d63b02d49c17b))


### 📌 Pinned Dependencies

*  ozi-core~=0.1.21 — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`f8ae848`](https://github.com/OZI-Project/OZI/commit/f8ae8485f04760b92f7c5b50e10fb19166f9f9ff))


### Other


* 1.17.18

Automatically generated by python-semantic-release
([`19b23f4`](https://github.com/OZI-Project/OZI/commit/19b23f4d2ceaaa71df0524a6139983dc6a2820d2))

## 1.17.17 (2024-08-12)


### 📌 Pinned Dependencies

*  ozi-core~=0.1.19

Cleans up calls to ``TAP.diagnostic``. — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`025cc95`](https://github.com/OZI-Project/OZI/commit/025cc95c600c7fea02a174463eb8aac3e82236bc))


### Other


* 1.17.17

Automatically generated by python-semantic-release
([`b88a3e1`](https://github.com/OZI-Project/OZI/commit/b88a3e140c2eef65adcefef630f6ffd8d5d1c972))

## 1.17.16 (2024-08-11)


### 📌 Pinned Dependencies

*  ozi-core~=0.1.18 — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`5d9cabd`](https://github.com/OZI-Project/OZI/commit/5d9cabd96387ce9f9762ba4ab4c78170fe119d00))


### Other


* 1.17.16

Automatically generated by python-semantic-release
([`caa42da`](https://github.com/OZI-Project/OZI/commit/caa42da83f12461aa37231ba634374a65eaf5c63))

## 1.17.15 (2024-08-11)


### ⬆️ Upgraded Dependencies

*  OZI-Project/release@0.8.5 — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`aa7a586`](https://github.com/OZI-Project/OZI/commit/aa7a586f3ffe20a235ebc65583b07f050bc4e29d))


### 🔨 Updated Scripts

*  add quay.io to allowed release endpoints — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`50269d7`](https://github.com/OZI-Project/OZI/commit/50269d774ec005342b115e19294b288b772140c4))


### Other


* 1.17.15

Automatically generated by python-semantic-release
([`014ce4b`](https://github.com/OZI-Project/OZI/commit/014ce4b4ecadddb7f6b8d12eb931606722a9a7f7))

* 1.17.15

Automatically generated by python-semantic-release
([`3bb3455`](https://github.com/OZI-Project/OZI/commit/3bb345505c682cde605fec3b04ff4bce69965b33))

## 1.17.14 (2024-08-11)


### ⬆️ Upgraded Dependencies

*  Bump actions/upload-artifact from 4.3.5 to 4.3.6

Bumps [actions/upload-artifact](https://github.com/actions/upload-artifact) from 4.3.5 to 4.3.6.
- [Release notes](https://github.com/actions/upload-artifact/releases)
- [Commits](https://github.com/actions/upload-artifact/compare/89ef406dd8d7e03cfd12d9e0a4a378f454709029...834a144ee995460fba8ed112a2fc961b36a5ec5a)


updated-dependencies:
- dependency-name: actions/upload-artifact
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`7662e60`](https://github.com/OZI-Project/OZI/commit/7662e60edd475a182c6b4a0d8ada46dd15d9425a))

*  Bump OZI-Project/draft from 0.3.7 to 0.3.8

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.7 to 0.3.8.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/f9e3ee38f76e3aefcbf29743e9ec64f716182001...38dfc0df2b189018bbae0b016c61ac1d704c2626)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`70c608e`](https://github.com/OZI-Project/OZI/commit/70c608e50ac806c531b302d519e29c42feedaa0f))

*  Bump OZI-Project/checkpoint from 0.5.0 to 0.5.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.5.0 to 0.5.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/8b8d7d173139c115188e4689204aba4e36e98810...bfd6e529455ff6ec099bfd16be2ab86fa0332a71)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`623829d`](https://github.com/OZI-Project/OZI/commit/623829d33c9cc85bf3b4c48a586410d7bab1bb95))

*  Bump OZI-Project/release from 0.7.3 to 0.8.4

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.7.3 to 0.8.4.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/b2388e2a058926646944ddc471737e2e6495940d...0ca87b5495c672f0d0c5ceaa6508e631a5c051f9)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`249838e`](https://github.com/OZI-Project/OZI/commit/249838e1abd5d8ac26cfe7e935199c2e62b674a5))

*  Update ozi-core requirement from ~=0.1.15 to ~=0.1.17


updated-dependencies:
- dependency-name: ozi-core
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`244f79c`](https://github.com/OZI-Project/OZI/commit/244f79c0a00db6acaebab271dc62118b89a6fc29))

*  Bump github/codeql-action from 3.25.15 to 3.26.0

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.15 to 3.26.0.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/afb54ba388a7dca6ecae48f608c4ff05ff4cc77a...eb055d739abdc2e8de2e5f4ba1a8b246daa779aa)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`3e7d549`](https://github.com/OZI-Project/OZI/commit/3e7d549cbbba88e7629afb6b1c5505f5ff54a1ee))

*  Bump step-security/harden-runner from 2.9.0 to 2.9.1

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.9.0 to 2.9.1.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/0d381219ddf674d61a7572ddd19d7941e271515c...5c7944e73c4c2a096b17a9cb74d65b6c2bbafbde)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`24acd17`](https://github.com/OZI-Project/OZI/commit/24acd17d609ee950157c7d26f60b6de0a4869156))

*  black~=24.8.0 — rjdbcm <ozi.project@outlook.com>
([`7160880`](https://github.com/OZI-Project/OZI/commit/7160880e3bb5614a9a76ed24e2cd647f9acab1d4))


### 📌 Pinned Dependencies

*  hypothesis[all]~=6.108 — rjdbcm <ozi.project@outlook.com>
([`3858c0b`](https://github.com/OZI-Project/OZI/commit/3858c0b85e3809b1a21e87481b7b364acf7cca49))

*  urllib3~=1.26 — rjdbcm <ozi.project@outlook.com>
([`327de11`](https://github.com/OZI-Project/OZI/commit/327de11e3072bc40098a31519b9138279b909051))

*  pytest-xdist~=3.6 — rjdbcm <ozi.project@outlook.com>
([`1dd1eed`](https://github.com/OZI-Project/OZI/commit/1dd1eed4949475f4ef0bfcb230ed187fc7ee5f46))

*  pytest-tcpclient~=0.7 — rjdbcm <ozi.project@outlook.com>
([`9286a08`](https://github.com/OZI-Project/OZI/commit/9286a081a3d1dd7986f18d9da6f06f44aab7babb))

*  pytest-randomly~=3.15 — rjdbcm <ozi.project@outlook.com>
([`32dbfa5`](https://github.com/OZI-Project/OZI/commit/32dbfa5edaf81af8b060b46506b7d5f49dd12011))

*  pytest-cov~=5.0 — rjdbcm <ozi.project@outlook.com>
([`a33aebe`](https://github.com/OZI-Project/OZI/commit/a33aebe4297a3c0c26a06b3ab0b12d7f6f26cd4a))

*  pytest-asyncio>=0.23.8 — rjdbcm <ozi.project@outlook.com>
([`a63cd1b`](https://github.com/OZI-Project/OZI/commit/a63cd1bdb6683466587053fe2c925920671b25b6))

*  pytest~=8.3 — rjdbcm <ozi.project@outlook.com>
([`8ec1e9f`](https://github.com/OZI-Project/OZI/commit/8ec1e9f00aafda87872c5b60505a6705b53a2d69))

*  sigstore~=3.1 — rjdbcm <ozi.project@outlook.com>
([`4365fb6`](https://github.com/OZI-Project/OZI/commit/4365fb68b03c36d64306b64260751e79d12c0a06))

*  python-semantic-release~=9.8 — rjdbcm <ozi.project@outlook.com>
([`15035cb`](https://github.com/OZI-Project/OZI/commit/15035cb466b85d7ad27ea3eae359ce52af74de00))

*  coverage[toml]~=7.6 — rjdbcm <ozi.project@outlook.com>
([`d44d07f`](https://github.com/OZI-Project/OZI/commit/d44d07f8f051c3df97ca092f22c10112bbf406a9))

*  flake8-pyi~=24.6 — rjdbcm <ozi.project@outlook.com>
([`a99849e`](https://github.com/OZI-Project/OZI/commit/a99849e5486da255003d5f59080957ff93889096))

*  flake8-tidy-imports~=4.10 — rjdbcm <ozi.project@outlook.com>
([`59b1e37`](https://github.com/OZI-Project/OZI/commit/59b1e3741a8f989ee17517581034749b422baeef))

*  flake8-leading-blank-lines~=1.0 — rjdbcm <ozi.project@outlook.com>
([`b17ae4a`](https://github.com/OZI-Project/OZI/commit/b17ae4a102c5653ed016b5593259b5b9f0266ddf))

*  flake8-comprehensions~=3.15 — rjdbcm <ozi.project@outlook.com>
([`8df75ee`](https://github.com/OZI-Project/OZI/commit/8df75ee1b05dd4bc5efc5175d32fff4743fa9c78))

*  flake8-no-pep420~=2.7 — rjdbcm <ozi.project@outlook.com>
([`d70e1a4`](https://github.com/OZI-Project/OZI/commit/d70e1a419e8795cd82a1a289c41c2a0676b00db4))

*  flake8-datetimez~=20.10 — rjdbcm <ozi.project@outlook.com>
([`b65325f`](https://github.com/OZI-Project/OZI/commit/b65325f09b7973131fdfb05a959b94e55ea0361b))

*  flake8-bugbear~=24.4 — rjdbcm <ozi.project@outlook.com>
([`a6a2484`](https://github.com/OZI-Project/OZI/commit/a6a2484b3818bceae1c7dba2db071451c129fdf5))

*  flake8-fixme~=1.1 — rjdbcm <ozi.project@outlook.com>
([`1d5f40d`](https://github.com/OZI-Project/OZI/commit/1d5f40d0cc021d20c3e95c6de792f2bd1e9fd733))

*  flake8-eradicate~=1.5 — rjdbcm <ozi.project@outlook.com>
([`d006831`](https://github.com/OZI-Project/OZI/commit/d006831019459f89e9f264dd311546e63f38a009))

*  flake8-broken-line~=1.0 — rjdbcm <ozi.project@outlook.com>
([`37be826`](https://github.com/OZI-Project/OZI/commit/37be826270bc8dfd6e300c5ef3219e0e450c4464))

*  flake8-annotations~=3.1 — rjdbcm <ozi.project@outlook.com>
([`804c2cb`](https://github.com/OZI-Project/OZI/commit/804c2cbf262abc75e9a4305bc3ce1dd48bc5e379))

*  flake8-type-checking~=2.9 — rjdbcm <ozi.project@outlook.com>
([`888de0f`](https://github.com/OZI-Project/OZI/commit/888de0fa698afb4437998188e869df97bd698983))

*  flake8-pytest-style~=2.0 — rjdbcm <ozi.project@outlook.com>
([`562e782`](https://github.com/OZI-Project/OZI/commit/562e782923c68c1672bbeb1b5378cb8f30c6075a))

*  bandit[toml]~=1.7 — rjdbcm <ozi.project@outlook.com>
([`374fe90`](https://github.com/OZI-Project/OZI/commit/374fe90bbccff95970d9506a279929441de5d40d))

*  flake8-quotes~=3.4 — rjdbcm <ozi.project@outlook.com>
([`ea8b400`](https://github.com/OZI-Project/OZI/commit/ea8b4009f6f863846593e17e9c082158aff0afe6))

*  flake8~=7.1 — rjdbcm <ozi.project@outlook.com>
([`3137752`](https://github.com/OZI-Project/OZI/commit/31377521ee6d5e1b1814fdff59f05e72ea3794f7))

*  Flake8-pyproject~=1.2 — rjdbcm <ozi.project@outlook.com>
([`8e5898d`](https://github.com/OZI-Project/OZI/commit/8e5898d7061608f1a8324974cc8f82dd20d08e5a))


### Other


* 1.17.14

Automatically generated by python-semantic-release
([`52dba88`](https://github.com/OZI-Project/OZI/commit/52dba88934222a9f88b3d99a9039096cb4e27f26))

## 1.17.13 (2024-08-04)


### Other


* 1.17.13

Automatically generated by python-semantic-release
([`3f06b01`](https://github.com/OZI-Project/OZI/commit/3f06b0185229845ca8b4d5958826a8555d866b0e))

## 1.17.12 (2024-08-04)


### Other


* 1.17.12

Automatically generated by python-semantic-release
([`693fbc7`](https://github.com/OZI-Project/OZI/commit/693fbc7e36eee1f5dbfb07b1acd65bfc8e147a85))

## 1.17.11 (2024-08-04)


### Other


* 1.17.11

Automatically generated by python-semantic-release
([`17bc347`](https://github.com/OZI-Project/OZI/commit/17bc34711f22ebae52739904b0c36c54377a5417))

## 1.17.10 (2024-08-04)


### ⬆️ Upgraded Dependencies

*  Bump actions/upload-artifact from 4.3.4 to 4.3.5

Bumps [actions/upload-artifact](https://github.com/actions/upload-artifact) from 4.3.4 to 4.3.5.
- [Release notes](https://github.com/actions/upload-artifact/releases)
- [Commits](https://github.com/actions/upload-artifact/compare/0b2256b8c012f0828dc542b3febcab082c67f72b...89ef406dd8d7e03cfd12d9e0a4a378f454709029)


updated-dependencies:
- dependency-name: actions/upload-artifact
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`898fee4`](https://github.com/OZI-Project/OZI/commit/898fee49f18635db5c6fcc2dffdeb573524dbe59))


### 🐛 Fixed Bugs

*  normalize ``semantic-release`` before checking version — rjdbcm <ozi.project@outlook.com>
([`9a92d58`](https://github.com/OZI-Project/OZI/commit/9a92d584e7f0533517649e273a03989ca7002ed2))

*  semantic-release name normalized — rjdbcm <ozi.project@outlook.com>
([`56d7331`](https://github.com/OZI-Project/OZI/commit/56d733154ada561326e9ab4d6442f69bbeb02474))

*  fix name normalization of ``python-semantic-release`` — rjdbcm <ozi.project@outlook.com>
([`bd5d080`](https://github.com/OZI-Project/OZI/commit/bd5d0808aa948c96c3fda6add0ab9bc3cd2f65e3))

*  normalize ``python-semantic-release`` to ``semantic_release`` for ``install-args`` — rjdbcm <ozi.project@outlook.com>
([`fa0d457`](https://github.com/OZI-Project/OZI/commit/fa0d4570f9d4e975c83c6601627cdda6af674df7))


### Other


* 1.17.10

Automatically generated by python-semantic-release
([`7405309`](https://github.com/OZI-Project/OZI/commit/7405309fce53bae746a0507ed4f10f8f2f21adb6))

## 1.17.9 (2024-08-01)


### 🐛 Fixed Bugs

* (meson.options): add ``flake8-docstring-checker`` to ``plugin-only`` — rjdbcm <ozi.project@outlook.com>
([`b69ee5c`](https://github.com/OZI-Project/OZI/commit/b69ee5c346d4155101b1686f2d6dbff4f4b841df))


### Other


* 1.17.9

Automatically generated by python-semantic-release
([`8a5201f`](https://github.com/OZI-Project/OZI/commit/8a5201fa15bad4a6e8deb1424d2d9b183acc1dfa))

## 1.17.8 (2024-08-01)


### 🐛 Fixed Bugs

*  normalize ``semantic-release`` to ``semantic_release`` — rjdbcm <ozi.project@outlook.com>
([`351327c`](https://github.com/OZI-Project/OZI/commit/351327c23be354aebece120bf3114630bb0e5f85))


### Other


* 1.17.8

Automatically generated by python-semantic-release
([`cbc2d80`](https://github.com/OZI-Project/OZI/commit/cbc2d807ef4481413cda84f80477ba914d9d368c))

## 1.17.7 (2024-08-01)


### 🐛 Fixed Bugs

*  fix semantic-release command name mismatch — rjdbcm <ozi.project@outlook.com>
([`9116e83`](https://github.com/OZI-Project/OZI/commit/9116e836f066e3fddc200c9f32f0c59178e8588a))


### Other


* 1.17.7

Automatically generated by python-semantic-release
([`2ab446f`](https://github.com/OZI-Project/OZI/commit/2ab446f5bd81c6f2539a46ff0abf42addacf6b57))

## 1.17.6 (2024-08-01)


### Other


* 1.17.6

Automatically generated by python-semantic-release
([`33fb6a6`](https://github.com/OZI-Project/OZI/commit/33fb6a6922822894cb2275ed204a82766a7e7e63))

## 1.17.5 (2024-08-01)


### Other


* 1.17.5

Automatically generated by python-semantic-release
([`bd89c0d`](https://github.com/OZI-Project/OZI/commit/bd89c0d137d5864b542e2758164545b5852bc6d4))

## 1.17.4 (2024-07-31)


### Other


* 1.17.4

Automatically generated by python-semantic-release
([`bd34f86`](https://github.com/OZI-Project/OZI/commit/bd34f86c4e4ce6a3bcc764d947372f5b6eced61b))

## 1.17.3 (2024-07-29)


### ⬆️ Upgraded Dependencies

*  Update ozi-core requirement from ~=0.1.14 to ~=0.1.15


updated-dependencies:
- dependency-name: ozi-core
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`7ea2e52`](https://github.com/OZI-Project/OZI/commit/7ea2e52bfd4094183a17d4012acfcdeb7c997c2e))

*  Bump ossf/scorecard-action from 2.3.3 to 2.4.0

Bumps [ossf/scorecard-action](https://github.com/ossf/scorecard-action) from 2.3.3 to 2.4.0.
- [Release notes](https://github.com/ossf/scorecard-action/releases)
- [Changelog](https://github.com/ossf/scorecard-action/blob/main/RELEASE.md)
- [Commits](https://github.com/ossf/scorecard-action/compare/dc50aa9510b46c811795eb24b2f1ba02a914e534...62b2cac7ed8198b15735ed49ab1e5cf35480ba46)


updated-dependencies:
- dependency-name: ossf/scorecard-action
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`e2a9a3c`](https://github.com/OZI-Project/OZI/commit/e2a9a3c155de39a932b606af25e81ddaa6f1b36a))

*  Update ozi-core requirement from ~=0.1.12 to ~=0.1.14


updated-dependencies:
- dependency-name: ozi-core
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`790c68f`](https://github.com/OZI-Project/OZI/commit/790c68f8b38eda325c21fbe5a66f30d95cb59c41))

*  Bump github/codeql-action from 3.25.14 to 3.25.15

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.14 to 3.25.15.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/5cf07d8b700b67e235fbb65cbc84f69c0cf10464...afb54ba388a7dca6ecae48f608c4ff05ff4cc77a)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`4d7b7f4`](https://github.com/OZI-Project/OZI/commit/4d7b7f4dc5839b6b121f032f097584a066fa0f38))

*  Bump github/codeql-action from 3.25.13 to 3.25.14

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.13 to 3.25.14.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/2d790406f505036ef40ecba973cc774a50395aac...5cf07d8b700b67e235fbb65cbc84f69c0cf10464)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`311dc09`](https://github.com/OZI-Project/OZI/commit/311dc095881d22a3f46965d76371c83f0b22aa0c))


### Other


* 1.17.3

Automatically generated by python-semantic-release
([`03c3c3e`](https://github.com/OZI-Project/OZI/commit/03c3c3e52e233fec2cdd7013fee6ac908fb258f8))

* Update dependabot.yml — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`bdf063f`](https://github.com/OZI-Project/OZI/commit/bdf063f075c90dc46af4f6190218aad867f6e35c))

## 1.17.2 (2024-07-25)


### Other


* 1.17.2

Automatically generated by python-semantic-release
([`9a9e19a`](https://github.com/OZI-Project/OZI/commit/9a9e19abd8d75eb40aef03f8bb26705505e86817))

## 1.17.1 (2024-07-23)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/publish from 0.1.8 to 0.1.9

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.8 to 0.1.9.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/798954a5a38220573d0a8c2873b5b08d1059d237...e53fb3caac6d0530d1cc3d05d0c3e3a6b6fb1c67)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`8308bb9`](https://github.com/OZI-Project/OZI/commit/8308bb9c82d4a34247c0e4c27bcd44a4527a929f))

*  Bump OZI-Project/draft from 0.3.6 to 0.3.7

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.6 to 0.3.7.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/29d09f8b7b490a3be3b6a448f1f40864fe1c7b25...f9e3ee38f76e3aefcbf29743e9ec64f716182001)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`2526a71`](https://github.com/OZI-Project/OZI/commit/2526a71e22333f39598d8d82f47a82fdc26facd2))

*  Bump github/codeql-action from 3.25.12 to 3.25.13

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.12 to 3.25.13.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/4fa2a7953630fd2f3fb380f21be14ede0169dd4f...2d790406f505036ef40ecba973cc774a50395aac)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`5b14348`](https://github.com/OZI-Project/OZI/commit/5b143481afe6096253db33bb742a4150573d6c6c))


### 🐛 Fixed Bugs

* (meson.options): yield dependencies and suite settings to superproject — rjdbcm <ozi.project@outlook.com>
([`1221540`](https://github.com/OZI-Project/OZI/commit/12215404dc362bd7a4ad94e6fc18b01ba8bd93ed))

*  fix broken changelog templates — rjdbcm <ozi.project@outlook.com>
([`00ed9f0`](https://github.com/OZI-Project/OZI/commit/00ed9f003957018ea9487f20aed4c3b6703a1786))


### 🏷️


*  add type ignore to main entrypoints — rjdbcm <ozi.project@outlook.com>
([`79e1534`](https://github.com/OZI-Project/OZI/commit/79e15341d48039b3199010a4544ffe2241e75c6b))


### 📌 Pinned Dependencies

*  pip-tools~=7.4 — rjdbcm <ozi.project@outlook.com>
([`cfdbe44`](https://github.com/OZI-Project/OZI/commit/cfdbe44f5bfed1fbd358f4aad82cd336ae309762))

*  ozi-core~=0.1.12 removed pins for all other core libs — rjdbcm <ozi.project@outlook.com>
([`2f768ac`](https://github.com/OZI-Project/OZI/commit/2f768ac8acac9f233268db6a14e21bd021cbeb58))


### Other


* 1.17.1

Automatically generated by python-semantic-release
([`ce902a7`](https://github.com/OZI-Project/OZI/commit/ce902a763761c72af4588a8bf7b5ff70a47ace33))

* :fix:(meson.options): ``python-dependencies`` shouldnt yield to superproject — rjdbcm <ozi.project@outlook.com>
([`f31d1e1`](https://github.com/OZI-Project/OZI/commit/f31d1e1a62d6f84d28e1a372dcf802b8fec0bba7))

## 1.17.0 (2024-07-21)


### ✨ Implemented Features

* 🐛 sigstore-v3 forces a minor version bump — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`8f8fa88`](https://github.com/OZI-Project/OZI/commit/8f8fa885491d718d87013e75ed96b704037ac9d8))


### Other


* 1.17.0

Automatically generated by python-semantic-release
([`f575732`](https://github.com/OZI-Project/OZI/commit/f575732d1bd1677c36d8ec2f027f80fa1bf47d16))

## 1.16.15 (2024-07-19)


### ⬆️ Upgraded Dependencies

*  Bump step-security/harden-runner from 2.8.1 to 2.9.0

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.8.1 to 2.9.0.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/17d0e2bd7d51742c71671bd19fa12bdc9d40a3d6...0d381219ddf674d61a7572ddd19d7941e271515c)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`9871f40`](https://github.com/OZI-Project/OZI/commit/9871f40be8a2aebc95b5953dabe2dba17d20019d))

*  Bump OZI-Project/draft from 0.3.5 to 0.3.6

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.5 to 0.3.6.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/8b8bafcce0442b4f6985d364c27030e44648e998...29d09f8b7b490a3be3b6a448f1f40864fe1c7b25)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`3ed3eb9`](https://github.com/OZI-Project/OZI/commit/3ed3eb9cbd5c9c4277bd31f0e3ebc302307b1394))

*  Bump OZI-Project/checkpoint from 0.4.3 to 0.5.0

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.4.3 to 0.5.0.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/bfd00dbaebfc8e86f730575dd907eb043052e795...8b8d7d173139c115188e4689204aba4e36e98810)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`f92a737`](https://github.com/OZI-Project/OZI/commit/f92a737f91db1d34b2da1b9293cf71aa9d63d69f))

*  Bump OZI-Project/release from 0.6.6 to 0.7.3

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.6.6 to 0.7.3.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/de8cb06cabbdc0697678bb16091258e8cc2e8f34...b2388e2a058926646944ddc471737e2e6495940d)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`51addab`](https://github.com/OZI-Project/OZI/commit/51addabc90fd4e64e0135c6f9030d313e66cdb17))


### 🚸 Improved Usability

*  use sigstore-v3 workflows in github CI — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`fa2ffd5`](https://github.com/OZI-Project/OZI/commit/fa2ffd520f349e39a15090e2cbf3e28487a45e05))


### Other


* 1.16.15

Automatically generated by python-semantic-release
([`d18c891`](https://github.com/OZI-Project/OZI/commit/d18c891fa15e733553a90886670eda10abe237a9))

## 1.16.14 (2024-07-18)


### 📌 Pinned Dependencies

*  TAP-Producer~=0.1.3 — rjdbcm <ozi.project@outlook.com>
([`dd0c6c0`](https://github.com/OZI-Project/OZI/commit/dd0c6c0b6677685357ea5efe2a55e2a84309611a))

* 🐛 fix wheel tags with OZI.build>=0.0.27 — rjdbcm <ozi.project@outlook.com>
([`c49ad41`](https://github.com/OZI-Project/OZI/commit/c49ad41d938d2042a4f7052c8b4f4b96af970617))


### Other


* 1.16.14

Automatically generated by python-semantic-release
([`7d5e64c`](https://github.com/OZI-Project/OZI/commit/7d5e64c0a1f4207ef0d3c61ab4f9f90d463ee099))

## 1.16.13 (2024-07-18)


### 📌 Pinned Dependencies

*  ozi-spec~=0.5.2 — rjdbcm <ozi.project@outlook.com>
([`5131c61`](https://github.com/OZI-Project/OZI/commit/5131c615bae759d04ba4e47df4f78cbff6d77711))


### Other


* 1.16.13

Automatically generated by python-semantic-release
([`8697914`](https://github.com/OZI-Project/OZI/commit/869791437c7b96a5bf2dad97aaf8d780978c0bdd))

## 1.16.12 (2024-07-14)


### Other


* 1.16.12

Automatically generated by python-semantic-release
([`1734f0f`](https://github.com/OZI-Project/OZI/commit/1734f0f4c648263e42969465580b9553a564769c))

## 1.16.11 (2024-07-14)


### Other


* 1.16.11

Automatically generated by python-semantic-release
([`1550ae8`](https://github.com/OZI-Project/OZI/commit/1550ae81de0e844f84c79789fbc3c1607f1dc0b2))

## 1.16.10 (2024-07-13)


### ⬆️ Upgraded Dependencies

*  OZI-Project/publish@0.1.8 — rjdbcm <ozi.project@outlook.com>
([`d5d8a98`](https://github.com/OZI-Project/OZI/commit/d5d8a983d9ef851db8f176d9451bc7828d5e0b47))

*  OZI-Project/release@0.6.1 — rjdbcm <ozi.project@outlook.com>
([`7f62e6f`](https://github.com/OZI-Project/OZI/commit/7f62e6ff6dbf99abc471365495b357cd994db500))

*  OZI-Project/draft@0.3.5 — rjdbcm <ozi.project@outlook.com>
([`92fb8fc`](https://github.com/OZI-Project/OZI/commit/92fb8fc0d3e72d0a86e91bcdadb323c6cce7f017))

*  OZI-Project/checkpoint@0.4.3 — rjdbcm <ozi.project@outlook.com>
([`ac01f1f`](https://github.com/OZI-Project/OZI/commit/ac01f1f9b24e2bcdc3a32b1978447e95426b980c))


### 🐛 Fixed Bugs

*  fix changelog heading levels.
([`6e55aa2`](https://github.com/OZI-Project/OZI/commit/6e55aa2814c3d23847c478ba46fb10e357eadf67))


### 🚸 Improved Usability

* (CHANGELOG.md): lower release heading levels — rjdbcm <ozi.project@outlook.com>
([`b7427a0`](https://github.com/OZI-Project/OZI/commit/b7427a0d1c56d7277af375380f293b342bd5b8cc))


### Other


* 1.16.10

Automatically generated by python-semantic-release
([`0fbdd7d`](https://github.com/OZI-Project/OZI/commit/0fbdd7dbb51bf9c183c4eb03d3721915cbde9d65))

## 1.16.9 (2024-07-12)


### ⬆️ Upgraded Dependencies

*  Bump actions/dependency-review-action from 4.3.3 to 4.3.4

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.3.3 to 4.3.4.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/72eb03d02c7872a771aacd928f3123ac62ad6d3a...5a2ce3f5b92ee19cbb1541a4984c76d921601d7c)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`b54dce2`](https://github.com/OZI-Project/OZI/commit/b54dce2123a706773b36200c59f70cfa6c3aae65))

*  Bump github/codeql-action from 3.25.11 to 3.25.12

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.11 to 3.25.12.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/b611370bb5703a7efb587f9d136a52ea24c5c38c...4fa2a7953630fd2f3fb380f21be14ede0169dd4f)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`75ee5b9`](https://github.com/OZI-Project/OZI/commit/75ee5b9d8a88d2213de4c280120bdece607efddc))


### 🐛 Fixed Bugs

* (ozi-new): remove pipe guard from args — rjdbcm <ozi.project@outlook.com>
([`53bf713`](https://github.com/OZI-Project/OZI/commit/53bf713ce010eaeae418606e0bf652778cb7a591))


### Other


* 1.16.9

Automatically generated by python-semantic-release
([`eb858ba`](https://github.com/OZI-Project/OZI/commit/eb858baa1f757f6419a87866d9128259146cff59))

## 1.16.8 (2024-07-12)


### Other


* 1.16.8

Automatically generated by python-semantic-release
([`e0089af`](https://github.com/OZI-Project/OZI/commit/e0089af8f212b1efb608bb9b1d38d903cf6e53da))

## 1.16.7 (2024-07-12)


### Other


* 1.16.7

Automatically generated by python-semantic-release
([`38f1419`](https://github.com/OZI-Project/OZI/commit/38f14194ec6b64385077ac744b98b65341c0aa1d))

## 1.16.6 (2024-07-12)


### Other


* 1.16.6

Automatically generated by python-semantic-release
([`cb02489`](https://github.com/OZI-Project/OZI/commit/cb02489c6fc9a3f64a857fd8bdd645acf2edc268))

## 1.16.5 (2024-07-11)


### Other


* 1.16.5

Automatically generated by python-semantic-release
([`3b8ba39`](https://github.com/OZI-Project/OZI/commit/3b8ba39dabe7a1e1756de9cbdb3b199236f25a65))

## 1.16.4 (2024-07-11)


### Other


* 1.16.4

Automatically generated by python-semantic-release
([`bb68e54`](https://github.com/OZI-Project/OZI/commit/bb68e54d52a05dfde510d3286963ddfb7c8645c5))

## 1.16.3 (2024-07-11)


### Other


* 1.16.3

Automatically generated by python-semantic-release
([`d7518fa`](https://github.com/OZI-Project/OZI/commit/d7518fa25279c09779bfe9bf1d79e84d28e56248))

## 1.16.2 (2024-07-11)


### ⬆️ Upgraded Dependencies

* 🐛 ozi-core>=0.0.2, fix cli arg order — rjdbcm <ozi.project@outlook.com>
([`641811a`](https://github.com/OZI-Project/OZI/commit/641811a9c4368599b02a7b9b5c7a996a2d64d0d7))


### 🐛 Fixed Bugs

*  fix missing version arg to ``ozi_spec.actions.info()`` — rjdbcm <ozi.project@outlook.com>
([`a1b586c`](https://github.com/OZI-Project/OZI/commit/a1b586c32f0e7b590ff5152fde736f65434617c1))

*  fix missing check_version arg
([`dc5dc41`](https://github.com/OZI-Project/OZI/commit/dc5dc419ccda6b2a4383846154bce311eae3a8a4))

*  fix metadata output, version, and check version — rjdbcm <ozi.project@outlook.com>
([`8836652`](https://github.com/OZI-Project/OZI/commit/883665288cce4e48e9c8f2031f35429a1a0e0d5b))


### 📌 Pinned Dependencies

*  ozi-core~=0.1.4 — rjdbcm <ozi.project@outlook.com>
([`ae758b0`](https://github.com/OZI-Project/OZI/commit/ae758b033b4b70afa0ea72d313b3c390e7e9cc0d))

*  ozi-core~=0.1.3 — rjdbcm <ozi.project@outlook.com>
([`0dc05f7`](https://github.com/OZI-Project/OZI/commit/0dc05f75763b3761ec501270d5fe62002bd1be3a))

*  ozi-core~=0.1.2
([`b31b97f`](https://github.com/OZI-Project/OZI/commit/b31b97f95d4281d061b462cde6aae45d952fe897))

*  ozi-core~=0.1.1 — rjdbcm <ozi.project@outlook.com>
([`e03473c`](https://github.com/OZI-Project/OZI/commit/e03473ce8c8b371e3876669be1612b13719e06af))


### Other


* 1.16.2

Automatically generated by python-semantic-release
([`9298980`](https://github.com/OZI-Project/OZI/commit/929898033c85c6e731953a22d6c80ae49760bad5))

## 1.16.1 (2024-07-11)


### Other


* 1.16.1

Automatically generated by python-semantic-release
([`cdd6915`](https://github.com/OZI-Project/OZI/commit/cdd6915e67c98a74b57731c46a1c91ff14eef6c7))

## 1.16.0 (2024-07-10)


### 🔥 Deleted Code or Files

*  remove alternate ``ozi-fix`` and ``ozi-new`` entrypoints throught ``ozi`` — rjdbcm <ozi.project@outlook.com>
([`096406f`](https://github.com/OZI-Project/OZI/commit/096406faedcf9fc66b36db60d74b010c9ea96505))


### 📌 Pinned Dependencies

*  ozi-core>=0.0.1 — rjdbcm <ozi.project@outlook.com>
([`8fb43cb`](https://github.com/OZI-Project/OZI/commit/8fb43cb275a794035c1cb4b15afbd7a5207eadf2))


### Other


* 1.16.0

Automatically generated by python-semantic-release
([`ac7b346`](https://github.com/OZI-Project/OZI/commit/ac7b3468ccd6c8dd8a25146ed3cafa90a044cb53))

## 1.15.3 (2024-07-10)


### 🚸 Improved Usability

*  extract core functions to ``ozi-core`` package — rjdbcm <ozi.project@outlook.com>
([`9b02455`](https://github.com/OZI-Project/OZI/commit/9b02455a0924e84dc44a2b6982dbccc7a9d06a1c))


### 🏷️


* (pyright): ignore ozi-core for now — rjdbcm <ozi.project@outlook.com>
([`f900b16`](https://github.com/OZI-Project/OZI/commit/f900b1683953c7d9ae9e5facc95b2339d6b21d6a))

* (mypy): add overrides for ``ozi-core`` — rjdbcm <ozi.project@outlook.com>
([`d362cfb`](https://github.com/OZI-Project/OZI/commit/d362cfbcab8268043d6147865bc9081f0595cfa4))


### Other


* 1.15.3

Automatically generated by python-semantic-release
([`4d6c589`](https://github.com/OZI-Project/OZI/commit/4d6c589907973f9533174f5d54c08a2fd0389c99))

* 🚨: run isort — rjdbcm <ozi.project@outlook.com>
([`39cca58`](https://github.com/OZI-Project/OZI/commit/39cca5823ba9d283fa380c76b0ad29cfaefa14c1))

* Update FUNDING.yml — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`b976520`](https://github.com/OZI-Project/OZI/commit/b976520f9368e786ed1ad0e7384ea36289c42852))

## 1.15.2 (2024-07-10)


### 🚸 Improved Usability

* (ozi.new): move ``pre/postprocess_arguments`` to ``ozi.new.validate`` — rjdbcm <ozi.project@outlook.com>
([`4bb70e2`](https://github.com/OZI-Project/OZI/commit/4bb70e29ffeb9ecdbf667a0540bd61f274fc7d42))

* (ozi.render): add RenderedContent class — rjdbcm <ozi.project@outlook.com>
([`707d9bc`](https://github.com/OZI-Project/OZI/commit/707d9bc89d6dd8391f90027786bb9b29365c3bb8))

* (ozi.spdx): add user-defined license expression to parser — rjdbcm <ozi.project@outlook.com>
([`cd0fca7`](https://github.com/OZI-Project/OZI/commit/cd0fca7c8c520ad829a6f7dc8124efd4bfe92b6a))


### 🔨 Updated Scripts

*  remove ``semantic_release`` from dist suite — rjdbcm <ozi.project@outlook.com>
([`047ac59`](https://github.com/OZI-Project/OZI/commit/047ac59418f7b441e2124fdf16aa2c05b0f8dbdd))


### Other


* 1.15.2

Automatically generated by python-semantic-release
([`1b43aa2`](https://github.com/OZI-Project/OZI/commit/1b43aa27491c0dae4d10c25603a2371b9e41d58b))

* 🚨(ozi.render): run black — rjdbcm <ozi.project@outlook.com>
([`964e9c5`](https://github.com/OZI-Project/OZI/commit/964e9c5f205f725aa08136ba8db6ec3ee15774ee))

* 🚨(ozi.render): version guard for Self type — rjdbcm <ozi.project@outlook.com>
([`863e32b`](https://github.com/OZI-Project/OZI/commit/863e32b9417772f7e8a22c6d78c9d26c0350fc8a))

## 1.15.1 (2024-07-08)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/publish from 0.1.6 to 0.1.7

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.6 to 0.1.7.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/5f82de29a76b1befa60a5b99752a881a83aeed47...1d1a105c970d1600a544bf67b93ef09fefe722cf)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`e88bde8`](https://github.com/OZI-Project/OZI/commit/e88bde8872a6f0aae6f139788eb568d09ddf745d))

*  Bump actions/upload-artifact from 4.3.3 to 4.3.4

Bumps [actions/upload-artifact](https://github.com/actions/upload-artifact) from 4.3.3 to 4.3.4.
- [Release notes](https://github.com/actions/upload-artifact/releases)
- [Commits](https://github.com/actions/upload-artifact/compare/65462800fd760344b1a7b4382951275a0abb4808...0b2256b8c012f0828dc542b3febcab082c67f72b)


updated-dependencies:
- dependency-name: actions/upload-artifact
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`040cbc3`](https://github.com/OZI-Project/OZI/commit/040cbc3e46bd5511209fe5f2ae7cd08473ade94d))

*  Bump OZI-Project/draft from 0.3.3 to 0.3.4

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.3 to 0.3.4.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1662727a1f63e3344fc5bda22ff785083596c8c3...58ae20c3cd6b2754a602bb4315bc80eee6c9d495)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`ab93b00`](https://github.com/OZI-Project/OZI/commit/ab93b00d004f4f31f6bde21fd8fc5289ca4c5cdb))


### Other


* 1.15.1

Automatically generated by python-semantic-release
([`af8d425`](https://github.com/OZI-Project/OZI/commit/af8d4251dc5ca52bf892d2ddca5226bb81788791))

## 1.15.0 (2024-07-08)


### Other


* 1.15.0

Automatically generated by python-semantic-release
([`2bbd2aa`](https://github.com/OZI-Project/OZI/commit/2bbd2aa12367b2f063b697d5e5a36cfce7471489))

* Update meson.options - semantic_release removed from should_fail — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`bbbf973`](https://github.com/OZI-Project/OZI/commit/bbbf973889cf08f15164858b333bdd590005b874))

## 1.14.10 (2024-07-06)


### 🐛 Fixed Bugs

*  add ``except configparser.NoSectionError`` to ci user lookup — rjdbcm <ozi.project@outlook.com>
([`4c819fb`](https://github.com/OZI-Project/OZI/commit/4c819fbb8d25058725c23d8e4414c93c6695a006))

* (ozi-fix missing): warn on missing required directories — rjdbcm <ozi.project@outlook.com>
([`8486918`](https://github.com/OZI-Project/OZI/commit/84869185690798aee9412925c595e7b6ced59643))


### 🚸 Improved Usability

* (ozi.render): git init a repo for new projects — rjdbcm <ozi.project@outlook.com>
([`17acd16`](https://github.com/OZI-Project/OZI/commit/17acd16c9349b1c1669f5960ece2c3af0f7d1a97))


### 📌 Pinned Dependencies

*  trove-classifiers~=2024.7 — rjdbcm <ozi.project@outlook.com>
([`51e4228`](https://github.com/OZI-Project/OZI/commit/51e42281566f60d09977fa5690eb7c51a4837bf7))

*  TAP-Producer~=0.1.1 — rjdbcm <ozi.project@outlook.com>
([`3b85987`](https://github.com/OZI-Project/OZI/commit/3b85987eb71c18ab33a441d302c9d0285cfbe523))


### ✨ Implemented Features

* 📌 ozi-spec~=0.5; ozi-templates~=2.5.1 — rjdbcm <ozi.project@outlook.com>
([`6a22639`](https://github.com/OZI-Project/OZI/commit/6a22639e76d0b2a21fa65a5791ac2adbda673e4d))


### 🔨 Updated Configuration

* (meson.options): add 'semantic_release' to ``should_fail`` — rjdbcm <ozi.project@outlook.com>
([`797d211`](https://github.com/OZI-Project/OZI/commit/797d211daba1e330758bbf688afa4fb7481d8d46))


### Other


* 1.14.10

Automatically generated by python-semantic-release
([`c61a9ac`](https://github.com/OZI-Project/OZI/commit/c61a9ac1fbe067563643cc7ae83a4df5149b202e))

* 🚨 hide some noqa from ruff — rjdbcm <ozi.project@outlook.com>
([`15f07a1`](https://github.com/OZI-Project/OZI/commit/15f07a1f791a16c707225d121df487c2543e635e))

* 🚨 no cover missing required directory — rjdbcm <ozi.project@outlook.com>
([`12d8298`](https://github.com/OZI-Project/OZI/commit/12d8298ed9804eb0fe4fdb5a731ac647b0bbfed2))

## 1.14.9 (2024-07-04)


### Other


* 1.14.9

Automatically generated by python-semantic-release
([`956d531`](https://github.com/OZI-Project/OZI/commit/956d5312de4ab3a63c0a13c4dec4ad6da481d32a))

## 1.14.8 (2024-07-04)


### 🐛 Fixed Bugs

*  use lowercase name in ``ozi.fix.missing:required_files`` — rjdbcm <ozi.project@outlook.com>
([`795cd4d`](https://github.com/OZI-Project/OZI/commit/795cd4de1f7da26cde29d2768a3bb76fff6fbfa8))


### 🚸 Improved Usability

*  move ``ozi.tap`` to ``TAP-Producer`` package — rjdbcm <ozi.project@outlook.com>
([`e5b317e`](https://github.com/OZI-Project/OZI/commit/e5b317e61f2862f8e44d4d8679d5e6a9f9ac3aae))


### ✏️ Corrected Typos

* 📝 CHANGELOG.md.j2 add project name to heading — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`547bc75`](https://github.com/OZI-Project/OZI/commit/547bc75ac6636842f5592b1310643d113c354872))


### Other


* 1.14.8

Automatically generated by python-semantic-release
([`ec56533`](https://github.com/OZI-Project/OZI/commit/ec565338e277a192b627e705d27be40c7061047e))

## 1.14.7 (2024-07-03)


### Other


* 1.14.7

Automatically generated by python-semantic-release
([`c529824`](https://github.com/OZI-Project/OZI/commit/c529824f43c4c7210df4e10068a9b061613e7b7f))

## 1.14.6 (2024-07-03)


### 🐛 Fixed Bugs

*  lowercase name in ``ozi.render.render_project_files`` — rjdbcm <ozi.project@outlook.com>
([`a18015a`](https://github.com/OZI-Project/OZI/commit/a18015ad442ea71fc48cb2d9ffd479a63bfeddff))

*  fix name normalization — rjdbcm <ozi.project@outlook.com>
([`1974a37`](https://github.com/OZI-Project/OZI/commit/1974a3723550171922fceaeb77ef3817aab894c4))

* ✏️ fix changelog blank — rjdbcm <ozi.project@outlook.com>
([`5257621`](https://github.com/OZI-Project/OZI/commit/5257621f1b1761758721071f14bd6cd1bc9f0d25))

* ✏️ changelog displays versions *greater* than 1.0.0 — rjdbcm <ozi.project@outlook.com>
([`cfeb32d`](https://github.com/OZI-Project/OZI/commit/cfeb32dee64195c477e56ed204da4388a93fbac0))


### 📌 Pinned Dependencies

*  ozi-templates~=2.4.8 — rjdbcm <ozi.project@outlook.com>
([`1709f7b`](https://github.com/OZI-Project/OZI/commit/1709f7b4f676805de63945b2b9e192add815f360))


### Other


* 1.14.6

Automatically generated by python-semantic-release
([`0c7d0b8`](https://github.com/OZI-Project/OZI/commit/0c7d0b83849b81cf0f9996a5c98f8ed5d672896e))

* 1.14.6

Automatically generated by python-semantic-release
([`f08e736`](https://github.com/OZI-Project/OZI/commit/f08e7368df02066e05f8efcdfdce0fbf86b79b15))

## 1.14.5 (2024-07-03)


### 🚸 Improved Usability

*  hide pre-1.0.0 commits from CHANGELOG — rjdbcm <ozi.project@outlook.com>
([`736bfbe`](https://github.com/OZI-Project/OZI/commit/736bfbef1efbfe8f17ce73e5d6ffe17120fc9450))


### Other


* 1.14.5

Automatically generated by python-semantic-release
([`25bb8ee`](https://github.com/OZI-Project/OZI/commit/25bb8eefc8d0e8b3c48c023e5772aac56d2ce316))

* use split method not filter — rjdbcm <ozi.project@outlook.com>
([`055dbfb`](https://github.com/OZI-Project/OZI/commit/055dbfb181f120610acba01fee18957fc873781d))

## 1.14.4 (2024-07-03)


### 🐛 Fixed Bugs

*  CHANGELOG duplicated commit headings fixed — rjdbcm <ozi.project@outlook.com>
([`0025cd6`](https://github.com/OZI-Project/OZI/commit/0025cd62fe1015e4517118eff3abbf7cae2beac4))


### Other


* 1.14.4

Automatically generated by python-semantic-release
([`d36fd16`](https://github.com/OZI-Project/OZI/commit/d36fd16478a4f56e7a41c90a27d071c7ed1eb9ba))

## 1.14.3 (2024-07-03)


### 🐛 Fixed Bugs

*  fix requirements.in render to properly ignore newlines — rjdbcm <ozi.project@outlook.com>
([`b313ede`](https://github.com/OZI-Project/OZI/commit/b313ede703d624962a309792973aead19e797203))

*  fix template emoji rendering — rjdbcm <ozi.project@outlook.com>
([`319c6d4`](https://github.com/OZI-Project/OZI/commit/319c6d443c9a0126cb174e5e688f27b3ffddd6f7))


### 🚸 Improved Usability

*  remove CHANGELOG.md from build files — rjdbcm <ozi.project@outlook.com>
([`cbe0c80`](https://github.com/OZI-Project/OZI/commit/cbe0c80b1346f7295204d80e953615d8f61ff34f))

* (ozi-new): use updated changelog template
([`450794c`](https://github.com/OZI-Project/OZI/commit/450794c3281d6587621466186fd8fe2b10d33610))


### 📌 Pinned Dependencies

*  ozi-templates~=2.4.3 — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`b392f0d`](https://github.com/OZI-Project/OZI/commit/b392f0dfc9847ce7b77f7ea591e040bc874ed792))

*  ozi-templates~=2.4.5 — rjdbcm <ozi.project@outlook.com>
([`5a3c774`](https://github.com/OZI-Project/OZI/commit/5a3c77433758b1a2768c234cf5ba456abc48d238))


### Other


* 1.14.3

Automatically generated by python-semantic-release
([`a363cff`](https://github.com/OZI-Project/OZI/commit/a363cff802c6622d914174f2fe0575db7b3fdd19))

* Update CHANGELOG.md.j2 — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`b6212a9`](https://github.com/OZI-Project/OZI/commit/b6212a9e7d3ed35b760c2086c5ec3aaa70097c3c))

## 1.14.2 (2024-07-02)


### Other


* 1.14.2

Automatically generated by python-semantic-release
([`d7d39c3`](https://github.com/OZI-Project/OZI/commit/d7d39c31de7424d89bd40a5c1557497db079700c))

## 1.14.1 (2024-07-02)


### Other


* 1.14.1

Automatically generated by python-semantic-release
([`9865711`](https://github.com/OZI-Project/OZI/commit/9865711bdc68a8549108d5246adcf82d2c07df39))

## 1.14.0 (2024-07-02)


### 🐛 Fixed Bugs

* 📝 Update CHANGELOG.md.j2 rendering — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`57e7d2c`](https://github.com/OZI-Project/OZI/commit/57e7d2c01a35907410021eebd6bcd5bee419fc92))

* 📝 Update CHANGELOG.md.j2 to fix rendering of code-blocks — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`3a2a186`](https://github.com/OZI-Project/OZI/commit/3a2a1861a0ce224b49f303ef70d2a9b3ce27048a))


### Other


* 1.14.0

Automatically generated by python-semantic-release
([`e3ec378`](https://github.com/OZI-Project/OZI/commit/e3ec3789a8ab1004d231ed22cb7a8374e4225ac5))

## 1.13.31 (2024-07-01)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.25.10 to 3.25.11

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.10 to 3.25.11.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/23acc5c183826b7a8a97bce3cecc52db901f8251...b611370bb5703a7efb587f9d136a52ea24c5c38c)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`1b166f0`](https://github.com/OZI-Project/OZI/commit/1b166f062bd3f8a8186512d80479460bdc37f1ce))


### 🏷️


* (mypy): ``ozi_spec.*: ignore_missing_imports = true`` — rjdbcm <ozi.project@outlook.com>
([`a016b31`](https://github.com/OZI-Project/OZI/commit/a016b3147258dc5a2c6ee8ea4d847f59fb2d9742))

* (mypy): ignore_errors ``ozi_spec.*`` — rjdbcm <ozi.project@outlook.com>
([`13f57a6`](https://github.com/OZI-Project/OZI/commit/13f57a60ed8e70efb19ca0baa85e15f55ccb495c))

*  pyright: ignore ``ozi_spec`` — rjdbcm <ozi.project@outlook.com>
([`0fe813c`](https://github.com/OZI-Project/OZI/commit/0fe813ceb16910cda27f05207c111e07c1d402bc))


### ✨ Implemented Features

*  move spec to ozi-spec package — rjdbcm <ozi.project@outlook.com>
([`80c6709`](https://github.com/OZI-Project/OZI/commit/80c6709a891e32b24e2af9df1c5a556fb4044ba7))


### Other


* 1.13.31

Automatically generated by python-semantic-release
([`3c0d74c`](https://github.com/OZI-Project/OZI/commit/3c0d74c22b6a6ba0a30f19bb1eee04bee26e1b20))

* 🚨 run linters — rjdbcm <ozi.project@outlook.com>
([`cddd84e`](https://github.com/OZI-Project/OZI/commit/cddd84ea3e3f4a7fd7bfbb606974c7deec0caa36))

## 1.13.30 (2024-06-30)


### Other


* 1.13.30

Automatically generated by python-semantic-release
([`9ca0599`](https://github.com/OZI-Project/OZI/commit/9ca059983316c1d15ab856637dd1e2a47d441797))

## 1.13.29 (2024-06-30)


### Other


* 1.13.29

Automatically generated by python-semantic-release
([`715cf97`](https://github.com/OZI-Project/OZI/commit/715cf9712560105a85b7f2a58b8ff5e5e4ede55e))

## 1.13.28 (2024-06-30)


### Other


* 1.13.28

Automatically generated by python-semantic-release
([`be03593`](https://github.com/OZI-Project/OZI/commit/be035938990d6fb592cdb676b75fdd0ba2fea017))

## 1.13.27 (2024-06-29)


### Other


* 1.13.27

Automatically generated by python-semantic-release
([`c15ed1d`](https://github.com/OZI-Project/OZI/commit/c15ed1d758e3fb98f4c3156863bc2ac2ade86bad))

## 1.13.26 (2024-06-29)


### 🐛 Fixed Bugs

*  Admonition modal min 40 columns wide instead of 8 — rjdbcm <ozi.project@outlook.com>
([`0edcc3b`](https://github.com/OZI-Project/OZI/commit/0edcc3bf326041416fabf7c522d739197f91d460))

* (ozi-new interactive): fix arg passing to ``ozi-new project`` — rjdbcm <ozi.project@outlook.com>
([`561d068`](https://github.com/OZI-Project/OZI/commit/561d068913efa0f8b5a3eb4f53cab956ab55dcd6))

* (ozi-new interactive): fix arg passing using chain — rjdbcm <ozi.project@outlook.com>
([`3afe7ba`](https://github.com/OZI-Project/OZI/commit/3afe7ba1511160086e4efa6b77d080dd00e5b1c8))

* (ozi-fix interactive): fix KeyError when editing classifiers — rjdbcm <ozi.project@outlook.com>
([`c6fb751`](https://github.com/OZI-Project/OZI/commit/c6fb7517abd9a5cb824007217442eb299c133552))

* (ozi-fix interactive): fix argument outputs — rjdbcm <ozi.project@outlook.com>
([`2bfd894`](https://github.com/OZI-Project/OZI/commit/2bfd894304b874ad7dbb1708e2aedd4e1efce414))


### 📌 Pinned Dependencies

* ozi-templates~=2.4.0

See https://github.com/OZI-Project/ozi-templates/releases/tag/2.4.0 for more info. — rjdbcm <ozi.project@outlook.com>
([`8682fe5`](https://github.com/OZI-Project/OZI/commit/8682fe5e061eee359f004b0d25d934792c4cdcb0))

*  ozi-templates~=2.3.4

fixes missing ``OSI Approved :: ... Unlicense ... `` folder missing. — rjdbcm <ozi.project@outlook.com>
([`dc9186c`](https://github.com/OZI-Project/OZI/commit/dc9186c210ec9b53fad9706adc85ed0368ee0fd9))

* ozi-templates~=2.3.3 — rjdbcm <ozi.project@outlook.com>
([`daac072`](https://github.com/OZI-Project/OZI/commit/daac0728f33eae31ab72d2abd0d177083a96a329))


### Other


* 1.13.26

Automatically generated by python-semantic-release
([`a8416ff`](https://github.com/OZI-Project/OZI/commit/a8416ffff45fe95a330d19539102c40572cf9a3c))

## 1.13.25 (2024-06-29)


### Other


* 1.13.25

Automatically generated by python-semantic-release
([`7187d73`](https://github.com/OZI-Project/OZI/commit/7187d730c2dae70fe26f67a3d79df148369fa140))

## 1.13.24 (2024-06-29)


### Other


* 1.13.24

Automatically generated by python-semantic-release
([`41aa522`](https://github.com/OZI-Project/OZI/commit/41aa522d5a82e28f84148a5fc61735946368e632))

## 1.13.23 (2024-06-29)


### Other


* 1.13.23

Automatically generated by python-semantic-release
([`740252f`](https://github.com/OZI-Project/OZI/commit/740252f4d5b0ab174f36e7c11709db120ca0e890))

## 1.13.22 (2024-06-29)


### Other


* 1.13.22

Automatically generated by python-semantic-release
([`8e3c1cd`](https://github.com/OZI-Project/OZI/commit/8e3c1cd8c343dc5ee831f821681fce2542823a57))

## 1.13.21 (2024-06-28)


### Other


* 1.13.21

Automatically generated by python-semantic-release
([`d3d9c00`](https://github.com/OZI-Project/OZI/commit/d3d9c00d28aecd65516d04eca31984e9180e6bd9))

## 1.13.20 (2024-06-28)


### Other


* 1.13.20

Automatically generated by python-semantic-release
([`16b3f33`](https://github.com/OZI-Project/OZI/commit/16b3f337d87ca06d8159ef7ea7eb90bcad68a36d))

## 1.13.19 (2024-06-28)


### Other


* 1.13.19

Automatically generated by python-semantic-release
([`01f815d`](https://github.com/OZI-Project/OZI/commit/01f815dc19febb1fdb051a4d077d2ad1fe8c2651))

## 1.13.18 (2024-06-28)


### Other


* 1.13.18

Automatically generated by python-semantic-release
([`edbea19`](https://github.com/OZI-Project/OZI/commit/edbea197b4d9f7114f3c5664024b30f62eefd7fd))

## 1.13.17 (2024-06-27)


### Other


* 1.13.17

Automatically generated by python-semantic-release
([`9dab4bb`](https://github.com/OZI-Project/OZI/commit/9dab4bbba5a3006b10cc62675b5b9f8251a5ffeb))

## 1.13.16 (2024-06-27)


### 🐛 Fixed Bugs

* 🏷️(ozi-new interactive) fix overlapping default conditional — rjdbcm <ozi.project@outlook.com>
([`97272e3`](https://github.com/OZI-Project/OZI/commit/97272e3fa241dd76d92f17fe0340e9b7c88d3761))

* (ozi-new interactive): fix option arg setting — rjdbcm <ozi.project@outlook.com>
([`758c91d`](https://github.com/OZI-Project/OZI/commit/758c91ddb39b81152e907b878229b48748a25d07))

* (ozi-new interactive): use mapping for setting args — rjdbcm <ozi.project@outlook.com>
([`38530a8`](https://github.com/OZI-Project/OZI/commit/38530a821565dd17722708cdf9a8188964c11756))

*  correct zlib to Zlib — rjdbcm <ozi.project@outlook.com>
([`76f3818`](https://github.com/OZI-Project/OZI/commit/76f3818af8e56cf91d4223942a63cd5f022cd6e8))

* ✏️: correct license short ids — rjdbcm <ozi.project@outlook.com>
([`8148c7b`](https://github.com/OZI-Project/OZI/commit/8148c7b88b1e3c26f992393632dbaca8dc227c1b))

* (ozi-new interactive): args output fixed and project_urls added — rjdbcm <ozi.project@outlook.com>
([`fcfcdba`](https://github.com/OZI-Project/OZI/commit/fcfcdbab57632f9b928f82001ab528f84bfd7438))

* ✏️ fix EUPL license IDs — rjdbcm <ozi.project@outlook.com>
([`b0a9425`](https://github.com/OZI-Project/OZI/commit/b0a94256692e919a80da97265875ec3e31883b83))

*  fix missing License :: Eiffel Forum License (EFL) — rjdbcm <ozi.project@outlook.com>
([`d263034`](https://github.com/OZI-Project/OZI/commit/d2630342b2257add6fbb2cd8e958d9d13e4db90f))

* (ozi-new interactive): fix missing license suggestions — rjdbcm <ozi.project@outlook.com>
([`21e0a4a`](https://github.com/OZI-Project/OZI/commit/21e0a4af19315fb19492c4e057aba2a8e6381229))

*  missing licenses and unsupported licenses list added — rjdbcm <ozi.project@outlook.com>
([`ac65c05`](https://github.com/OZI-Project/OZI/commit/ac65c059bdcb378c1d649eaf7590ad2d450e7b1a))

*  fix list indexing in license_expression — rjdbcm <ozi.project@outlook.com>
([`c47cad8`](https://github.com/OZI-Project/OZI/commit/c47cad82b89c488ca4011753c7b1ea6cc36e57ae))

*  fix license expression dialog crash — rjdbcm <ozi.project@outlook.com>
([`4babcd3`](https://github.com/OZI-Project/OZI/commit/4babcd3a5a644c6f7b58bb11d07ae1d76997f519))

* (ozi-new interactive): fix list argument rendering — rjdbcm <ozi.project@outlook.com>
([`0becd2e`](https://github.com/OZI-Project/OZI/commit/0becd2e29621c486f66cde130fc85d5b4399a846))

* (ozi-new interactive): fix arg quoting — rjdbcm <ozi.project@outlook.com>
([`0b8d0fd`](https://github.com/OZI-Project/OZI/commit/0b8d0fd1e2e22366cafc31f4efc5c07b71063685))

* (ozi-new interactive): hide cursor and wrap lines in Admonitions — rjdbcm <ozi.project@outlook.com>
([`d1cf3da`](https://github.com/OZI-Project/OZI/commit/d1cf3da8c80b577f38748be221017f7ddf65b082))

* (ozi-new interactive): correct handling of list args
([`862460d`](https://github.com/OZI-Project/OZI/commit/862460d9aacdde8c9e8169074d048ca338d28754))

* (ozi-new): accept standard Requires-Dist argument form
([`fc0401e`](https://github.com/OZI-Project/OZI/commit/fc0401ef9129663ae62e0da9b8d5b32b6a584340))


### 🏷️


* ``SPDX_LICENSE_MAP: dict[str, Sequence[str]]`` — rjdbcm <ozi.project@outlook.com>
([`22a5ed5`](https://github.com/OZI-Project/OZI/commit/22a5ed54d6669433bce1dab02625aa0021a3b839))

* (ozi-new interactive): fix license_expression dialog typing — rjdbcm <ozi.project@outlook.com>
([`399d270`](https://github.com/OZI-Project/OZI/commit/399d270521355a035128d944c2ceed4e2733f5ba))


### 📌 Pinned Dependencies

*  ozi-templates~=2.3.2 — rjdbcm <ozi.project@outlook.com>
([`97f1f90`](https://github.com/OZI-Project/OZI/commit/97f1f9099336394381787e9290a9cfa8c661faa5))

*  ozi-templates~=2.3.1 — rjdbcm <ozi.project@outlook.com>
([`d88b026`](https://github.com/OZI-Project/OZI/commit/d88b026a8c54b0d4f8d6850da5a355b7c6250370))

* ozi-templates~=2.3.0 — rjdbcm <ozi.project@outlook.com>
([`f7bbaa5`](https://github.com/OZI-Project/OZI/commit/f7bbaa59cacf87afca6a265629c00e41f15485df))


### Other


* 1.13.16

Automatically generated by python-semantic-release
([`23c7538`](https://github.com/OZI-Project/OZI/commit/23c7538c39cf03b6851e57e1a01928d35e0d9e60))

* 🚨(ozi-new interactive): run lint — rjdbcm <ozi.project@outlook.com>
([`c334f68`](https://github.com/OZI-Project/OZI/commit/c334f6873e3c1c7c787b3ac7e33d01a453d044c6))

## 1.13.15 (2024-06-26)


### Other


* 1.13.15

Automatically generated by python-semantic-release
([`ac69baf`](https://github.com/OZI-Project/OZI/commit/ac69bafb4fbcf9b1f1835c3393dbb6924ad58f2e))

## 1.13.14 (2024-06-24)


### Other


* 1.13.14

Automatically generated by python-semantic-release
([`e7733b8`](https://github.com/OZI-Project/OZI/commit/e7733b80e1154ae75662412daa074b2e0a7510ea))

## 1.13.13 (2024-06-24)


### 🐛 Fixed Bugs

* (ozi-new interactive): refactor and fix prompts — rjdbcm <ozi.project@outlook.com>
([`41f931c`](https://github.com/OZI-Project/OZI/commit/41f931cddca281928deaf2b7a7c1d97694391782))


### 🔨 Updated Scripts

* (ozi-new interactive): finalize implementation — rjdbcm <ozi.project@outlook.com>
([`95b4aeb`](https://github.com/OZI-Project/OZI/commit/95b4aebdfca4234912691778b3eafb525b6965eb))


### Other


* 1.13.13

Automatically generated by python-semantic-release
([`9a84b74`](https://github.com/OZI-Project/OZI/commit/9a84b7495631fde5a5a172132f8dc527f663b456))

## 1.13.12 (2024-06-24)


### Other


* 1.13.12

Automatically generated by python-semantic-release
([`eeaf54f`](https://github.com/OZI-Project/OZI/commit/eeaf54fa069c373ca9046c3413a8f4229163b066))

## 1.13.11 (2024-06-24)


### Other


* 1.13.11

Automatically generated by python-semantic-release
([`a4edd66`](https://github.com/OZI-Project/OZI/commit/a4edd6651cf1fb371db7462f0d5ad011de923e14))

## 1.13.10 (2024-06-23)


### Other


* 1.13.10

Automatically generated by python-semantic-release
([`fbcf01e`](https://github.com/OZI-Project/OZI/commit/fbcf01e9a4f8a8f6336ebb6ebfe19c9e8952f0c9))

## 1.13.9 (2024-06-23)


### 🐛 Fixed Bugs

* (ozi-new interactive): fix disclaimer text styling — rjdbcm <ozi.project@outlook.com>
([`3d8864a`](https://github.com/OZI-Project/OZI/commit/3d8864a182ae049c3a53cc2cc2bc695c128e11c6))

* 📄: updated disclaimer for CLI apps — rjdbcm <ozi.project@outlook.com>
([`5760da1`](https://github.com/OZI-Project/OZI/commit/5760da183f66de34a3d7c949bc1f01d98d2e7520))


### 🔨 Updated Scripts

* 🚸(ozi-new interactive): added metadata viewer to the menu. — rjdbcm <ozi.project@outlook.com>
([`fd9e7b0`](https://github.com/OZI-Project/OZI/commit/fd9e7b08d31fcf640c33b10cdde64b015f304652))

* (ozi-new interactive) only scroll page on Admonition dialog — rjdbcm <ozi.project@outlook.com>
([`2bbbd42`](https://github.com/OZI-Project/OZI/commit/2bbbd4242d528d7e885439578d4a9bf26a82cbf7))

*  Admonition dialog class for displaying scrolling text — rjdbcm <ozi.project@outlook.com>
([`02dff10`](https://github.com/OZI-Project/OZI/commit/02dff10c3f87b3c279bc242469d82d0958a9be21))


### 📝 Updated Documentation

* (ozi-new interactive): fix usage for docs — rjdbcm <ozi.project@outlook.com>
([`a6bca88`](https://github.com/OZI-Project/OZI/commit/a6bca88f84574ce745d776906c06cbcd92556129))

*  Update README — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`3ad41ee`](https://github.com/OZI-Project/OZI/commit/3ad41ee48630e301043b62c9ae683719d0ad3669))


### Other


* 1.13.9

Automatically generated by python-semantic-release
([`314123e`](https://github.com/OZI-Project/OZI/commit/314123e352a8b84d1ba442255550b3c5f9e93c45))

* 🚨 run lint — rjdbcm <ozi.project@outlook.com>
([`771d1bd`](https://github.com/OZI-Project/OZI/commit/771d1bdeb8b4b682eafa11e3a5d6ff9da6dda2be))

## 1.13.8 (2024-06-23)


### 🔨 Updated Scripts

* (ozi-new interactive): refactor — rjdbcm <ozi.project@outlook.com>
([`d41a8b6`](https://github.com/OZI-Project/OZI/commit/d41a8b6598ca57b0633455cffa909b58186ddf0c))


### Other


* 1.13.8

Automatically generated by python-semantic-release
([`6a23331`](https://github.com/OZI-Project/OZI/commit/6a2333144edfa7d0a4e5ab3798e6022c8c1f040e))

* 📄 add disclaimer to prompt session start — rjdbcm <ozi.project@outlook.com>
([`74a34b2`](https://github.com/OZI-Project/OZI/commit/74a34b214df1cf09b054492f57c6a65b593e123f))

* 🚨 run black — rjdbcm <ozi.project@outlook.com>
([`00d017f`](https://github.com/OZI-Project/OZI/commit/00d017fa010a03c1bdead6e2e64bc27dbffd525c))

## 1.13.7 (2024-06-23)


### Other


* 1.13.7

Automatically generated by python-semantic-release
([`682eaf0`](https://github.com/OZI-Project/OZI/commit/682eaf064bb304b8ebaece328031a3ab7c497ebe))

## 1.13.6 (2024-06-22)


### Other


* 1.13.6

Automatically generated by python-semantic-release
([`4d17299`](https://github.com/OZI-Project/OZI/commit/4d1729977b167541633c3bcbaafef7b02a25f93e))

## 1.13.5 (2024-06-21)


### Other


* 1.13.5

Automatically generated by python-semantic-release
([`bf86bf6`](https://github.com/OZI-Project/OZI/commit/bf86bf63928f566d3b7456c6f00d8d0fac219057))

## 1.13.4 (2024-06-21)


### Other


* 1.13.4

Automatically generated by python-semantic-release
([`787c3e2`](https://github.com/OZI-Project/OZI/commit/787c3e298017e2d5042bb443706669662e9e94b2))

## 1.13.3 (2024-06-21)


### 🐛 Fixed Bugs

* (interactive prompt): add summary validator — rjdbcm <ozi.project@outlook.com>
([`2d6849b`](https://github.com/OZI-Project/OZI/commit/2d6849b007a0e017adea3bdcaf28eadbd11c096f))


### 🚸 Improved Usability

* 🐛(ozi-new interactive) fix styling of checkbox and radio — rjdbcm <ozi.project@outlook.com>
([`5a2c657`](https://github.com/OZI-Project/OZI/commit/5a2c65744bb82d2ef0a47f49600d5dd1bb52ba14))

*  enhanced prompt with menu — rjdbcm <ozi.project@outlook.com>
([`e8ac4e0`](https://github.com/OZI-Project/OZI/commit/e8ac4e0e1251bac2c186a13382e8ca7f237a6518))


### 🔨 Updated Scripts

*  add ``--check-package-exists`` bool to interactive args

refactor menu system — rjdbcm <ozi.project@outlook.com>
([`f79d467`](https://github.com/OZI-Project/OZI/commit/f79d467fe208d7421397c20459e25150c389e661))


### Other


* 1.13.3

Automatically generated by python-semantic-release
([`3b86b01`](https://github.com/OZI-Project/OZI/commit/3b86b01241a725929d0693acfd77e7b94d5dc8d4))

* 🚨 run black — rjdbcm <ozi.project@outlook.com>
([`5748852`](https://github.com/OZI-Project/OZI/commit/5748852a3e842d81970b4974e2257543707964d3))

## 1.13.2 (2024-06-21)


### Other


* 1.13.2

Automatically generated by python-semantic-release
([`c1312b2`](https://github.com/OZI-Project/OZI/commit/c1312b2f4efaff3ef8b787556a4f5a847f85f53a))

## 1.13.1 (2024-06-21)


### Other


* 1.13.1

Automatically generated by python-semantic-release
([`31d1ae3`](https://github.com/OZI-Project/OZI/commit/31d1ae3aa2be1443a223cfc99a455dbfeada2c78))

## 1.13.0 (2024-06-21)


### ⬆️ Upgraded Dependencies

*  ozi-templates~=2.1.2 — rjdbcm <ozi.project@outlook.com>
([`0c4e9ac`](https://github.com/OZI-Project/OZI/commit/0c4e9acdf2a70a99af697a123abc5eafa21ae15c))


### 🐛 Fixed Bugs

*  fix summary arg — rjdbcm <ozi.project@outlook.com>
([`22bffda`](https://github.com/OZI-Project/OZI/commit/22bffda89bd6b460aab81d1ad2b15e957ef00137))

* 📝: add interactive doc help — rjdbcm <ozi.project@outlook.com>
([`0b4c054`](https://github.com/OZI-Project/OZI/commit/0b4c054d402a8eec06fa49d0d6aa6e194af340b3))

*  fix errant rendering of parsed_commit_heading stub — rjdbcm <ozi.project@outlook.com>
([`96c0306`](https://github.com/OZI-Project/OZI/commit/96c03066cfa0d56b36c5d29fb5276604d3e148d7))


### 🚸 Improved Usability

* clarify interactive prompt ``Cancel`` becomes ``Skip``
([`486f6b1`](https://github.com/OZI-Project/OZI/commit/486f6b1a0bae3107e0ac44d495dfdb4131a32a43))

* (interactive prompt): add final confirm dialog — rjdbcm <ozi.project@outlook.com>
([`045df8a`](https://github.com/OZI-Project/OZI/commit/045df8a1f428fd9a9668ebfb7d5d87755a90f111))


### 📝 Updated Documentation

*  add versionadded to docstring — rjdbcm <ozi.project@outlook.com>
([`5428424`](https://github.com/OZI-Project/OZI/commit/54284248e8b3cd3d70bab76e0386008669d42a1a))


### Other


* 1.13.0

Automatically generated by python-semantic-release
([`d476a01`](https://github.com/OZI-Project/OZI/commit/d476a013b39c7b10629f90867d9b11952f1abc77))

## 1.12.8 (2024-06-20)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/draft from 0.3.2 to 0.3.3

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.2 to 0.3.3.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/4cb9feb842df0dcd1e48c0f64f3b61e0ac64f05d...1662727a1f63e3344fc5bda22ff785083596c8c3)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`1af206c`](https://github.com/OZI-Project/OZI/commit/1af206c9815d97b0a3d808c14051b30b47efbf10))

*  Bump OZI-Project/publish from 0.1.5 to 0.1.6

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.5 to 0.1.6.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/edb7e48d4196153b8dabddb970405495e1ff2092...5f82de29a76b1befa60a5b99752a881a83aeed47)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`5938b98`](https://github.com/OZI-Project/OZI/commit/5938b98e43f5aef127cb0bd0a34e77ab54ec514e))

*  ozi-templates~=2.1.1 — rjdbcm <ozi.project@outlook.com>
([`af47885`](https://github.com/OZI-Project/OZI/commit/af478850a43ea3d10fd97845d05648b02d60a33b))


### 🐛 Fixed Bugs

* (ozi.scripts.render_requirements): correct filtering of empty lines — rjdbcm <ozi.project@outlook.com>
([`e9f671a`](https://github.com/OZI-Project/OZI/commit/e9f671a89485ebfec1f2d47786319067918c9f81))

*  remove mkdir templates in test — rjdbcm <ozi.project@outlook.com>
([`cc02853`](https://github.com/OZI-Project/OZI/commit/cc028537fe31d6bec848bc8135b4227856ae1801))

*  use pathlib idiom for template rendering — rjdbcm <ozi.project@outlook.com>
([`89ff2d6`](https://github.com/OZI-Project/OZI/commit/89ff2d635ab03317848e71374d92b9edbf7ede27))

*  add previously deleted ``blastpipe.wrap`` — rjdbcm <ozi.project@outlook.com>
([`aa7f8f7`](https://github.com/OZI-Project/OZI/commit/aa7f8f7681a7839db7cd6c29fc26c883a78e3768))


### ➕ Added Dependencies

*  add ``prompt_toolkit`` as a dependency — rjdbcm <ozi.project@outlook.com>
([`7e46ff6`](https://github.com/OZI-Project/OZI/commit/7e46ff680fce8fe619d0916a774b6e9ec878dcbe))


### 📝 Updated Documentation

*  update docstrings — rjdbcm <ozi.project@outlook.com>
([`2a33b0b`](https://github.com/OZI-Project/OZI/commit/2a33b0b6421e410947f8b8980820d76658d14b1e))

*  fix changelog template — rjdbcm <ozi.project@outlook.com>
([`c42f603`](https://github.com/OZI-Project/OZI/commit/c42f60312bc93debea3f2ddf28cea5b4e66cbb7e))


### ✏️ Corrected Typos

*  render templates set write mode — rjdbcm <ozi.project@outlook.com>
([`528abd8`](https://github.com/OZI-Project/OZI/commit/528abd87e42dae88532746d31d4f959f2864ce1c))


### 📌 Pinned Dependencies

* (checkpoint,draft,release,publish): update patch version — rjdbcm <ozi.project@outlook.com>
([`2fa3193`](https://github.com/OZI-Project/OZI/commit/2fa3193f2e07b9f7fc31bd8cdd07914ef8e5d3cb))


### ✨ Implemented Features

* (ozi-new): add interactive prompt mode — rjdbcm <ozi.project@outlook.com>
([`9576024`](https://github.com/OZI-Project/OZI/commit/95760249a73bf915c9502122e3938d9b5adabc1f))

* (ozi.render): add ``render_templates`` function

Renders templates folder with CHANGELOG and release notes templates for semantic-release. — rjdbcm <ozi.project@outlook.com>
([`bd1eb95`](https://github.com/OZI-Project/OZI/commit/bd1eb95fd92477001691bb765adbbcdfcf8a6005))


### Other


* 1.12.8

Automatically generated by python-semantic-release
([`1749275`](https://github.com/OZI-Project/OZI/commit/17492754eabc51e077e48ee27e3725eab7201fa4))

* 🚨 ``# noqa: ANN101`` Validator classes — rjdbcm <ozi.project@outlook.com>
([`7b7dff0`](https://github.com/OZI-Project/OZI/commit/7b7dff03f903916c5ced759cffb01b04853558ab))

* 🚨 lint cleanup — rjdbcm <ozi.project@outlook.com>
([`896af32`](https://github.com/OZI-Project/OZI/commit/896af323a37c0db963479616cbbb475963a0193a))

* 🚨 ignore type ignore — rjdbcm <ozi.project@outlook.com>
([`3556c91`](https://github.com/OZI-Project/OZI/commit/3556c91d50be947066048e705643d6c64fc6a98d))

* 🚨 move Self to typechecking guard — rjdbcm <ozi.project@outlook.com>
([`4a1dfd4`](https://github.com/OZI-Project/OZI/commit/4a1dfd4f68e78bdb725e7faafce255a129c9bbb6))

* 🚨 clean up lint — rjdbcm <ozi.project@outlook.com>
([`6fe1102`](https://github.com/OZI-Project/OZI/commit/6fe110290861a920a25249e1bd0040d8816a27d7))

## 1.12.7 (2024-06-19)


### Other


* 1.12.7

Automatically generated by python-semantic-release
([`fd5d135`](https://github.com/OZI-Project/OZI/commit/fd5d135a1f5744e9e42cf82dccde594bdb8b1d14))

## 1.12.6 (2024-06-19)


### Other


* 1.12.6

Automatically generated by python-semantic-release
([`4f65e4b`](https://github.com/OZI-Project/OZI/commit/4f65e4b4142aa1b6ce72f6acf4446992fdfec47e))

## 1.12.5 (2024-06-18)


### Other


* 1.12.5

Automatically generated by python-semantic-release
([`fc3480f`](https://github.com/OZI-Project/OZI/commit/fc3480f5cdb9b77dc26f5f01117221ca2f53daf4))

## 1.12.4 (2024-06-18)


### Other


* 1.12.4

Automatically generated by python-semantic-release
([`9321378`](https://github.com/OZI-Project/OZI/commit/93213786770261cb6c752731d9c93bd89ca63f48))

## 1.12.3 (2024-06-17)


### 🐛 Fixed Bugs

*  fix argv missing in ``ozi-new`` output — rjdbcm <ozi.project@outlook.com>
([`92899a7`](https://github.com/OZI-Project/OZI/commit/92899a7c588d5984393fa6964529bde80be99b29))


### 🚸 Improved Usability

* ``ozi-new`` now accepts stdin — rjdbcm <ozi.project@outlook.com>
([`05da91e`](https://github.com/OZI-Project/OZI/commit/05da91e7fe932ff292f2562632016dec24f2f821))

*  ``PKG-INFO required`` arguments to ``ozi-new`` no longer required — rjdbcm <ozi.project@outlook.com>
([`0a20811`](https://github.com/OZI-Project/OZI/commit/0a20811c34574c7055b126824d97fadaea2c6093))


### 📝 Updated Documentation

* remove horizontal dividers from CHANGELOG template — rjdbcm <ozi.project@outlook.com>
([`ee50072`](https://github.com/OZI-Project/OZI/commit/ee5007224f8778f802de2a324f4b756ab7850357))

*  clean up release_notes and CHANGELOG templates — rjdbcm <ozi.project@outlook.com>
([`2b9eaaf`](https://github.com/OZI-Project/OZI/commit/2b9eaaf64fd99323f87079b0e475dc2fc7f0b06e))


### ✏️ Corrected Typos

*  Better changelog — rjdbcm <ozi.project@outlook.com>
([`6f3f525`](https://github.com/OZI-Project/OZI/commit/6f3f525ce4d677b0310e140ab6b2fb804c518125))


### 📌 Pinned Dependencies

* (requirements.in): ozi-templates>=2.0.5

(checkpoint.yml.j2): prerelease checkpoint no longer included — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`bb9ff99`](https://github.com/OZI-Project/OZI/commit/bb9ff9904bde50fc3a08adb5ad447d7940ba0108))


### 🔨 Updated Configuration

*  re-enable blastpipe bootstrap — rjdbcm <ozi.project@outlook.com>
([`3c062d6`](https://github.com/OZI-Project/OZI/commit/3c062d664a150bb4823f9ff735c47ec2bab5547b))


### Other


* 1.12.3

Automatically generated by python-semantic-release
([`777b2bf`](https://github.com/OZI-Project/OZI/commit/777b2bf84bf6484977e117fc5ef82d268235d3f0))

* 🚨 run black — rjdbcm <ozi.project@outlook.com>
([`64ddc38`](https://github.com/OZI-Project/OZI/commit/64ddc381d4f18fae96e114f33c55d04a283c0ffa))

## 1.12.2 (2024-06-17)


### 🐛 Fixed Bugs

* 📝: Consistent CLI documentation. — rjdbcm <ozi.project@outlook.com>
([`cc37091`](https://github.com/OZI-Project/OZI/commit/cc370919b9f0dd8f353f636851f9fc2a22fe362c))


### Other


* 1.12.2

Automatically generated by python-semantic-release
([`fa28a23`](https://github.com/OZI-Project/OZI/commit/fa28a237666ce14e44f4c4eee726ccaccb7d554f))

## 1.12.1 (2024-06-17)


### Other


* 1.12.1

Automatically generated by python-semantic-release
([`dd1c801`](https://github.com/OZI-Project/OZI/commit/dd1c801735244d2a19acb52dd38644141deeacb2))

## 1.12.0 (2024-06-17)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/release from 0.6.4 to 0.6.5

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.6.4 to 0.6.5.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/cfe06ef22488ee71ba4f2807b16bbdba1a6fb26f...f99b4e470f3dc50884d227dff38c18c3f0f3f927)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`48dff8c`](https://github.com/OZI-Project/OZI/commit/48dff8c46bb12abda13e7334bff7cae9dd894c91))


### 🐛 Fixed Bugs

* 📝: fix documentation refs — rjdbcm <ozi.project@outlook.com>
([`284e8ab`](https://github.com/OZI-Project/OZI/commit/284e8abde89e39a65fc1674ef0a13780be41435d))


### Other


* 1.12.0

Automatically generated by python-semantic-release
([`3936317`](https://github.com/OZI-Project/OZI/commit/39363176664c6c70437aae7df111973e7d5045a7))

## 1.11.12 (2024-06-16)


### 📌 Pinned Dependencies

*  ozi-templates>=2.0.4 — rjdbcm <ozi.project@outlook.com>
([`8d5e3ba`](https://github.com/OZI-Project/OZI/commit/8d5e3ba5832de8008040e1426abfbdcd114914de))


### ✨ Implemented Features

*  ozi-templates becomes a dependency

No longer depends on blastpipe. — rjdbcm <ozi.project@outlook.com>
([`dc6882e`](https://github.com/OZI-Project/OZI/commit/dc6882e32ae96f7aa835a41194978a469f245402))

*  ozi-templates becomes a dependency

No longer depends on blastpipe. — rjdbcm <ozi.project@outlook.com>
([`8d17090`](https://github.com/OZI-Project/OZI/commit/8d170905e2edc16989c4fc1858884a70ff84ba7b))


### Other


* 1.11.12

Automatically generated by python-semantic-release
([`a2f0af8`](https://github.com/OZI-Project/OZI/commit/a2f0af8e86f57f8d5abae2361933742809789972))

* bump ozi-templates — rjdbcm <ozi.project@outlook.com>
([`3bec2f5`](https://github.com/OZI-Project/OZI/commit/3bec2f5e9644ec01737d7a1d3a125a1ec81d209e))

* 🚨 fix lint — rjdbcm <ozi.project@outlook.com>
([`427e3ca`](https://github.com/OZI-Project/OZI/commit/427e3ca8ee25f9443654863c90833e88e77fd23e))

## 1.11.11 (2024-06-16)


### Other


* 1.11.11

Automatically generated by python-semantic-release
([`de81db1`](https://github.com/OZI-Project/OZI/commit/de81db1beface18eec6a3fa49f8992f26d643dd9))

## 1.11.10 (2024-06-16)


### Other


* 1.11.10

Automatically generated by python-semantic-release
([`4f3a1e7`](https://github.com/OZI-Project/OZI/commit/4f3a1e712ab5fb4a4b655351a0bb36e177acff90))

## 1.11.9 (2024-06-15)


### Other


* 1.11.9

Automatically generated by python-semantic-release
([`1ac44bb`](https://github.com/OZI-Project/OZI/commit/1ac44bb0e79d6da3c741829525463e4e9aa199d0))

## 1.11.8 (2024-06-14)


### ⬆️ Upgraded Dependencies

*  OZI.build>=0.0.26 — rjdbcm <ozi.project@outlook.com>
([`a271807`](https://github.com/OZI-Project/OZI/commit/a2718078dfda696a437c57dc0afeb073244d72e1))

*  OZI.build 0.0.25
([`fd5bb40`](https://github.com/OZI-Project/OZI/commit/fd5bb400c81a2bf588d82b3f43cd92accad5264b))

* (requirements): blastpipe 2024.11.9 — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`3f92b5f`](https://github.com/OZI-Project/OZI/commit/3f92b5fc05c534cc8a0453943f508bf0a3c5afed))

* (requirements): blastpipe 2024.11.7 — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`322c17e`](https://github.com/OZI-Project/OZI/commit/322c17ec29c220ce26e9d15b08d83c52d6bc1bd1))

*  Bump OZI-Project/draft from 0.3.1 to 0.3.2

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.1 to 0.3.2.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/f136e6eb55507553aee04e92455cc2dc279583fc...4cb9feb842df0dcd1e48c0f64f3b61e0ac64f05d)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`a63c4cb`](https://github.com/OZI-Project/OZI/commit/a63c4cbed578a379c1e272ccad886ac98b57b7a3))

*  Bump github/codeql-action from 3.25.9 to 3.25.10

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.9 to 3.25.10.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/530d4feaa9c62aaab2d250371e2061eb7a172363...23acc5c183826b7a8a97bce3cecc52db901f8251)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`62a0043`](https://github.com/OZI-Project/OZI/commit/62a0043eb2eb7b4ae222b88ac7ba76b8c0e6d6e5))

*  Bump OZI-Project/checkpoint from 0.4.1 to 0.4.2

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.4.1 to 0.4.2.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/6cc6de3235d61a5bae47fa03e773a2af9a985016...f8acf37d2479db59d191e5f6324758e224149bd0)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`77f7b33`](https://github.com/OZI-Project/OZI/commit/77f7b33f6b207faead794527c343d52ba2badf38))

*  Bump OZI-Project/checkpoint from 0.4.0 to 0.4.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.4.0 to 0.4.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/0.4.0...6cc6de3235d61a5bae47fa03e773a2af9a985016)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`7f1329c`](https://github.com/OZI-Project/OZI/commit/7f1329c3371455d9b23e2c42541ea787c7c0f12d))

*  Bump actions/checkout from 4.1.6 to 4.1.7

Bumps [actions/checkout](https://github.com/actions/checkout) from 4.1.6 to 4.1.7.
- [Release notes](https://github.com/actions/checkout/releases)
- [Changelog](https://github.com/actions/checkout/blob/main/CHANGELOG.md)
- [Commits](https://github.com/actions/checkout/compare/a5ac7e51b41094c92402da3b24376905380afc29...692973e3d937129bcbf40652eb9f2f61becf3332)


updated-dependencies:
- dependency-name: actions/checkout
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`509a199`](https://github.com/OZI-Project/OZI/commit/509a1992c59d5ff8f36222a59ea5201c3015598b))

*  Bump github/codeql-action from 3.25.8 to 3.25.9

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.8 to 3.25.9.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/2e230e8fe0ad3a14a340ad0815ddb96d599d2aff...530d4feaa9c62aaab2d250371e2061eb7a172363)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`94abd27`](https://github.com/OZI-Project/OZI/commit/94abd27c32507118ba9608be9dc6db46179470c3))


### 🚸 Improved Usability

*  Fix release branch patterns. — rjdbcm <ozi.project@outlook.com>
([`2be2fb6`](https://github.com/OZI-Project/OZI/commit/2be2fb6d901c2042f03c7045a023c39adf3b8fa6))


### 🔨 Updated Scripts

*  revert render change — rjdbcm <ozi.project@outlook.com>
([`62d0c22`](https://github.com/OZI-Project/OZI/commit/62d0c22f8ecfecb0b5ccef9558df6e6a56d34975))


### 📌 Pinned Dependencies

*  blastpipe~=2024.11.10 — rjdbcm <ozi.project@outlook.com>
([`556210b`](https://github.com/OZI-Project/OZI/commit/556210b18134e568dbb3d6fafbaab1e077500bc5))


### Other


* 1.11.8

Automatically generated by python-semantic-release
([`9bbc893`](https://github.com/OZI-Project/OZI/commit/9bbc893d1c9fe77828feaa307185e2c645fd0a80))

## 1.11.7 (2024-06-13)


### Other


* 1.11.7

Automatically generated by python-semantic-release
([`276c89e`](https://github.com/OZI-Project/OZI/commit/276c89e7ae372117dc85a751ae16468e14a0cc0a))

## 1.11.6 (2024-06-13)


### Other


* 1.11.6

Automatically generated by python-semantic-release
([`fdd71d5`](https://github.com/OZI-Project/OZI/commit/fdd71d520a0adb30cd0be481aafaa4aee50149ef))

## 1.11.5 (2024-06-12)


### Other


* 1.11.5

Automatically generated by python-semantic-release
([`a7f8a67`](https://github.com/OZI-Project/OZI/commit/a7f8a67246ae50ebbe97a44924531f27b0606abe))

## 1.11.4 (2024-06-12)


### ⬆️ Upgraded Dependencies

* (requirements): blastpipe 2024.11.2 — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`1d707ec`](https://github.com/OZI-Project/OZI/commit/1d707ec21bd18263b9c11fe2f6e85f8e833e3f2d))

*  blastpipe 2024.10.5 — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`f4e6690`](https://github.com/OZI-Project/OZI/commit/f4e6690ea05cbd4bd14d2f9e7064fb7163997019))

*  Bump step-security/harden-runner from 2.8.0 to 2.8.1

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.8.0 to 2.8.1.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/f086349bfa2bd1361f7909c78558e816508cdc10...17d0e2bd7d51742c71671bd19fa12bdc9d40a3d6)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`95e6805`](https://github.com/OZI-Project/OZI/commit/95e6805a6a52f06d1b086c58ce918bf57c35d3d4))


### 🐛 Fixed Bugs

* (pyproject.toml): Fix branch release match pattern escape ``.`` — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`3ab600e`](https://github.com/OZI-Project/OZI/commit/3ab600e91cd044cdd595960d64193052992e7db3))

*  add a cleanup workflow to new projects. — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`5a6c442`](https://github.com/OZI-Project/OZI/commit/5a6c442dd00dfdd59bbaca024601f2e9e1b3ab6e))

* (checkpoint): ``parallel: false`` to workaround issue with CPython countedFileLock API. — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`5667a6f`](https://github.com/OZI-Project/OZI/commit/5667a6f395e835a0f1a0331ca2502c1889af391b))

* (dist-workflow.yml) Ignore copied symlinks release@0.6.4 — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`d473142`](https://github.com/OZI-Project/OZI/commit/d47314280b1bfc80e00411b6f1d67a79e7d35132))

* (dist-workflow.yml): FIX remove copy artifact step — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`df10823`](https://github.com/OZI-Project/OZI/commit/df10823a0b9baeb67eaec2c767e9c8886a831d41))

* (dist-workflow.yml): FIX artifact download — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`e5e70c6`](https://github.com/OZI-Project/OZI/commit/e5e70c649b945ff9abea28cf03983e97c15b7ccc))

* (dist-workflow.yml) FIX artifacts in release artifact — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`1526d3c`](https://github.com/OZI-Project/OZI/commit/1526d3cf87476977ff98810414373f76515613d4))

*  correct use of ``long_description_content_type``
([`3d614b7`](https://github.com/OZI-Project/OZI/commit/3d614b772f5d0a1b6a7f7b33bd3b5d25718fd89a))

* (ozi-new): create an appropriate symlink for GitHub README rendering to work — rjdbcm <ozi.project@outlook.com>
([`44d2033`](https://github.com/OZI-Project/OZI/commit/44d2033ea1b6d23a1690255ee833f63a7aede975))

*  set README linguist-language — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`973b7a9`](https://github.com/OZI-Project/OZI/commit/973b7a9537bcef0f1a29925327ca773a297d4420))

*  add readme symlink for gh renderer — rjdbcm <ozi.project@outlook.com>
([`ae4a2f3`](https://github.com/OZI-Project/OZI/commit/ae4a2f33795da7998a10cfa585095b4d8e209eec))


### 🔨 Updated Scripts

* (render.py): minor refactor for complexity — rjdbcm <ozi.project@outlook.com>
([`884071c`](https://github.com/OZI-Project/OZI/commit/884071cf3877fbc62f0e6bd42f85ebbe4b11a67d))

* (cleanup.yml) permissions: read-all — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`a067dde`](https://github.com/OZI-Project/OZI/commit/a067ddea6d8b80ba2d173f9f8f3c2947148190a2))

* (cleanup.yml): permissions for cache delete — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`de29e57`](https://github.com/OZI-Project/OZI/commit/de29e572c3cff7f0676532d5721529cddc8c7861))

* (cleanup.yml): write permissions for cache delete — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`7d90049`](https://github.com/OZI-Project/OZI/commit/7d90049a552490a4cec60998b4251e3a883a6d49))

* (cleanup.yml): add toplevel permissions. — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`b89487a`](https://github.com/OZI-Project/OZI/commit/b89487ab79e1a34bc17cbe869e20b1424cfab59e))

* (cleanup.yml): ``permissions: id-token: write`` — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`042514d`](https://github.com/OZI-Project/OZI/commit/042514de337386bc646971da514fb291551e61cb))

*  harden cleanup workflow. — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`43289d6`](https://github.com/OZI-Project/OZI/commit/43289d637d7fcf44b0dc708f85e012fd94877685))

* (readme-renderer): fs.copyfile README with extension
([`f3a208c`](https://github.com/OZI-Project/OZI/commit/f3a208c57bbb57c050c3ba458bd69453c11d24f5))


### 📝 Updated Documentation

*  Update README — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`fb697e4`](https://github.com/OZI-Project/OZI/commit/fb697e408247a7a64936805633325a5d6aef5435))

*  rename ``README.rst`` to ``README`` per OZI spec — rjdbcm <ozi.project@outlook.com>
([`d6b7e34`](https://github.com/OZI-Project/OZI/commit/d6b7e3420944fbe71718fe73c7409237b68df30c))


### 📌 Pinned Dependencies

*  OZI-Project/release@0.6.4 — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`fef34b8`](https://github.com/OZI-Project/OZI/commit/fef34b85654da4d66d4caec5988f9347356689ad))

*  OZI-Project/release@0.6.3 — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`64f61f2`](https://github.com/OZI-Project/OZI/commit/64f61f24078cc087d4067c6d0d8c1d2e95493a29))

*  OZI-Project/release@0.6.2 — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`9aa4e68`](https://github.com/OZI-Project/OZI/commit/9aa4e684116bd1dc970fae58c80b7cc7d67a8a6e))


### 🗑️ Deprecated Code

*  delete .gitattributes and modelines — rjdbcm <ozi.project@outlook.com>
([`38e6785`](https://github.com/OZI-Project/OZI/commit/38e6785d3c27050907dd6e340f1c7779e6100ede))


### 🔨 Updated Configuration

* (args-readme-renderer) target README — rjdbcm <ozi.project@outlook.com>
([`f09c7b8`](https://github.com/OZI-Project/OZI/commit/f09c7b864abc61a0dd0b18e7119b340cdbad9c38))

* (.gitattributes): remove README from linguist-documentation — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`b3465e7`](https://github.com/OZI-Project/OZI/commit/b3465e78bede56fc869cecf05b83eb1efd7cf3f9))


### Other


* 1.11.4

Automatically generated by python-semantic-release
([`9b371a9`](https://github.com/OZI-Project/OZI/commit/9b371a9263d072c35b2c42c67143d893f8e6352a))

* 1.11.4

Automatically generated by python-semantic-release
([`f7507cb`](https://github.com/OZI-Project/OZI/commit/f7507cb6f6ee7c74f94dd30003200fc683453241))

* 1.11.4

Automatically generated by python-semantic-release
([`317585d`](https://github.com/OZI-Project/OZI/commit/317585d54f7a20a10065df5093886f65f217d2e7))

* 1.11.4

Automatically generated by python-semantic-release
([`3f5c5d4`](https://github.com/OZI-Project/OZI/commit/3f5c5d4a3e693962739ca989772ae12aa2f19e8d))

* 1.11.5

Automatically generated by python-semantic-release
([`461e8bd`](https://github.com/OZI-Project/OZI/commit/461e8bd9b883ae9c64c4dd438c7414a836ec8345))

* escape dots — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`022354d`](https://github.com/OZI-Project/OZI/commit/022354d002ca8b94e21832c41958c0d517f3e517))

* ⬆️(requirements): blastpipe 2024.11.4 — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`961b3a7`](https://github.com/OZI-Project/OZI/commit/961b3a7be9b28045c84a28a5226919d04ccf871a))

* ⬆️(requirements): blastpipe 2024.11.3 — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`b3c3181`](https://github.com/OZI-Project/OZI/commit/b3c31816002dbffa663293e412d3fb55cf56cb57))

* Update requirements.in — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`b0aecc0`](https://github.com/OZI-Project/OZI/commit/b0aecc07fa1dc2cbaa3545ce555a8f3db5978dd3))

* Create cleanup.yml — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`93a9a7a`](https://github.com/OZI-Project/OZI/commit/93a9a7ab7da6fad954e744839f8f2c0b0f01214d))

* Update dev-workflow.yml checkpoint version — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`2d9308a`](https://github.com/OZI-Project/OZI/commit/2d9308a1fa8c8279d7e878d4c0099d5d85701853))

* 1.11.4

Automatically generated by python-semantic-release
([`4779bfa`](https://github.com/OZI-Project/OZI/commit/4779bfa4d9a83594255a9220650d2c95568ad538))

* 🚨 ``tox -e fix`` — rjdbcm <ozi.project@outlook.com>
([`b3275d0`](https://github.com/OZI-Project/OZI/commit/b3275d00af09bd7e9ff91b8f8fad638b3c069556))

* remove unused import — rjdbcm <ozi.project@outlook.com>
([`f4c3e2e`](https://github.com/OZI-Project/OZI/commit/f4c3e2ef360c75f3efc55ed05b2c2ef7acb944f5))

## 1.11.3 (2024-06-10)


### 🐛 Fixed Bugs

*  ozi.spec.base.Default now public as ozi.spec.Default — rjdbcm <ozi.project@outlook.com>
([`8556d46`](https://github.com/OZI-Project/OZI/commit/8556d46e5760f68889f4fa6dde0d0f566d14a4ff))


### ✏️ Corrected Typos

*  Fix docstrings in spec — rjdbcm <ozi.project@outlook.com>
([`235b16e`](https://github.com/OZI-Project/OZI/commit/235b16eb4bfccb53ba0006b7f0515f361f220153))


### Other


* 1.11.3

Automatically generated by python-semantic-release
([`59cea8a`](https://github.com/OZI-Project/OZI/commit/59cea8ad3bd5dc1581c24763606a99a3f5cd619e))

## 1.11.2 (2024-06-09)


### 🐛 Fixed Bugs

*  no cover score function — rjdbcm <ozi.project@outlook.com>
([`906d9f8`](https://github.com/OZI-Project/OZI/commit/906d9f8b4e85a1525d96f9cec6886ce14f827079))

*  Fix typing for ozi.spec.base.Default.
([`43f840f`](https://github.com/OZI-Project/OZI/commit/43f840f19688eb98d70cbd135ab5b17c1b0998eb))

*  rename score_file to score (score_file deprecated) — rjdbcm <ozi.project@outlook.com>
([`756d2c1`](https://github.com/OZI-Project/OZI/commit/756d2c1b99e3b112ebf1c3f70e1341d741e2baf4))

*  CheckpointSuite no longer kw_only — rjdbcm <ozi.project@outlook.com>
([`2804a02`](https://github.com/OZI-Project/OZI/commit/2804a020be2e7481207b8490d636de768354da11))


### 📝 Updated Documentation

*  add some spec metadata to versions — rjdbcm <ozi.project@outlook.com>
([`13f37ac`](https://github.com/OZI-Project/OZI/commit/13f37ace212ef86fc0e39714bc1475b9652daf8d))


### ✏️ Corrected Typos

*  remove Any — rjdbcm <ozi.project@outlook.com>
([`c8156ec`](https://github.com/OZI-Project/OZI/commit/c8156ec2549a4c3edb9602f0cee00dc53611fdee))


### Other


* 1.11.2

Automatically generated by python-semantic-release
([`e4643fb`](https://github.com/OZI-Project/OZI/commit/e4643fb7439bae35159d27a9ff2ee8f5aaa3dc2f))

* 🚨 Type ignore ozi.spec.base.Default. — rjdbcm <ozi.project@outlook.com>
([`d2804df`](https://github.com/OZI-Project/OZI/commit/d2804dfdb6ee4bbaec49e7123c13033c5af9eb73))

* 🚨 Fix empty list guard. — rjdbcm <ozi.project@outlook.com>
([`fdccaae`](https://github.com/OZI-Project/OZI/commit/fdccaae2278a30beed5589263c98e14019667e9f))

* 🚨 clean up import guards — rjdbcm <ozi.project@outlook.com>
([`cc78500`](https://github.com/OZI-Project/OZI/commit/cc78500977a5be2b77ba3fab7788b2c42dbfb8ab))

* :doc:🚨 refactor ozi.spec.base.Default

add iter method
help in Field metadata
improved docstring for asdict
([`66408f5`](https://github.com/OZI-Project/OZI/commit/66408f510814e98ed6b4e7c8546c0ab79cc40d91))

* 🚨 moved import guards to end of imports — rjdbcm <ozi.project@outlook.com>
([`791fcf6`](https://github.com/OZI-Project/OZI/commit/791fcf6a82a3e9476f0770ea1626c9bb89dddce4))

## 1.11.1 (2024-06-07)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/publish from 0.1.4 to 0.1.5

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.4 to 0.1.5.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/132db35a4d8eaec96886eecc50034f3c3db8bc45...edb7e48d4196153b8dabddb970405495e1ff2092)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`f39ec90`](https://github.com/OZI-Project/OZI/commit/f39ec905bc49c9b5e18aac0fe2df35e617ee7b57))

*  Bump OZI-Project/draft from 0.3.0 to 0.3.1

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.0 to 0.3.1.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/b1b9f3b412ed16a45dfe7c6f60ea8d6fbae97630...f136e6eb55507553aee04e92455cc2dc279583fc)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`ab9d266`](https://github.com/OZI-Project/OZI/commit/ab9d266bd9e030a65d48aeea40a6d7cc456c7af4))

*  Bump actions/dependency-review-action from 4.3.2 to 4.3.3

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.3.2 to 4.3.3.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/0c155c5e8556a497adf53f2c18edabf945ed8e70...72eb03d02c7872a771aacd928f3123ac62ad6d3a)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`58481c6`](https://github.com/OZI-Project/OZI/commit/58481c6e2d9583beffb8d7cecef2f2458e0a4dab))

*  Bump github/codeql-action from 3.25.7 to 3.25.8

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.7 to 3.25.8.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/f079b8493333aace61c81488f8bd40919487bd9f...2e230e8fe0ad3a14a340ad0815ddb96d599d2aff)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`db3b62d`](https://github.com/OZI-Project/OZI/commit/db3b62da0a2b93ac289a8dfb38e3fb3356f00f78))


### 🔨 Updated Scripts

*  CommentPatterns spec class is now public. — rjdbcm <ozi.project@outlook.com>
([`d0d5035`](https://github.com/OZI-Project/OZI/commit/d0d5035a34fe011ce9b2f34a14a866e070ba90a8))


### 📌 Pinned Dependencies

*  OZI-Project/draft 0.3.1 — rjdbcm <ozi.project@outlook.com>
([`7d1b5f3`](https://github.com/OZI-Project/OZI/commit/7d1b5f3e690494368407c1ef5defff5aca8a68fb))

*  OZI-Project/publish 0.1.5 — rjdbcm <ozi.project@outlook.com>
([`1d15f59`](https://github.com/OZI-Project/OZI/commit/1d15f59fd6add19139b4c74f8b926f2e731cf143))


### Other


* 1.11.1

Automatically generated by python-semantic-release
([`b4f35a3`](https://github.com/OZI-Project/OZI/commit/b4f35a3f881910aa430475c22a62e2b46ed6bbf5))

## 1.11.0 (2024-05-30)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.25.6 to 3.25.7

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.6 to 3.25.7.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/9fdb3e49720b44c48891d036bb502feb25684276...f079b8493333aace61c81488f8bd40919487bd9f)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`8ff6ee3`](https://github.com/OZI-Project/OZI/commit/8ff6ee334165b1b55702b922a09ab8ae91172a1d))

*  blastpipe~=2024.10.1 — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`4332d46`](https://github.com/OZI-Project/OZI/commit/4332d46aaa00f7264e19d3601451d7a1fc3329b2))


### 📌 Pinned Dependencies

*  blastpipe~=2024.10 — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`532f42a`](https://github.com/OZI-Project/OZI/commit/532f42a2abf2a4e62e0a9e12d1a01856232bc55b))


### ✨ Implemented Features

* 🐛 FIX Our Python distribution support keys are incorrect #620 — rjdbcm <ozi.project@outlook.com>
([`1400beb`](https://github.com/OZI-Project/OZI/commit/1400beb06219e4cca5961460c3f6605322a5c927))


### Other


* 1.11.0

Automatically generated by python-semantic-release
([`dbc9c43`](https://github.com/OZI-Project/OZI/commit/dbc9c434b395f2893fdc05f806b0a33a8ff05107))

## 1.10.2 (2024-05-30)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/draft from 0.2.0 to 0.2.1

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.2.0 to 0.2.1.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/52700faa171c8b44e53834c4878e6cbca430b1d9...914c0f88bb59d105ed0fc061278442565bb6860c)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`ee6c27a`](https://github.com/OZI-Project/OZI/commit/ee6c27aa58e9362a1bb4993d6a598dd4ec777129))

*  Bump OZI-Project/publish from 0.1.3 to 0.1.4

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.3 to 0.1.4.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/f5d14bfb29fd5daa0fd3002a9c57f863e86ddf93...132db35a4d8eaec96886eecc50034f3c3db8bc45)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`18fb106`](https://github.com/OZI-Project/OZI/commit/18fb10681545764f55d4a73d4139970864649aa3))


### Other


* 1.10.2

Automatically generated by python-semantic-release
([`45601c2`](https://github.com/OZI-Project/OZI/commit/45601c228cb773116436eaade32439d976aaf798))

## 1.10.1 (2024-05-27)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/publish from 0.1.2 to 0.1.3

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.2 to 0.1.3.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/e0a606616e2ff69a1b564f151f1061601683668f...f5d14bfb29fd5daa0fd3002a9c57f863e86ddf93)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`6823b84`](https://github.com/OZI-Project/OZI/commit/6823b84627acfb2511685963846ceb3a079d6a4c))


### 📌 Pinned Dependencies

*  OZI-Project/publish@0.1.3 in spec — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`1b00586`](https://github.com/OZI-Project/OZI/commit/1b005868ab6eb32f6f131db6f09a49063b3bfcba))


### Other


* 1.10.1

Automatically generated by python-semantic-release
([`57bf930`](https://github.com/OZI-Project/OZI/commit/57bf930b054ae2d3980f776f140d3b8d7692833f))

## 1.10.0 (2024-05-27)


### ⬆️ Upgraded Dependencies

*  OZI-Project/checkpoint-0.4.0

Now accepting args for tox posargs. — rjdbcm <ozi.project@outlook.com>
([`eb1cee9`](https://github.com/OZI-Project/OZI/commit/eb1cee92ca8ac576cca50a28f85fded3bf820dda))


### 🔨 Updated Scripts

*  accept posargs to checkpoint suites — rjdbcm <ozi.project@outlook.com>
([`912e394`](https://github.com/OZI-Project/OZI/commit/912e394cfa2f969f4b49ee5fea1e019063544190))

*  Display spec version of OZI when tag history not found.

This mainly applies when OZI is invoked as a wrapdb or subproject. — rjdbcm <ozi.project@outlook.com>
([`976d574`](https://github.com/OZI-Project/OZI/commit/976d574ad7d2c733656ce86e5aa170cbc07f134e))

*  remove docs setup, clarify meson config messages. — rjdbcm <ozi.project@outlook.com>
([`bbfb9c5`](https://github.com/OZI-Project/OZI/commit/bbfb9c5bc175fb60b07984231170f97fd61e83b9))


### ✨ Implemented Features

* 📌 blastpipe~=2024.9.3 — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`2a3c4d1`](https://github.com/OZI-Project/OZI/commit/2a3c4d1565a243f610ba81def6271ba443399dcb))


### 🔨 Updated Configuration

*  bump checkpoint in spec and add 1.10 branch pattern — rjdbcm <ozi.project@outlook.com>
([`7dfca03`](https://github.com/OZI-Project/OZI/commit/7dfca03a5166961bee35cedaa545479ee2f1829a))

*  configure step options for each checkpoint utility.

Uses ``config-args-`` prefix, does not include plugins, as these share a requirements input with their parent module. — rjdbcm <ozi.project@outlook.com>
([`3f509e6`](https://github.com/OZI-Project/OZI/commit/3f509e66c3d38f0a714a4afa1aea2ba1f7af9311))

*  add install options for each checkpoint command. — rjdbcm <ozi.project@outlook.com>
([`223ad2f`](https://github.com/OZI-Project/OZI/commit/223ad2fabd420a36d8f57343b1cffb4a4641fe81))


### Other


* 1.10.0

Automatically generated by python-semantic-release
([`31bc939`](https://github.com/OZI-Project/OZI/commit/31bc9390adc009fbf9987d52f37dbda500d7a898))

* add static.crates.io to allow — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`39ac47b`](https://github.com/OZI-Project/OZI/commit/39ac47b40a36c8387ad4ac99e435268d41de422b))

* add index.crates.io to allow list
([`b9055db`](https://github.com/OZI-Project/OZI/commit/b9055dbfe23489b300a286b4f9c0c7a8776c9cc0))

* remove failing checkpoint for now. — rjdbcm <ozi.project@outlook.com>
([`e9c7867`](https://github.com/OZI-Project/OZI/commit/e9c78673837059def61d1c52287ccf8e9f1853ae))

* 👷🔧 add CPython 3.13 checkpoints.
([`ce876aa`](https://github.com/OZI-Project/OZI/commit/ce876aaf0ea2b9bdcd366941e7cfe620fd454ae0))

## 1.9.10 (2024-05-23)


### 🐛 Fixed Bugs

*  fix bad default value for ``--check-license-expr``
([`d5a7609`](https://github.com/OZI-Project/OZI/commit/d5a7609c080a28881de6d33944b158df793a17bd))


### Other


* 1.9.10

Automatically generated by python-semantic-release
([`082a185`](https://github.com/OZI-Project/OZI/commit/082a18574c62128645f6b8ca12f17dd86e5ddc94))

## 1.9.9 (2024-05-23)


### 🐛 Fixed Bugs

* 📝 fix no cover showing up in docs
([`231625c`](https://github.com/OZI-Project/OZI/commit/231625c85234be3a212dbaeee7b55ea0a78ef767))


### Other


* 1.9.9

Automatically generated by python-semantic-release
([`8cb1d85`](https://github.com/OZI-Project/OZI/commit/8cb1d856500cb970630364792f10f17f5d95b511))

## 1.9.8 (2024-05-23)


### 🐛 Fixed Bugs

*  fix ``--check-license-expression`` wasnt accepting args. — rjdbcm <ozi.project@outlook.com>
([`f858e41`](https://github.com/OZI-Project/OZI/commit/f858e41e6243aa33ab7a0a450b93672df9562f20))


### Other


* 1.9.8

Automatically generated by python-semantic-release
([`638ef3e`](https://github.com/OZI-Project/OZI/commit/638ef3ef78260652e5517dcd041627fe673cbf8e))

* no cover — rjdbcm <ozi.project@outlook.com>
([`28a9602`](https://github.com/OZI-Project/OZI/commit/28a9602f8fae2a65d081fbca9337ce71b47ac659))

## 1.9.7 (2024-05-23)


### 🐛 Fixed Bugs

* 📝 fix ``ozi-new project`` parser docs — rjdbcm <ozi.project@outlook.com>
([`fdcd0cd`](https://github.com/OZI-Project/OZI/commit/fdcd0cd8d65806be5be415593af1c81195c368de))


### Other


* 1.9.7

Automatically generated by python-semantic-release
([`4a5fe0c`](https://github.com/OZI-Project/OZI/commit/4a5fe0c810e37899c1b08d9a67296ca33974f5a6))

## 1.9.6 (2024-05-23)


### 🐛 Fixed Bugs

* 📝 Clean up documentation of CLI. — rjdbcm <ozi.project@outlook.com>
([`a5aa0c2`](https://github.com/OZI-Project/OZI/commit/a5aa0c20fd51509e7ee67003f7096785413aea8a))


### Other


* 1.9.6

Automatically generated by python-semantic-release
([`05d1cef`](https://github.com/OZI-Project/OZI/commit/05d1cef85e7bda6a8e99a9e2b3ff656b434856ab))

* flake8 ignore long format string
([`a3ff071`](https://github.com/OZI-Project/OZI/commit/a3ff071b034646d5c30a66bc24a94b69e344038b))

## 1.9.5 (2024-05-23)


### 🐛 Fixed Bugs

*  clean up CLI help and options printout. — rjdbcm <ozi.project@outlook.com>
([`ede0289`](https://github.com/OZI-Project/OZI/commit/ede0289fd95dd70bb349a985d35a5e4bbaf4d4cb))


### Other


* 1.9.5

Automatically generated by python-semantic-release
([`011e68c`](https://github.com/OZI-Project/OZI/commit/011e68cdc68dbfb2b7602d6fc07295e6e14cedda))

## 1.9.4 (2024-05-23)


### 🔨 Updated Scripts

* 📝 add LICENSE_EXPR metavar and doc — rjdbcm <ozi.project@outlook.com>
([`1614d31`](https://github.com/OZI-Project/OZI/commit/1614d310bc660ed62097389febb180a2ac5c53f8))

* 📝 fix ``--list-available`` doc presentation. — rjdbcm <ozi.project@outlook.com>
([`1c48693`](https://github.com/OZI-Project/OZI/commit/1c48693cbb1e39a28d3aafcc919f5ad8cfddc59a))


### Other


* 1.9.4

Automatically generated by python-semantic-release
([`1dc483f`](https://github.com/OZI-Project/OZI/commit/1dc483f7007edb39861add55f470235081852453))

## 1.9.3 (2024-05-22)


### 🐛 Fixed Bugs

*  revert change to list-available arg. — rjdbcm <ozi.project@outlook.com>
([`49afaaf`](https://github.com/OZI-Project/OZI/commit/49afaaf1ba03fdb878ef4a33a9880071176b2169))


### Other


* 1.9.3

Automatically generated by python-semantic-release
([`8d66c39`](https://github.com/OZI-Project/OZI/commit/8d66c39260cb533f924278489110129c67e9e1d8))

## 1.9.2 (2024-05-22)


### 🔨 Updated Scripts

* 📝 update docstrings and CLI helps. — rjdbcm <ozi.project@outlook.com>
([`adb9487`](https://github.com/OZI-Project/OZI/commit/adb948737e942d6c954e4896f2e0e9bef7192908))


### Other


* 1.9.2

Automatically generated by python-semantic-release
([`88af191`](https://github.com/OZI-Project/OZI/commit/88af191355b6bdfd2bba6a1783d1f030a0109728))

## 1.9.1 (2024-05-22)


### 📌 Pinned Dependencies

*  blastpipe~=2024.9.1 — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`327ca80`](https://github.com/OZI-Project/OZI/commit/327ca800aa85921aa5bb8b32a09179846183e224))


### Other


* 1.9.1

Automatically generated by python-semantic-release
([`8ae07d0`](https://github.com/OZI-Project/OZI/commit/8ae07d07e327f63679dc712d779e704cc79a2c33))

* 
updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`62af563`](https://github.com/OZI-Project/OZI/commit/62af563627568d412ef4a1ef01899b1da0487b89))

## 1.9.0 (2024-05-21)


### 📌 Pinned Dependencies

*  Update ci.py - Release 0.5.10  — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`d827e33`](https://github.com/OZI-Project/OZI/commit/d827e33cd45396c97efd62585ca7e3239239b05f))

*  blastpipe~=2024.9 — rjdbcm <ozi.project@outlook.com>
([`00051ee`](https://github.com/OZI-Project/OZI/commit/00051ee3461002fc0432fe91529069316212dc32))


### ✨ Implemented Features

*  Use oziproject.dev API workflows. — rjdbcm <ozi.project@outlook.com>
([`967c5d2`](https://github.com/OZI-Project/OZI/commit/967c5d2d10bc1f0bfb3b16b1f926d5e51e6a5b7d))


### 🔨 Updated Configuration

*  add 1.9 branch pattern — rjdbcm <ozi.project@outlook.com>
([`ff90526`](https://github.com/OZI-Project/OZI/commit/ff905266ca2b558b071849c218edc32ffa90f1d8))

* 👷 Update dev-workflow.yml — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`a4cf2cf`](https://github.com/OZI-Project/OZI/commit/a4cf2cfcbfff42e1e57c112d2a51a3578a0080cb))


### Other


* 1.9.0

Automatically generated by python-semantic-release
([`9f5d68e`](https://github.com/OZI-Project/OZI/commit/9f5d68e01cbb39831e17880ca5ec6f2a26835d30))

* Update dist-workflow.yml - release 0.5.10 — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`828b086`](https://github.com/OZI-Project/OZI/commit/828b086498838db0686a532a37d1b5232f56f8b5))

* 1.9.0

Automatically generated by python-semantic-release
([`cb8d70c`](https://github.com/OZI-Project/OZI/commit/cb8d70cfe53c88f0c653fd5846164dbd694e33c8))

* retry release — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`b7c73b5`](https://github.com/OZI-Project/OZI/commit/b7c73b541123c82bc2f5dd95d4d6f94385433232))

* Update dist-workflow.yml allow objects.githubusercontent.com:443 — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`20e6a5b`](https://github.com/OZI-Project/OZI/commit/20e6a5bababb0806fcd51fc5b8adbf4a5caa6ce1))

* 1.9.0

Automatically generated by python-semantic-release
([`79e52a3`](https://github.com/OZI-Project/OZI/commit/79e52a32e774945bc649e8ef7ebb2e22230f3cde))

* Update dist-workflow.yml - allow API endpoint — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`a488a66`](https://github.com/OZI-Project/OZI/commit/a488a66a359e0e73da4a5a614032253dadf983f7))

* 1.9.0

Automatically generated by python-semantic-release
([`cfe509a`](https://github.com/OZI-Project/OZI/commit/cfe509a874211c03106429f0e9d9dae6dd7e2588))

* Update dist-workflow.yml — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`8649788`](https://github.com/OZI-Project/OZI/commit/8649788d9fc20ba203da61fea22ad87a7ec94f50))

* 
updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`7ec3682`](https://github.com/OZI-Project/OZI/commit/7ec36822d1deeb25835e157b28a2a273e00656db))

* 
updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`0a8d598`](https://github.com/OZI-Project/OZI/commit/0a8d59830717469c99e479a350aecbe3304cafa5))

## 1.8.5 (2024-05-21)


### Other


* 1.8.5

Automatically generated by python-semantic-release
([`c86f745`](https://github.com/OZI-Project/OZI/commit/c86f7453013250e5ddcf8ecb9ad3296d450a9bab))

## 1.8.4 (2024-05-20)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/publish from 0.1.1 to 0.1.2

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.1 to 0.1.2.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/87aae4bed7ea3ab8b864689945200ecd71ecc29f...e0a606616e2ff69a1b564f151f1061601683668f)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`a7903eb`](https://github.com/OZI-Project/OZI/commit/a7903eb30aec3bc1afd7a90b3f641bc59a30945c))

*  Bump OZI-Project/release from 0.4.0 to 0.4.1

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.4.0 to 0.4.1.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/8b5e46e9d8899289f676ca2b432a63fe2faa93f9...033e98adfa7086d1b1273bcc80b0576297e733bd)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`04a849d`](https://github.com/OZI-Project/OZI/commit/04a849d5ffc200d5f5f609dcee64fcde0f516a9d))


### Other


* 1.8.4

Automatically generated by python-semantic-release
([`2eb96c5`](https://github.com/OZI-Project/OZI/commit/2eb96c51c460f1607a3051d3243878447ac4fccf))

* 
updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`c3fe678`](https://github.com/OZI-Project/OZI/commit/c3fe678ea94dd230d7c4a74c173919b4ffc1970d))

* 
updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`b5f2ce9`](https://github.com/OZI-Project/OZI/commit/b5f2ce9dee8273df8fb78225f2a0fae4cc27d616))

## 1.8.3 (2024-05-19)


### 🐛 Fixed Bugs

*  Shorten reprs of pkg and project spec. — rjdbcm <ozi.project@outlook.com>
([`0dc3f21`](https://github.com/OZI-Project/OZI/commit/0dc3f21e2a61d02ca7af9ffdbf60644dfa4ac511))


### Other


* 1.8.3

Automatically generated by python-semantic-release
([`9167d71`](https://github.com/OZI-Project/OZI/commit/9167d7127db7cdac9bfc90826cdf41da42134f58))

## 1.8.2 (2024-05-19)


### 🐛 Fixed Bugs

*  fix unimplemented repr in ``ozi.spec.base.Default`` — rjdbcm <ozi.project@outlook.com>
([`e7791d0`](https://github.com/OZI-Project/OZI/commit/e7791d017cf770d47fe847bc8d949d634e81ce95))


### Other


* 1.8.2

Automatically generated by python-semantic-release
([`23a8a4d`](https://github.com/OZI-Project/OZI/commit/23a8a4dcf25575015980d678397b2e7727058140))

## 1.8.1 (2024-05-18)


### 🚸 Improved Usability

*  truncated ``ozi.spec`` repr.
([`a5a3bd6`](https://github.com/OZI-Project/OZI/commit/a5a3bd605c33aad9c0431ff1ac983f8e32357634))


### Other


* 1.8.1

Automatically generated by python-semantic-release
([`c9e8fa5`](https://github.com/OZI-Project/OZI/commit/c9e8fa5a8e1780ed7bff1bb9a6c5b41b4c63c1d9))

* 1.8.1

Automatically generated by python-semantic-release
([`e7d96ae`](https://github.com/OZI-Project/OZI/commit/e7d96aefc5b174e24ffd34e87b503d800336b334))

## 1.8.0 (2024-05-18)


### ⬆️ Upgraded Dependencies

* 📌 blastpipe~=2024.8 — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`d356293`](https://github.com/OZI-Project/OZI/commit/d3562932378ce2c11ef72e9e01e414dfab0f6db3))

*  OZI-Project/checkpoint 0.2.0 — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`1cc5620`](https://github.com/OZI-Project/OZI/commit/1cc5620f3bea66a56247a7ad61f9f854926b0286))


### 📌 Pinned Dependencies

*  Update ozi/spec/ci.py - checkpoint 0.2.0 — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`48b4cf6`](https://github.com/OZI-Project/OZI/commit/48b4cf699fd69af3ae5d152beeb80a43184352a2))


### ✨ Implemented Features

*  Update README.rst for 1.8 — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`31f26dd`](https://github.com/OZI-Project/OZI/commit/31f26dd17f6ed28adf0250e9f4725a93696742d4))

*  Enable pipx isolation of apps.
🔨 Update spec files.
⬆️ OZI Spec v0.4
🔧 add 1.8 release branch pattern.

The following are no longer in ``meson.options:module-only``:
* sigstore
* Flake8-pyproject
* coverage
* flake8
* bandit
* black
* isort
* pyright
* mypy

 — rjdbcm <ozi.project@outlook.com>
([`50d4509`](https://github.com/OZI-Project/OZI/commit/50d450935d3333a58c98c8dbf19d594620adce36))


### Other


* 1.8.0

Automatically generated by python-semantic-release
([`9ef16dc`](https://github.com/OZI-Project/OZI/commit/9ef16dcbc23ee6095de9537e4d645554d3cb6e63))

* Update README.rst — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`a1fd7f8`](https://github.com/OZI-Project/OZI/commit/a1fd7f828180302789e242564c5b34bc7df7244b))

* Feature/1.8 pipx integration (#540)
([`50d4509`](https://github.com/OZI-Project/OZI/commit/50d450935d3333a58c98c8dbf19d594620adce36))

* Update dist-workflow.yml checkpoint 0.2.0 — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`a155b06`](https://github.com/OZI-Project/OZI/commit/a155b0627a82cf6d9868b13b74f7697568cbbfd5))

## 1.7.4 (2024-05-18)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/draft from 0.1.1 to 0.1.2

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.1.1 to 0.1.2.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/7fb25933b941dc9531abb0809d0be0c79404b351...574ec018b98bb323c079a826b54247c78cc4abac)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`b285fdc`](https://github.com/OZI-Project/OZI/commit/b285fdc6eb8628e49e498da3ee2b6a110ef32b88))

*  Bump actions/checkout from 4.1.5 to 4.1.6

Bumps [actions/checkout](https://github.com/actions/checkout) from 4.1.5 to 4.1.6.
- [Release notes](https://github.com/actions/checkout/releases)
- [Changelog](https://github.com/actions/checkout/blob/main/CHANGELOG.md)
- [Commits](https://github.com/actions/checkout/compare/44c2b7a8a4ea60a981eaca3cf939b5f4305c123b...a5ac7e51b41094c92402da3b24376905380afc29)


updated-dependencies:
- dependency-name: actions/checkout
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`f6daa93`](https://github.com/OZI-Project/OZI/commit/f6daa9357359255cbc1b53076448bb95c6dc2048))


### Other


* 1.7.4

Automatically generated by python-semantic-release
([`6b7a687`](https://github.com/OZI-Project/OZI/commit/6b7a687b5628371d5b551f9d6928c0d8a0ae92f5))

## 1.7.3 (2024-05-16)


### 🐛 Fixed Bugs

*  Fix entrypoint arg conflict.

``ozi --license-expression`` is now ``ozi --check-license-expr``
([`e13d0ed`](https://github.com/OZI-Project/OZI/commit/e13d0eddb98513b6646e20c8cb10f2ed2bfec6b2))


### Other


* 1.7.3

Automatically generated by python-semantic-release
([`f97a8b5`](https://github.com/OZI-Project/OZI/commit/f97a8b514fad84d9fc09f5bd8fc14d324d940d51))

## 1.7.2 (2024-05-16)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.25.4 to 3.25.5

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.4 to 3.25.5.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/ccf74c947955fd1cf117aef6a0e4e66191ef6f61...b7cec7526559c32f1616476ff32d17ba4c59b2d6)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`601250f`](https://github.com/OZI-Project/OZI/commit/601250f26f2ad97f20e9fb8ad8c718dfca60e1c3))


### 🐛 Fixed Bugs

*  fix imports.
([`bf0ac1f`](https://github.com/OZI-Project/OZI/commit/bf0ac1f6c577eb1976d1de4927c2d89e2dcd3170))

*  remove offset argv in ``ozi-new`` — rjdbcm <ozi.project@outlook.com>
([`a27b2a5`](https://github.com/OZI-Project/OZI/commit/a27b2a5db40454fc8d212f9aa1f8070f62914bc0))


### Other


* 1.7.2

Automatically generated by python-semantic-release
([`a0b9f80`](https://github.com/OZI-Project/OZI/commit/a0b9f8080c741a7d6f5c5552958aea9614ccb46e))

## 1.7.1 (2024-05-14)


### 📌 Pinned Dependencies

*  Spec version set to 0.3 — rjdbcm <ozi.project@outlook.com>
([`d007b1e`](https://github.com/OZI-Project/OZI/commit/d007b1e55cbf68488ca97f4594f03beec2f39a04))


### Other


* 1.7.1

Automatically generated by python-semantic-release
([`dc59dca`](https://github.com/OZI-Project/OZI/commit/dc59dca14e5c72a8d969af0998681dc5d2eb9daf))

## 1.7.0 (2024-05-14)


### Other


* 1.7.0

Automatically generated by python-semantic-release
([`26891bb`](https://github.com/OZI-Project/OZI/commit/26891bb34914129879dfa8be5432f5f628e70a43))

* Update pyproject.toml — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`2e4d278`](https://github.com/OZI-Project/OZI/commit/2e4d2781177aead20e41ea24cd9586e30113f361))

## 1.6.5 (2024-05-13)


### 🐛 Fixed Bugs

*  Fix bug introduced in ``ozi-fix`` 1.6.4.

missing target positional argument. — rjdbcm <ozi.project@outlook.com>
([`335558d`](https://github.com/OZI-Project/OZI/commit/335558da5eda61d230990d4429d816455372e143))


### ✨ Implemented Features

*  markdown and plaintext readmes. — rjdbcm <ozi.project@outlook.com>
([`bf5f5ac`](https://github.com/OZI-Project/OZI/commit/bf5f5ac5c4824b82be8b29b496025b28a6b3ffce))


### Other


* 1.6.5

Automatically generated by python-semantic-release
([`c174809`](https://github.com/OZI-Project/OZI/commit/c1748091bab7227fbfabedad91d7ac7a594740e5))

## 1.6.4 (2024-05-13)


### 🐛 Fixed Bugs

*  Parsers default to target the current working dir. — rjdbcm <ozi.project@outlook.com>
([`7628281`](https://github.com/OZI-Project/OZI/commit/7628281ade6849d747f797ad7e29816c0fa7561a))


### Other


* 1.6.4

Automatically generated by python-semantic-release
([`8f4e499`](https://github.com/OZI-Project/OZI/commit/8f4e499ceecb1c2aab136b6067b31a565519a74a))

* run black
([`18f2ad8`](https://github.com/OZI-Project/OZI/commit/18f2ad80aecb5a7209ba9499673ceae6e1bfb978))

* run black — rjdbcm <ozi.project@outlook.com>
([`344ad5d`](https://github.com/OZI-Project/OZI/commit/344ad5da25b74f6b7b5edfa6077a1149ded15440))

## 1.6.3 (2024-05-13)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/draft from 0.1.0 to 0.1.1

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.1.0 to 0.1.1.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/12b9a4f0d4e25ff5466bf2b0486d11aa4f3bf30d...7fb25933b941dc9531abb0809d0be0c79404b351)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`c7d8ba4`](https://github.com/OZI-Project/OZI/commit/c7d8ba484043458621d0696a4010f2e249410fae))


### Other


* 1.6.3

Automatically generated by python-semantic-release
([`3f59a4a`](https://github.com/OZI-Project/OZI/commit/3f59a4aefee932ecf8cea6b674172d395174c3d0))

* Update ci.py — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`7e71362`](https://github.com/OZI-Project/OZI/commit/7e71362bba2fbf422a9a7f29954a027fd506cd0c))

## 1.6.2 (2024-05-13)


### ✏️ Corrected Typos

*  fix version pin
([`ed5e623`](https://github.com/OZI-Project/OZI/commit/ed5e6230852b419e5a33841eda212c99c8839413))

* 📌 add ``packaging`` as dependency. — rjdbcm <ozi.project@outlook.com>
([`1978a4c`](https://github.com/OZI-Project/OZI/commit/1978a4cf21eeb0b44643f609f3a382c5e4a550ec))


### Other


* 1.6.2

Automatically generated by python-semantic-release
([`e134b2e`](https://github.com/OZI-Project/OZI/commit/e134b2ece1ee359cd338aab0f6985caa2dd51d85))

## 1.6.1 (2024-05-12)


### 💬


*  clean up package maintainer names. — rjdbcm <ozi.project@outlook.com>
([`286cfea`](https://github.com/OZI-Project/OZI/commit/286cfea531180021b788072ae55e330a9885d965))


### Other


* 1.6.1

Automatically generated by python-semantic-release
([`2a2398b`](https://github.com/OZI-Project/OZI/commit/2a2398bb717eca0c559919969b8337c886a464de))

* Update scorecard.yml — Eden Rose, MSc <ozi.project@outlook.com>
([`efd87cd`](https://github.com/OZI-Project/OZI/commit/efd87cdfd4401b03dd6d01ece19279ce02574507))

## 1.6.0 (2024-05-10)


### Other


* 1.6.0

Automatically generated by python-semantic-release
([`732311b`](https://github.com/OZI-Project/OZI/commit/732311b3c662838f4bbc7d044581e82d50eeebb7))

## 1.5.1 (2024-05-10)


### ⬆️ Upgraded Dependencies

*  Update blastpipe~=2024.6.3 — Eden Rose, MSc <ozi.project@outlook.com>
([`45d855c`](https://github.com/OZI-Project/OZI/commit/45d855ca84f9c68b38e80d530c66d2ae3021fc31))

*  Bump ossf/scorecard-action from 2.3.1 to 2.3.3

Bumps [ossf/scorecard-action](https://github.com/ossf/scorecard-action) from 2.3.1 to 2.3.3.
- [Release notes](https://github.com/ossf/scorecard-action/releases)
- [Changelog](https://github.com/ossf/scorecard-action/blob/main/RELEASE.md)
- [Commits](https://github.com/ossf/scorecard-action/compare/0864cf19026789058feabb7e87baa5f140aac736...dc50aa9510b46c811795eb24b2f1ba02a914e534)


updated-dependencies:
- dependency-name: ossf/scorecard-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`a081ae5`](https://github.com/OZI-Project/OZI/commit/a081ae5d80107471828f40c0486c7a6df181ee89))


### 📝 Updated Documentation

*  Update pyproject.toml add branch release pattern. — Eden Rose, MSc <ozi.project@outlook.com>
([`e27296a`](https://github.com/OZI-Project/OZI/commit/e27296ac8e6cbb2152dd121ebb817392e20f19c7))


### ✨ Implemented Features

*  update spec version to 0.2 — rjdbcm <ozi.project@outlook.com>
([`b9decce`](https://github.com/OZI-Project/OZI/commit/b9decce98202932032ddb937263450bb462d52c3))


### Other


* 1.5.1

Automatically generated by python-semantic-release
([`0d1dab6`](https://github.com/OZI-Project/OZI/commit/0d1dab64c32fe3591de7049d6cd23aa40e34888d))

## 1.5.0 (2024-05-09)


### 🔨 Updated Configuration

*  add 1.5 release branch group — Eden Rose, MSc <ozi.project@outlook.com>
([`fa09315`](https://github.com/OZI-Project/OZI/commit/fa09315597531d789b1a364e35bdb3885e20e301))


### Other


* 1.5.0

Automatically generated by python-semantic-release
([`cab27c9`](https://github.com/OZI-Project/OZI/commit/cab27c9cc432626747a15bb3016673323689c071))

## 1.4.3 (2024-05-08)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.25.3 to 3.25.4

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.3 to 3.25.4.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/d39d31e687223d841ef683f52467bd88e9b21c14...ccf74c947955fd1cf117aef6a0e4e66191ef6f61)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`8e83edb`](https://github.com/OZI-Project/OZI/commit/8e83edbd2c514fa57bb9cccf51730f9eebc6a6e8))

*  Bump OZI-Project workflow actions

* OZI-Project/checkpoint 0.1.6
* OZI-Project/release 0.3.2
* OZI-Project/release 0.1.1 — rjdbcm <ozi.project@outlook.com>
([`fb19e5a`](https://github.com/OZI-Project/OZI/commit/fb19e5a1140d3a8fc617d7d3cdca0b8880e1e465))

*  Bump actions/checkout from 4.1.4 to 4.1.5

Bumps [actions/checkout](https://github.com/actions/checkout) from 4.1.4 to 4.1.5.
- [Release notes](https://github.com/actions/checkout/releases)
- [Changelog](https://github.com/actions/checkout/blob/main/CHANGELOG.md)
- [Commits](https://github.com/actions/checkout/compare/0ad4b8fadaa221de15dcec353f45205ec38ea70b...44c2b7a8a4ea60a981eaca3cf939b5f4305c123b)


updated-dependencies:
- dependency-name: actions/checkout
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`971c548`](https://github.com/OZI-Project/OZI/commit/971c5483215457df5c70d99bcf34bb7513622882))


### 🔨 Updated Scripts

*  clean up jinja2 import. — rjdbcm <ozi.project@outlook.com>
([`b6e6f50`](https://github.com/OZI-Project/OZI/commit/b6e6f505c8221bcab9e2f80ea44de65505cdc6ae))


### ✏️ Corrected Typos

*  fix docstring raw html escapes — rjdbcm <ozi.project@outlook.com>
([`ef63113`](https://github.com/OZI-Project/OZI/commit/ef63113a8f60366fff120b28cf1a2e9f3382183f))

*  missing ``from __future__ import annotations`` — rjdbcm <ozi.project@outlook.com>
([`508291a`](https://github.com/OZI-Project/OZI/commit/508291ade1880fdd0e96aeefb78d43265126f600))

*  fix RuntimeWarning that should be FutureWarning — rjdbcm <ozi.project@outlook.com>
([`0f23f31`](https://github.com/OZI-Project/OZI/commit/0f23f3121e2434cbe509b1230735c8a6dba56cd9))


### 📌 Pinned Dependencies

*  Set blastpipe 2024.5 as the compatible version. — rjdbcm <ozi.project@outlook.com>
([`1b33b6c`](https://github.com/OZI-Project/OZI/commit/1b33b6c3a58e9069b83a1ac94dc46c541a68aead))


### ✨ Implemented Features

*  Add cython extensions with ``ozi-fix``

Also add ``--[no-]enable-cython`` to ``ozi-new``.
⬆️ blastpipe 2024.5 — rjdbcm <ozi.project@outlook.com>
([`407db9b`](https://github.com/OZI-Project/OZI/commit/407db9b1abc53b30e9aa73ab589a2e5b0056f726))


### Other


* 1.4.3

Automatically generated by python-semantic-release
([`2da8874`](https://github.com/OZI-Project/OZI/commit/2da887413c25b5b88f43a9e7648335b6e9c8a661))

## 1.4.2 (2024-05-05)


### 🐛 Fixed Bugs

*  correct deprecated Python warnings.

User-facing deprecation warnings should always use FutureWarning. — Eden Rose, MSc <ozi.project@outlook.com>
([`df2de03`](https://github.com/OZI-Project/OZI/commit/df2de0354a546f6a092c277a479b2e0fa6b2edb5))


### Other


* 1.4.2

Automatically generated by python-semantic-release
([`4bc57de`](https://github.com/OZI-Project/OZI/commit/4bc57deee389a18b3db97787a328c668b13b1d31))

## 1.4.1 (2024-05-05)


### 🐛 Fixed Bugs

*  Update ozi.spec.python

PendingDeprecationWarning 52 weeks prior to python end-of-life
DeprecationWarning instead of RuntimeError if python end-of-life reached. — Eden Rose, MSc <ozi.project@outlook.com>
([`b2ffa99`](https://github.com/OZI-Project/OZI/commit/b2ffa995cd3b907d5a9db8e4606f01db3c09ca56))


### Other


* 1.4.1

Automatically generated by python-semantic-release
([`d72941c`](https://github.com/OZI-Project/OZI/commit/d72941c7343fea65e5e332697fa942144b1fe733))

* Update ci.py — Eden Rose, MSc <ozi.project@outlook.com>
([`54917ec`](https://github.com/OZI-Project/OZI/commit/54917eca88d25e2e2ecc567cbd50965407c86689))

* Update pyproject.toml — Eden Rose, MSc <ozi.project@outlook.com>
([`4dfc574`](https://github.com/OZI-Project/OZI/commit/4dfc5749b8b59a112a498c6aa0385fe1b6e6ae66))

## 1.4.0 (2024-05-04)


### Other


* 1.4.0

Automatically generated by python-semantic-release
([`2f07cb2`](https://github.com/OZI-Project/OZI/commit/2f07cb2ab28b4997939e282c117e00a2ab95e3bd))

* Update pyproject.toml - add 1.4 branch — Eden Rose, MSc <ozi.project@outlook.com>
([`40954c3`](https://github.com/OZI-Project/OZI/commit/40954c3fa1ed1a850eb5b1d18874b1dfe46cae9d))

## 1.3.3 (2024-05-04)


### Other


* 1.3.3

Automatically generated by python-semantic-release
([`85ef1bd`](https://github.com/OZI-Project/OZI/commit/85ef1bdee9937d4519cb604474fd937515cbc93d))

## 1.3.2 (2024-05-03)


### ⬆️ Upgraded Dependencies

*  Update requirements.in, bump blastpipe. — Eden Rose, MSc <ozi.project@outlook.com>
([`effa8a7`](https://github.com/OZI-Project/OZI/commit/effa8a7f7018d64200888e4351f85b25bda44b09))

*  Update blastpipe pin to 2024.4.0 — rjdbcm <ozi.project@outlook.com>
([`bfea6bf`](https://github.com/OZI-Project/OZI/commit/bfea6bf78717dcc41ed8e96d4333c792d0a061dd))


### 🐛 Fixed Bugs

*  Update meson.build - dont build requirements during bootstrap. — Eden Rose, MSc <ozi.project@outlook.com>
([`33468ef`](https://github.com/OZI-Project/OZI/commit/33468ef723579b8505c47d2fb0dabfd55fb87688))

*  Update requirements.in — Eden Rose, MSc <ozi.project@outlook.com>
([`117fc93`](https://github.com/OZI-Project/OZI/commit/117fc939ca84bf0c038298d6282b046fb29f3d9e))

*  remove blastpipe wrapfile. — rjdbcm <ozi.project@outlook.com>
([`d9bae28`](https://github.com/OZI-Project/OZI/commit/d9bae287ee6ad5a852cfb51a5636987ebb368d84))

*  Update meson.build fix blastpipe already being built. — Eden Rose, MSc <ozi.project@outlook.com>
([`7b5cf04`](https://github.com/OZI-Project/OZI/commit/7b5cf046d3bb6b76515273fc7fd16d0584e44698))

*  fix OZI.build — rjdbcm <ozi.project@outlook.com>
([`6f9cb08`](https://github.com/OZI-Project/OZI/commit/6f9cb08f9f6ce7622bea8ddf0ab0fdb02361240e))

*  Fix OZI.build — rjdbcm <ozi.project@outlook.com>
([`9cd8447`](https://github.com/OZI-Project/OZI/commit/9cd8447a4045c9688f79c18578fce36549613949))


### 📌 Pinned Dependencies

*  Update requirements.in - blastpipe 2024.4.3 — Eden Rose, MSc <ozi.project@outlook.com>
([`0d4a8a3`](https://github.com/OZI-Project/OZI/commit/0d4a8a34cfdf2761559c3435da4eeda6276311d4))


### ✨ Implemented Features

*  OZI-Project/release 0.3.0 and OZI.build 0.0.14 (#478)

* Update pyproject.toml - OZI.build 0.0.14 — Eden Rose, MSc <ozi.project@outlook.com>

* Update ci.py

OZI-Project/OZI.build 0.0.14
OZI-Project/release 0.3.0 — Eden Rose, MSc <ozi.project@outlook.com>

* Update dist-workflow.yml

Bump to 0.3.0 sha256:3067778a8ac4622c1075321b46b7a7333bea64a0 — Eden Rose, MSc <ozi.project@outlook.com>

 — Eden Rose, MSc <ozi.project@outlook.com>
([`83b8027`](https://github.com/OZI-Project/OZI/commit/83b80271f90a51b4b97914c4eb48bbde9b7f87c7))


### Other


* 1.3.2

Automatically generated by python-semantic-release
([`ccf781b`](https://github.com/OZI-Project/OZI/commit/ccf781bccacb0de8b7af5c7eeaea6ff999033f6e))

* Update requirements.in - rollback blastpipe to stable version — Eden Rose, MSc <ozi.project@outlook.com>
([`49bfb81`](https://github.com/OZI-Project/OZI/commit/49bfb815003ffa930911686b296fe2874d664549))

## 1.3.1 (2024-05-03)


### ⬆️ Upgraded Dependencies

*  OZI.build 0.0.9 for correct wheel names. — rjdbcm <ozi.project@outlook.com>
([`f800863`](https://github.com/OZI-Project/OZI/commit/f80086322ef1adee703fe006c313bec5690910c2))

* 🐛 Fix ``pyproject.toml:tool.ozi-build.metadata`` rendering.

Also updates the blastpipe pin to ``>=2024.4`` — rjdbcm <ozi.project@outlook.com>
([`f800863`](https://github.com/OZI-Project/OZI/commit/f80086322ef1adee703fe006c313bec5690910c2))

* 🐛 Fix OZI.build missing builddir in checkpoint runs. — rjdbcm <ozi.project@outlook.com>
([`f800863`](https://github.com/OZI-Project/OZI/commit/f80086322ef1adee703fe006c313bec5690910c2))


### 🐛 Fixed Bugs

* ⬆️ Bump OZI.build 0.0.12 — rjdbcm <ozi.project@outlook.com>
([`4d24665`](https://github.com/OZI-Project/OZI/commit/4d24665dabab58f19119bae5c25581c98fdfe32c))

*  OZI.build 0.0.11 fixes for in-situ metadata generation
([`f800863`](https://github.com/OZI-Project/OZI/commit/f80086322ef1adee703fe006c313bec5690910c2))

*  fix pin — rjdbcm <ozi.project@outlook.com>
([`f800863`](https://github.com/OZI-Project/OZI/commit/f80086322ef1adee703fe006c313bec5690910c2))

* ⬆️ OZI.build 0.0.11 fixes for in-situ metadata generation. — rjdbcm <ozi.project@outlook.com>
([`f800863`](https://github.com/OZI-Project/OZI/commit/f80086322ef1adee703fe006c313bec5690910c2))

*  revert blastpipe pin — rjdbcm <ozi.project@outlook.com>

 — rjdbcm <ozi.project@outlook.com>
Signed-off-by: Eden Rose, MSc <ozi.project@outlook.com>
([`f800863`](https://github.com/OZI-Project/OZI/commit/f80086322ef1adee703fe006c313bec5690910c2))


### Other


* 1.3.1

Automatically generated by python-semantic-release
([`2519ccb`](https://github.com/OZI-Project/OZI/commit/2519ccbf63f0846a9cfff0e733d71d2389dd1f2f))

* 1.3.1

Automatically generated by python-semantic-release
([`3b05e2e`](https://github.com/OZI-Project/OZI/commit/3b05e2ef2ad0680746e6dc1009b7d3424f1aefa1))

## 1.3.0 (2024-05-03)


### ⬆️ Upgraded Dependencies

*  OZI.build 0.0.9 for correct wheel names. (#457) — rjdbcm <ozi.project@outlook.com>
([`adde41a`](https://github.com/OZI-Project/OZI/commit/adde41a9dd0eadcea050905799dc0509b3fb7e24))

*  Bump actions/dependency-review-action from 4.3.1 to 4.3.2

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.3.1 to 4.3.2.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/e58c696e52cac8e62d61cc21fda89565d71505d7...0c155c5e8556a497adf53f2c18edabf945ed8e70)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`7b83047`](https://github.com/OZI-Project/OZI/commit/7b830474618e3dd1778c8498ffbef75939ebd274))

*  OZI-Project/release 0.2.4 — rjdbcm <ozi.project@outlook.com>
([`cefd702`](https://github.com/OZI-Project/OZI/commit/cefd702d81b1e0b9428d67b78c10a8cebcc1b3ef))

*  OZI-Project/release 0.2.2

* Update ci.py  — Eden Rose, MSc <ozi.project@outlook.com>

* Update dist-workflow.yml — Eden Rose, MSc <ozi.project@outlook.com>

 — Eden Rose, MSc <ozi.project@outlook.com>
([`28a1e70`](https://github.com/OZI-Project/OZI/commit/28a1e70a41dfe62a94e124790ec34ba592c9d773))

*  release 0.2.1

* Update dist-workflow.yml - release 0.2.1 — Eden Rose, MSc <ozi.project@outlook.com>

* Update ci.py - release 0.2.1 — Eden Rose, MSc <ozi.project@outlook.com>

 — Eden Rose, MSc <ozi.project@outlook.com>
([`eb56e91`](https://github.com/OZI-Project/OZI/commit/eb56e91c27c40b359674b29d744124c25eacf322))

*  OZI.build 0.0.7 in spec — rjdbcm <ozi.project@outlook.com>
([`1e3a51d`](https://github.com/OZI-Project/OZI/commit/1e3a51dfd7fc140e122a999ae92e642a84cea822))

*  OZI-Project/release 0.2.0 for OZI.build backend change. — rjdbcm <ozi.project@outlook.com>
([`24e23ba`](https://github.com/OZI-Project/OZI/commit/24e23baf1d795ee265580c84c721d55b6d7f037f))

*  OZI.build 0.0.7 — rjdbcm <ozi.project@outlook.com>
([`817265b`](https://github.com/OZI-Project/OZI/commit/817265bd093260eda4e6ad1136fd87552a2657b5))

*  OZI.build 0.0.6 — rjdbcm <ozi.project@outlook.com>
([`958b39a`](https://github.com/OZI-Project/OZI/commit/958b39aad552d2bc91520c2320c9fa94a1df4c09))


### 🔨 Updated Scripts

*  unlink extant PKG-INFO during dist. — rjdbcm <ozi.project@outlook.com>
([`7b99c62`](https://github.com/OZI-Project/OZI/commit/7b99c62023ab54f2c6b9da017f1cbdcce5f2f949))

*  remove monkey-patched setuptools_scm dist script.
([`0505516`](https://github.com/OZI-Project/OZI/commit/050551600633572a647e239ebcfcadd5904c1c7f))

*  auto pkg-info — rjdbcm <ozi.project@outlook.com>
([`dc0ee47`](https://github.com/OZI-Project/OZI/commit/dc0ee47ef9789fabadbd63fee08ba62093bf719b))

*  revert pkg-info move — rjdbcm <ozi.project@outlook.com>
([`ff8356f`](https://github.com/OZI-Project/OZI/commit/ff8356f4fab00fd9b632f4fae356c1c5632a94b7))

*  change metadata pkg-info-file — rjdbcm <ozi.project@outlook.com>
([`84a6b13`](https://github.com/OZI-Project/OZI/commit/84a6b13c8d8b86b925c0c014b6d863caf5c5df2e))

*  Implement OZI.build — rjdbcm <ozi.project@outlook.com>
([`7a25a87`](https://github.com/OZI-Project/OZI/commit/7a25a870cefee7ad5bf054c152bd81d59f177055))


### ✨ Implemented Features

*  Add 1.3 release group! — Eden Rose, MSc <ozi.project@outlook.com>
([`fd418e4`](https://github.com/OZI-Project/OZI/commit/fd418e4b7ca008b63f62da106f9f7d5bf020d80d))

*  OZI 1.3 — Eden Rose, MSc <ozi.project@outlook.com>
([`c957112`](https://github.com/OZI-Project/OZI/commit/c9571120ba6765801e8f0447f60af0b5cead88b3))


### Other


* 1.3.0

Automatically generated by python-semantic-release
([`9688d72`](https://github.com/OZI-Project/OZI/commit/9688d72eef5ad04f0b868830c431751a5b18381d))

* 1.3.0

Automatically generated by python-semantic-release
([`19dde5a`](https://github.com/OZI-Project/OZI/commit/19dde5a367c569c7fe5e8f2f3c2044135942c0f9))

* 1.3.0

Automatically generated by python-semantic-release
([`400ccab`](https://github.com/OZI-Project/OZI/commit/400ccab9cbd7bba608e2c9fa007ec7a763756c86))

* 1.3.0

Automatically generated by python-semantic-release
([`868df32`](https://github.com/OZI-Project/OZI/commit/868df32ea7d93c7e95c38a6a06def02dcda76372))

* 1.3.0

Automatically generated by python-semantic-release
([`a9afaeb`](https://github.com/OZI-Project/OZI/commit/a9afaeb2c75e2751c42c09d695b16b679f0a8ae1))

* OZI-Project/release 0.2.5 — rjdbcm <ozi.project@outlook.com>
([`e3801f4`](https://github.com/OZI-Project/OZI/commit/e3801f4161facecbb31385c933bfd0e90dd7bb83))

* Update dist-workflow.yml — Eden Rose, MSc <ozi.project@outlook.com>
([`65b7b67`](https://github.com/OZI-Project/OZI/commit/65b7b672b70a5791fbc76807b1dbcc3ed3036961))

* Update ci.py — Eden Rose, MSc <ozi.project@outlook.com>
([`924cd7e`](https://github.com/OZI-Project/OZI/commit/924cd7ee3cbb700cb55d772b06a2a8752fb2abcd))

* 1.3.0

Automatically generated by python-semantic-release
([`388b237`](https://github.com/OZI-Project/OZI/commit/388b237bbd96e0a2e818ba775e1012cc408f1fbb))

* 1.3.0

Automatically generated by python-semantic-release
([`98f699a`](https://github.com/OZI-Project/OZI/commit/98f699a7bea65bb88f58f0401cfbe694421d99ac))

* use pkg-info-file — rjdbcm <ozi.project@outlook.com>
([`1f09610`](https://github.com/OZI-Project/OZI/commit/1f096107ab8818f5e7d72c181a41cf29971573a5))

## 1.2.2 (2024-04-30)


### ⬆️ Upgraded Dependencies

*  Bump step-security/harden-runner from 2.7.0 to 2.7.1

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.7.0 to 2.7.1.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/63c24ba6bd7ba022e95695ff85de572c04a18142...a4aa98b93cab29d9b1101a6143fb8bce00e2eac4)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`3184386`](https://github.com/OZI-Project/OZI/commit/3184386d8308b4604d6f6c832940045176ec1e2d))

*  Bump actions/dependency-review-action from 4.2.5 to 4.3.1

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.2.5 to 4.3.1.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/5bbc3ba658137598168acb2ab73b21c432dd411b...e58c696e52cac8e62d61cc21fda89565d71505d7)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`1f7e9f1`](https://github.com/OZI-Project/OZI/commit/1f7e9f199315405bc2a17af147c41047ace16aa3))


### 📝 Updated Documentation

*  update docstrings for 1.2 (#429) — rjdbcm <ozi.project@outlook.com>
([`d72f67c`](https://github.com/OZI-Project/OZI/commit/d72f67c298a0dee02ad6abc3006b875b3067b397))


### Other


* 1.2.2

Automatically generated by python-semantic-release
([`5a4bf0c`](https://github.com/OZI-Project/OZI/commit/5a4bf0cd1c302aed909768774178dddfd358c069))

## 1.2.1 (2024-04-28)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/release 0.1.18 > 0.1.17
([`656c609`](https://github.com/OZI-Project/OZI/commit/656c609ec37886c31679b7be6de2a08d9a950c0b))

*  Update dist-workflow.yml - release 0.1.18 > 0.1.17 — Eden Rose, MSc <ozi.project@outlook.com>
([`656c609`](https://github.com/OZI-Project/OZI/commit/656c609ec37886c31679b7be6de2a08d9a950c0b))

*  bump release to 0.1.18 — Eden Rose, MSc <ozi.project@outlook.com>

 — Eden Rose, MSc <ozi.project@outlook.com>
([`656c609`](https://github.com/OZI-Project/OZI/commit/656c609ec37886c31679b7be6de2a08d9a950c0b))


### Other


* 1.2.1

Automatically generated by python-semantic-release
([`e5b6999`](https://github.com/OZI-Project/OZI/commit/e5b6999e3295a64dddc345916ef57ea5aa763bca))

## 1.2.0 (2024-04-28)


### 📌 Pinned Dependencies

*  set blastpipe pin to 2024.2.6. — rjdbcm <ozi.project@outlook.com>
([`7ed571c`](https://github.com/OZI-Project/OZI/commit/7ed571c12c8e8b91082cbf7044f0ce28a7d63090))


### ✨ Implemented Features

*  Reduce the overall repo size.

Move templates to the blastpipe repo.
Make blastpipe a dependency. — rjdbcm <ozi.project@outlook.com>
([`cfd1234`](https://github.com/OZI-Project/OZI/commit/cfd123435aaf83b4be871c1e42ea99c183e87999))


### Other


* 1.2.0

Automatically generated by python-semantic-release
([`067050e`](https://github.com/OZI-Project/OZI/commit/067050efca0943d431276ffbb3dd73dc6a8bb36f))

* 🚨 add ``# pyright: ignore`` to blastpipe filter imports. — rjdbcm <ozi.project@outlook.com>
([`580750b`](https://github.com/OZI-Project/OZI/commit/580750b20cbf62152d81e7c0c91e94084349feed))

* add 1.2 release branch pattern — rjdbcm <ozi.project@outlook.com>
([`7c78a1e`](https://github.com/OZI-Project/OZI/commit/7c78a1e4d8a76db1091851de9084af6a6f50ccd9))

## 1.1.6 (2024-04-27)


### ⚗️


* (``ozi.render.load_environment``): Add globals dict argument. — rjdbcm <ozi.project@outlook.com>
([`eaac863`](https://github.com/OZI-Project/OZI/commit/eaac8633e08b2f345333e4a4bfdf0b350ce7966d))


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.25.2 to 3.25.3

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.2 to 3.25.3.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/8f596b4ae3cb3c588a5c46780b86dd53fef16c52...d39d31e687223d841ef683f52467bd88e9b21c14)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`e7888b0`](https://github.com/OZI-Project/OZI/commit/e7888b059f9223008680a7d9dfd28e01a07205ba))

*  Bump actions/checkout from 4.1.3 to 4.1.4

Bumps [actions/checkout](https://github.com/actions/checkout) from 4.1.3 to 4.1.4.
- [Release notes](https://github.com/actions/checkout/releases)
- [Changelog](https://github.com/actions/checkout/blob/main/CHANGELOG.md)
- [Commits](https://github.com/actions/checkout/compare/1d96c772d19495a3b5c517cd2bc0cb401ea0529f...0ad4b8fadaa221de15dcec353f45205ec38ea70b)


updated-dependencies:
- dependency-name: actions/checkout
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`41251c9`](https://github.com/OZI-Project/OZI/commit/41251c94d744593a3931d1d5acd70ac18f2838e5))


### 🐛 Fixed Bugs

*  exclude double quotes from fuzzer input. — rjdbcm <ozi.project@outlook.com>
([`361a75a`](https://github.com/OZI-Project/OZI/commit/361a75a9e1b63dc6ad12b24cf85f9762a213c8a7))


### Other


* 1.1.6

Automatically generated by python-semantic-release
([`54026f2`](https://github.com/OZI-Project/OZI/commit/54026f20c8d042a344610d2243ec55185959475a))

* 🚨 run ``black -S tests`` — rjdbcm <ozi.project@outlook.com>
([`fdd8fe2`](https://github.com/OZI-Project/OZI/commit/fdd8fe2fdbe6b7941972efc33aa77ee1707dae5a))

## 1.1.5 (2024-04-24)


### ⬆️ Upgraded Dependencies

*  Bump release to 0.1.17 — Eden Rose, MSc <ozi.project@outlook.com>
([`eca9b71`](https://github.com/OZI-Project/OZI/commit/eca9b713ea773157c3912eca2fb4d87ff38d0ef5))

*  Bump OZI-Project/release from 0.1.16 to 0.1.17

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.1.16 to 0.1.17.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/cde80205350cc9bd7c00c042b788136b36bd1828...ceffb3c8beef212a5abaffeac486d67fb247381b)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`5bd1337`](https://github.com/OZI-Project/OZI/commit/5bd1337de8893888ea714f9d361a9d287d2caabc))


### 🔨 Updated Scripts

*  Correct pytest ``--cov=`` argument.

Use the normalized module name in the template. — rjdbcm <ozi.project@outlook.com>
([`aaaa7c3`](https://github.com/OZI-Project/OZI/commit/aaaa7c30ecd16040224e0933bbef26d0ab45347e))


### Other


* 1.1.5

Automatically generated by python-semantic-release
([`fd1a842`](https://github.com/OZI-Project/OZI/commit/fd1a8422b0e362795b0de6001228cf264b313fc0))

## 1.1.4 (2024-04-24)


### 🐛 Fixed Bugs

* 🔨 Fix pytest-args for coverage. — rjdbcm <ozi.project@outlook.com>
([`1193781`](https://github.com/OZI-Project/OZI/commit/119378168e8e56096e05751b170fcd29a23e676b))


### Other


* 1.1.4

Automatically generated by python-semantic-release
([`8a97242`](https://github.com/OZI-Project/OZI/commit/8a97242b0cd1f5426eb39dd79a4f080a8525a5c5))

## 1.1.3 (2024-04-24)


### Other


* 1.1.3

Automatically generated by python-semantic-release
([`d62fea0`](https://github.com/OZI-Project/OZI/commit/d62fea08a4c51b5a4587fe80bd433a207d83ff9d))

* 🚨 Fix project template lint. — rjdbcm <ozi.project@outlook.com>
([`e946042`](https://github.com/OZI-Project/OZI/commit/e9460422674d666cb62f314a6d5dced9004fdd93))

## 1.1.2 (2024-04-24)


### 🐛 Fixed Bugs

*  Fix failing project build. — rjdbcm <ozi.project@outlook.com>
([`c87cbfd`](https://github.com/OZI-Project/OZI/commit/c87cbfd2219b46704324e22f16ca7bf8ddc93c2f))


### Other


* 1.1.2

Automatically generated by python-semantic-release
([`433c2d3`](https://github.com/OZI-Project/OZI/commit/433c2d3161b7e4be644f212a959c411f11c9d208))

* 🚨 no cover to_distribution. — rjdbcm <ozi.project@outlook.com>
([`cb4faba`](https://github.com/OZI-Project/OZI/commit/cb4faba04318b956c75a656a882d48a8ddecf4c1))

* Only run checkpoints on PR — rjdbcm <ozi.project@outlook.com>
([`1c28263`](https://github.com/OZI-Project/OZI/commit/1c2826321397784873ac366777ff2df1dd039038))

## 1.1.1 (2024-04-24)


### 🐛 Fixed Bugs

*  Fix pyproject_config missing in root ``meson.build`` template. — rjdbcm <ozi.project@outlook.com>
([`99b6528`](https://github.com/OZI-Project/OZI/commit/99b652818efae3f303897f27dcebb27d817574ec))


### Other


* 1.1.1

Automatically generated by python-semantic-release
([`1c1839d`](https://github.com/OZI-Project/OZI/commit/1c1839d3aa64840f8f0ed4c429b40e313f8a282b))

## 1.1.0 (2024-04-23)


### ⬆️ Upgraded Dependencies

*  Bump slsa-framework/slsa-github-generator

Bumps [slsa-framework/slsa-github-generator](https://github.com/slsa-framework/slsa-github-generator) from 1.10.0 to 2.0.0.
- [Release notes](https://github.com/slsa-framework/slsa-github-generator/releases)
- [Changelog](https://github.com/slsa-framework/slsa-github-generator/blob/main/CHANGELOG.md)
- [Commits](https://github.com/slsa-framework/slsa-github-generator/compare/v1.10.0...v2.0.0)


updated-dependencies:
- dependency-name: slsa-framework/slsa-github-generator
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] <support@github.com>
([`613e61e`](https://github.com/OZI-Project/OZI/commit/613e61ece9249db1d341d2ca3bd5ee9af4aa9032))

*  Bump OZI-Project/checkpoint from 0.1.4 to 0.1.5

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.1.4 to 0.1.5.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/8b7d897024b918d4bb4d44bbaec23a22f357182e...a6290f1edcd89a03dca8d123327e25f0c3bfc91c)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`d8b8bf4`](https://github.com/OZI-Project/OZI/commit/d8b8bf4d88e7727bc54ab5b07851233425d8bdf9))

*  Bump slsa-framework/slsa-github-generator

Bumps [slsa-framework/slsa-github-generator](https://github.com/slsa-framework/slsa-github-generator) from 1.10.0 to 2.0.0.
- [Release notes](https://github.com/slsa-framework/slsa-github-generator/releases)
- [Changelog](https://github.com/slsa-framework/slsa-github-generator/blob/main/CHANGELOG.md)
- [Commits](https://github.com/slsa-framework/slsa-github-generator/compare/v1.10.0...v2.0.0)


updated-dependencies:
- dependency-name: slsa-framework/slsa-github-generator
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] <support@github.com>
([`4c36d99`](https://github.com/OZI-Project/OZI/commit/4c36d99b912e91369441143dee2ce4031e9df5ca))

*  Bump github/codeql-action from 3.25.1 to 3.25.2

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.1 to 3.25.2.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/c7f9125735019aa87cfc361530512d50ea439c71...8f596b4ae3cb3c588a5c46780b86dd53fef16c52)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`e5c1cbe`](https://github.com/OZI-Project/OZI/commit/e5c1cbe8c62c08a43c224c0a8a5ccc444fd0d382))

*  Bump actions/upload-artifact from 4.3.2 to 4.3.3

Bumps [actions/upload-artifact](https://github.com/actions/upload-artifact) from 4.3.2 to 4.3.3.
- [Release notes](https://github.com/actions/upload-artifact/releases)
- [Commits](https://github.com/actions/upload-artifact/compare/1746f4ab65b179e0ea60a494b83293b640dd5bba...65462800fd760344b1a7b4382951275a0abb4808)


updated-dependencies:
- dependency-name: actions/upload-artifact
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`7ac5bb8`](https://github.com/OZI-Project/OZI/commit/7ac5bb8ab6e962f843538809d11bda1835a635f0))


### ✨ Implemented Features

*  Add 1.1 release branch group.
([`02ee683`](https://github.com/OZI-Project/OZI/commit/02ee683996ad5bbdf5b8289f490f9ce7bef34f13))

*  SLSA provenance builder updated in template.

2.0.0>1.10.0 — rjdbcm <ozi.project@outlook.com>
([`8235263`](https://github.com/OZI-Project/OZI/commit/8235263028a1b0ff389cbedaf316597ff609c83b))


### Other


* 1.1.0

Automatically generated by python-semantic-release
([`3b84e8d`](https://github.com/OZI-Project/OZI/commit/3b84e8dd0b12e6e85d66cfa146b52e2e6d0bc724))

## 1.0.0 (2024-04-22)


### 🐛 Fixed Bugs

*  fix version bump. — rjdbcm <ozi.project@outlook.com>
([`e518299`](https://github.com/OZI-Project/OZI/commit/e518299b62831f3674aecb5eda9e671f3de87aee))


### Other


* 1.0.0

Automatically generated by python-semantic-release
([`fa2b639`](https://github.com/OZI-Project/OZI/commit/fa2b63993788b21271151ec96fce0b6f50631ca3))
